@@ -1,6 +1,7 @@
 #pragma once
 
 #include <string>
+#include <string_view>
 #include <vector>
 #include <cstdio>
 #include <cstdint>
@@ -32,8 +33,9 @@ enum {
 	GETFILES_GET_NAVIGATION_ENTRIES = 2,  // If you don't set this, "." and ".." will be skipped.
 };
 
-bool GetFilesInDir(const Path &directory, std::vector<FileInfo> *files, const char *filter = nullptr, int flags = 0);
-std::vector<File::FileInfo> ApplyFilter(std::vector<File::FileInfo> files, const char *filter);
+// Note: extensionFilter is ignored for directories, so you can recurse.
+bool GetFilesInDir(const Path &directory, std::vector<FileInfo> *files, const char *extensionFilter = nullptr, int flags = 0, std::string_view prefix = std::string_view());
+std::vector<File::FileInfo> ApplyFilter(std::vector<File::FileInfo> files, const char *extensionFilter, std::string_view prefix);
 
 #ifdef _WIN32
 std::vector<std::string> GetWindowsDrives();
