@@ -42,10 +42,10 @@ bool MemArena::GrabMemSpace(size_t size) {
 	vm_size = size;
 	kern_return_t retval = vm_allocate(mach_task_self(), &vm_mem, size, VM_FLAGS_ANYWHERE);
 	if (retval != KERN_SUCCESS) {
-		ERROR_LOG(MEMMAP, "Failed to grab a block of virtual memory");
+		ERROR_LOG(Log::MemMap, "Failed to grab a block of virtual memory");
 		return false;
 	} else {
-		INFO_LOG(MEMMAP, "Successfully allocated %d bytes at %p", (int)size, (void *)vm_mem);
+		INFO_LOG(Log::MemMap, "Successfully allocated %d bytes at %p", (int)size, (void *)vm_mem);
 		return true;
 	}
 }
@@ -72,7 +72,7 @@ void *MemArena::CreateView(s64 offset, size_t size, void *base) {
 		// 1 == KERN_INVALID_ADDRESS
 		// 3 == KERN_NO_SPACE (race?)
 		// 4 == KERN_INVALID_ARGUMENT
-		ERROR_LOG(MEMMAP, "vm_remap failed (%d) - could not remap from %llx (offset %llx) of size %llx to %p",
+		ERROR_LOG(Log::MemMap, "vm_remap failed (%d) - could not remap from %llx (offset %llx) of size %llx to %p",
 				  (int)retval, (uint64_t)source, (uint64_t)offset, (uint64_t)size, base);
 		return nullptr;
 	}
