@@ -21,25 +21,16 @@ public:
 
 	uint32_t SetFont(const char *fontName, int size, int flags) override;
 	void SetFont(uint32_t fontHandle) override;  // Shortcut once you've set the font once.
-	void MeasureString(const char *str, size_t len, float *w, float *h) override;
-	void MeasureStringRect(const char *str, size_t len, const Bounds &bounds, float *w, float *h, int align = ALIGN_TOPLEFT) override;
-	void DrawString(DrawBuffer &target, const char *str, float x, float y, uint32_t color, int align = ALIGN_TOPLEFT) override;
-	void DrawStringBitmap(std::vector<uint8_t> &bitmapData, TextStringEntry &entry, Draw::DataFormat texFormat, const char *str, int align = ALIGN_TOPLEFT) override;
-	// Use for housekeeping like throwing out old strings.
-	void OncePerFrame() override;
+	bool DrawStringBitmap(std::vector<uint8_t> &bitmapData, TextStringEntry &entry, Draw::DataFormat texFormat, std::string_view str, int align, bool fullColor) override;
 
 protected:
-	void ClearCache() override;
-	void RecreateFonts();  // On DPI change
+	void MeasureStringInternal(std::string_view str, float *w, float *h) override;
+	bool SupportsColorEmoji() const override { return true; }
+	void ClearFonts() override;
 
 	TextDrawerContext *ctx_;
 	std::map<uint32_t, std::unique_ptr<TextDrawerFontContext>> fontMap_;
 
-	uint32_t fontHash_;
-	std::map<CacheKey, std::unique_ptr<TextStringEntry>> cache_;
-	std::map<CacheKey, std::unique_ptr<TextMeasureEntry>> sizeCache_;
-	
-
 	// Direct2D drawing components.
 	ID2D1Factory5*        m_d2dFactory;
 	ID2D1Device4*         m_d2dDevice;
