@@ -7,9 +7,6 @@
 
 #if defined(_WIN32) && !defined(USING_QT_UI) && !PPSSPP_PLATFORM(UWP)
 
-#define WIN32_LEAN_AND_MEAN
-#include <Windows.h>
-
 struct TextDrawerContext;
 // Internal struct but all details in .cpp file (pimpl to avoid pulling in excessive headers here)
 class TextDrawerFontContext;
