@@ -8,6 +8,9 @@
 #include "Common/UI/View.h"
 #include "Common/UI/ScrollView.h"
 
+// from StringUtils
+enum class StringRestriction;
+
 namespace UI {
 
 static const float NO_DEFAULT_FLOAT = -1000000.0f;
@@ -77,14 +80,18 @@ private:
 
 class SliderPopupScreen : public PopupScreen {
 public:
-	SliderPopupScreen(int *value, int minValue, int maxValue, int defaultValue, std::string_view title, int step = 1, std::string_view units = "")
-		: PopupScreen(title, "OK", "Cancel"), units_(units), value_(value), minValue_(minValue), maxValue_(maxValue), defaultValue_(defaultValue), step_(step) {}
+	SliderPopupScreen(int *value, int minValue, int maxValue, int defaultValue, std::string_view title, int step, std::string_view units, bool liveUpdate)
+		: PopupScreen(title, "OK", "Cancel"), units_(units), value_(value), minValue_(minValue), maxValue_(maxValue), defaultValue_(defaultValue), step_(step), liveUpdate_(liveUpdate) {}
 	void CreatePopupContents(ViewGroup *parent) override;
 
 	void SetNegativeDisable(const std::string &str) {
 		negativeLabel_ = str;
 		disabled_ = *value_ < 0;
 	}
+	void RestrictChoices(const int *fixedChoices, size_t numFixedChoices) {
+		fixedChoices_ = fixedChoices;
+		numFixedChoices_ = numFixedChoices;
+	}
 
 	const char *tag() const override { return "SliderPopup"; }
 
@@ -107,8 +114,11 @@ private:
 	int maxValue_;
 	int defaultValue_;
 	int step_;
+	bool liveUpdate_;
 	bool changing_ = false;
 	bool disabled_ = false;
+	const int *fixedChoices_ = nullptr;
+	size_t numFixedChoices_ = 0;
 };
 
 class SliderFloatPopupScreen : public PopupScreen {
@@ -300,9 +310,16 @@ public:
 	void SetZeroLabel(std::string_view str) {
 		zeroLabel_ = str;
 	}
+	void SetLiveUpdate(bool update) {
+		liveUpdate_ = update;
+	}
 	void SetNegativeDisable(std::string_view str) {
 		negativeLabel_ = str;
 	}
+	void RestrictChoices(const int *fixedChoices, size_t numFixedChoices) {
+		fixedChoices_ = fixedChoices;
+		numFixedChoices_ = numFixedChoices;
+	}
 
 	Event OnChange;
 
@@ -324,6 +341,9 @@ private:
 	std::string units_;
 	ScreenManager *screenManager_;
 	bool restoreFocus_ = false;
+	bool liveUpdate_ = false;
+	const int *fixedChoices_ = nullptr;
+	size_t numFixedChoices_ = 0;
 };
 
 class PopupSliderChoiceFloat : public AbstractChoiceWithValueDisplay {
@@ -371,6 +391,11 @@ public:
 
 	Event OnChange;
 
+	void SetRestriction(StringRestriction restriction, int minLength) {
+		restriction_ = restriction;
+		minLen_ = minLength;
+	}
+
 protected:
 	std::string ValueText() const override;
 
@@ -383,7 +408,9 @@ private:
 	std::string placeHolder_;
 	std::string defaultText_;
 	int maxLen_;
+	int minLen_ = 0;
 	bool restoreFocus_ = false;
+	StringRestriction restriction_;
 };
 
 class ChoiceWithValueDisplay : public AbstractChoiceWithValueDisplay {
@@ -420,8 +447,6 @@ public:
 
 private:
 	std::string *value_;
-	BrowseFileType fileType_;
-	RequesterToken token_;
 };
 
 class FolderChooserChoice : public AbstractChoiceWithValueDisplay {
