@@ -100,7 +100,7 @@ View::~View() {
 	RemoveQueuedEventsByView(this);
 
 	// Could use unique_ptr, but then we have to include tween everywhere.
-	for (auto &tween : tweens_)
+	for (UI::Tween *tween : tweens_)
 		delete tween;
 }
 
@@ -249,6 +249,11 @@ bool Clickable::Touch(const TouchInput &input) {
 		return contains;
 	}
 
+	// Ignore buttons other than the left one.
+	if ((input.flags & TOUCH_MOUSE) && (input.buttons & 1) == 0) {
+		return contains;
+	}
+
 	if (input.flags & TOUCH_DOWN) {
 		if (bounds_.Contains(input.x, input.y)) {
 			if (IsFocusMovementEnabled())
@@ -531,6 +536,10 @@ void Choice::Draw(UIContext &dc) {
 		} else {
 			if (rightIconImage_.isValid()) {
 				uint32_t col = rightIconKeepColor_ ? 0xffffffff : style.fgColor; // Don't apply theme to gold icon
+				if (shine_) {
+					Bounds b = Bounds::FromCenter(bounds_.x2() - 32 - paddingX, bounds_.centerY(), bounds_.h * 0.4f);
+					DrawIconShine(dc, b.Inset(5.0f, 5.0f), 0.65f, false);
+				}
 				dc.Draw()->DrawImageRotated(rightIconImage_, bounds_.x2() - 32 - paddingX, bounds_.centerY(), rightIconScale_, rightIconRot_, col, rightIconFlipH_);
 			}
 			Bounds textBounds(bounds_.x + paddingX + textPadding_.left, bounds_.y, availWidth, bounds_.h);
@@ -552,10 +561,6 @@ std::string Choice::DescribeText() const {
 InfoItem::InfoItem(std::string_view text, std::string_view rightText, LayoutParams *layoutParams)
 	: Item(layoutParams), text_(text), rightText_(rightText) {
 	// We set the colors later once we have a UIContext.
-	bgColor_ = AddTween(new CallbackColorTween(0.1f));
-	bgColor_->Persist();
-	fgColor_ = AddTween(new CallbackColorTween(0.1f));
-	fgColor_->Persist();
 }
 
 void InfoItem::Draw(UIContext &dc) {
@@ -563,20 +568,6 @@ void InfoItem::Draw(UIContext &dc) {
 
 	UI::Style style = HasFocus() ? dc.theme->itemFocusedStyle : dc.theme->infoStyle;
 
-	if (choiceStyle_) {
-		style = HasFocus() ? dc.theme->itemFocusedStyle : dc.theme->itemStyle;
-	}
-
-	if (style.background.type == DRAW_SOLID_COLOR) {
-		// For a smoother fade, using the same color with 0 alpha.
-		if ((style.background.color & 0xFF000000) == 0)
-			style.background.color = dc.theme->itemFocusedStyle.background.color & 0x00FFFFFF;
-		bgColor_->Divert(style.background.color & 0x7fffffff);
-		style.background.color = bgColor_->CurrentValue();
-	}
-	fgColor_->Divert(style.fgColor);
-	style.fgColor = fgColor_->CurrentValue();
-
 	dc.FillRect(style.background, bounds_);
 
 	int paddingX = 12;
@@ -607,6 +598,7 @@ void ItemHeader::Draw(UIContext &dc) {
 	dc.SetFontStyle(large_ ? dc.theme->uiFont : dc.theme->uiFontSmall);
 
 	const UI::Style &style = popupStyle_ ? dc.theme->popupStyle : dc.theme->headerStyle;
+	dc.FillRect(style.background, bounds_);
 	dc.DrawText(text_, bounds_.x + 4, bounds_.centerY(), style.fgColor, ALIGN_LEFT | ALIGN_VCENTER);
 	dc.Draw()->DrawImageCenterTexel(dc.theme->whiteImage, bounds_.x, bounds_.y2()-2, bounds_.x2(), bounds_.y2(), style.fgColor);
 }
@@ -636,7 +628,7 @@ CollapsibleHeader::CollapsibleHeader(bool *toggle, std::string_view text, Layout
 }
 
 void CollapsibleHeader::Draw(UIContext &dc) {
-	Style style = dc.theme->itemStyle;
+	Style style = dc.theme->collapsibleHeaderStyle;
 	if (HasFocus()) style = dc.theme->itemFocusedStyle;
 	if (down_) style = dc.theme->itemDownStyle;
 	if (!IsEnabled()) style = dc.theme->itemDisabledStyle;
@@ -722,8 +714,12 @@ void PopupHeader::Draw(UIContext &dc) {
 		dc.PushScissor(tb);
 	}
 
-	dc.DrawText(text_, bounds_.x + tx, bounds_.centerY(), dc.theme->itemStyle.fgColor, ALIGN_LEFT | ALIGN_VCENTER);
-	dc.Draw()->DrawImageCenterTexel(dc.theme->whiteImage, bounds_.x, bounds_.y2()-2, bounds_.x2(), bounds_.y2(), dc.theme->itemStyle.fgColor);
+	// Header background
+	dc.FillRect(dc.theme->popupTitleStyle.background, bounds_);
+	// Header title text
+	dc.DrawText(text_, bounds_.x + tx, bounds_.centerY(), dc.theme->popupTitleStyle.fgColor, ALIGN_LEFT | ALIGN_VCENTER);
+	// Underline
+	dc.Draw()->DrawImageCenterTexel(dc.theme->whiteImage, bounds_.x, bounds_.y2()-2, bounds_.x2(), bounds_.y2(), dc.theme->popupTitleStyle.fgColor);
 
 	if (availableWidth < tw) {
 		dc.PopScissor();
@@ -1019,8 +1015,13 @@ void RadioButton::Draw(UIContext &dc) {
 	}
 }
 
+ImageView::ImageView(ImageID atlasImage, const std::string &text, ImageSizeMode sizeMode, LayoutParams *layoutParams)
+	: InertView(layoutParams), text_(text), atlasImage_(atlasImage), sizeMode_(sizeMode) {}
+
 void ImageView::GetContentDimensions(const UIContext &dc, float &w, float &h) const {
 	dc.Draw()->GetAtlas()->measureImage(atlasImage_, &w, &h);
+	w *= scale_;
+	h *= scale_;
 	// TODO: involve sizemode
 }
 
@@ -1063,7 +1064,7 @@ void TextView::GetContentDimensionsBySpec(const UIContext &dc, MeasureSpec horiz
 }
 
 void TextView::Draw(UIContext &dc) {
-	uint32_t textColor = hasTextColor_ ? textColor_ : dc.theme->infoStyle.fgColor;
+	uint32_t textColor = hasTextColor_ ? textColor_ : (popupStyle_ ? dc.theme->popupStyle.fgColor : dc.theme->infoStyle.fgColor);
 	if (!(textColor & 0xFF000000))
 		return;
 
@@ -1120,6 +1121,40 @@ void TextView::Draw(UIContext &dc) {
 	}
 }
 
+bool ClickableTextView::Touch(const TouchInput &input) {
+	bool contains = bounds_.Contains(input.x, input.y);
+
+	// Ignore buttons other than the left one.
+	if ((input.flags & TOUCH_MOUSE) && (input.buttons & 1) == 0) {
+		return contains;
+	}
+
+	if (input.flags & TOUCH_DOWN) {
+		if (bounds_.Contains(input.x, input.y)) {
+			if (IsFocusMovementEnabled())
+				SetFocusedView(this);
+			dragging_ = true;
+			down_ = true;
+		} else {
+			down_ = false;
+			dragging_ = false;
+		}
+	} else if (input.flags & TOUCH_MOVE) {
+		if (dragging_)
+			down_ = bounds_.Contains(input.x, input.y);
+	}
+	if (input.flags & TOUCH_UP) {
+		if ((input.flags & TOUCH_CANCEL) == 0 && dragging_ && bounds_.Contains(input.x, input.y)) {
+			EventParams e{};
+			e.v = this;
+			OnClick.Trigger(e);
+		}
+		down_ = false;
+		dragging_ = false;
+	}
+	return contains;
+}
+
 TextEdit::TextEdit(std::string_view text, std::string_view title, std::string_view placeholderText, LayoutParams *layoutParams)
   : View(layoutParams), text_(text), title_(title), undo_(text), placeholderText_(placeholderText),
     textColor_(0xFFFFFFFF), maxLen_(255) {
@@ -1138,9 +1173,11 @@ void TextEdit::FocusChanged(int focusFlags) {
 void TextEdit::Draw(UIContext &dc) {
 	dc.PushScissor(bounds_);
 	dc.SetFontStyle(dc.theme->uiFont);
+
+	// TODO: make background themeable?
 	dc.FillRect(HasFocus() ? UI::Drawable(0x80000000) : UI::Drawable(0x30000000), bounds_);
 
-	uint32_t textColor = hasTextColor_ ? textColor_ : dc.theme->infoStyle.fgColor;
+	uint32_t textColor = popupStyle_ ? dc.theme->popupStyle.fgColor : dc.theme->infoStyle.fgColor;
 	float textX = bounds_.x;
 	float w, h;
 
@@ -1339,7 +1376,7 @@ bool TextEdit::Key(const KeyInput &input) {
 			// Insert it! (todo: do it with a string insert)
 			char buf[8];
 			buf[u8_wc_toutf8(buf, unichar)] = '\0';
-			if (strlen(buf) + text_.size() < maxLen_) {
+			if (strlen(buf) + text_.size() <= maxLen_) {
 				undo_ = text_;
 				InsertAtCaret(buf);
 				textChanged = true;
@@ -1391,6 +1428,13 @@ void Spinner::Draw(UIContext &dc) {
 		return;
 	double t = time_now_d() * 1.3f;
 	double angle = fmod(t, M_PI * 2.0);
+
+	if (!images_) {
+		// Simple.
+		dc.Draw()->CircleSegment(bounds_.centerX(), bounds_.centerY(), bounds_.radius(), 3.0f, 20.0f, angle, angle + PI * 3.0 / 2.0, dc.theme->itemStyle.fgColor, 0.0f);
+		return;
+	}
+
 	float r = bounds_.w * 0.5f;
 	double da = M_PI * 2.0 / numImages_;
 	for (int i = 0; i < numImages_; i++) {
@@ -1408,6 +1452,7 @@ bool TriggerButton::Touch(const TouchInput &input) {
 			down_ |= 1 << input.id;
 		}
 	}
+
 	if (input.flags & TOUCH_MOVE) {
 		if (contains)
 			down_ |= 1 << input.id;
@@ -1455,32 +1500,71 @@ bool Slider::Key(const KeyInput &input) {
 }
 
 bool Slider::ApplyKey(InputKeyCode keyCode) {
-	switch (keyCode) {
-	case NKCODE_DPAD_LEFT:
-	case NKCODE_MINUS:
-	case NKCODE_NUMPAD_SUBTRACT:
-		*value_ -= step_;
-		break;
-	case NKCODE_DPAD_RIGHT:
-	case NKCODE_PLUS:
-	case NKCODE_NUMPAD_ADD:
-		*value_ += step_;
-		break;
-	case NKCODE_PAGE_UP:
-		*value_ -= step_ * 10;
-		break;
-	case NKCODE_PAGE_DOWN:
-		*value_ += step_ * 10;
-		break;
-	case NKCODE_MOVE_HOME:
-		*value_ = minValue_;
-		break;
-	case NKCODE_MOVE_END:
-		*value_ = maxValue_;
-		break;
-	default:
-		return false;
+	SnapToFixed();
+	
+	if (numFixedChoices_) {
+		// Find the current one.
+		int curIndex = -1;
+		for (int i = 0; i < numFixedChoices_; i++) {
+			if (*value_ == fixedChoices_[i]) {
+				curIndex = i;
+			}
+		}
+		switch (keyCode) {
+		case NKCODE_DPAD_LEFT:
+		case NKCODE_MINUS:
+		case NKCODE_NUMPAD_SUBTRACT:
+		case NKCODE_PAGE_DOWN:
+			if (curIndex >= 1) {
+				*value_ = fixedChoices_[curIndex - 1];
+			}
+			break;
+		case NKCODE_DPAD_RIGHT:
+		case NKCODE_PLUS:
+		case NKCODE_NUMPAD_ADD:
+		case NKCODE_PAGE_UP:
+			if (curIndex < numFixedChoices_ - 1) {
+				*value_ = fixedChoices_[curIndex + 1];
+			}
+			break;
+		case NKCODE_MOVE_HOME:
+			*value_ = fixedChoices_[0];
+			break;
+		case NKCODE_MOVE_END:
+			*value_ = fixedChoices_[numFixedChoices_ - 1];
+			break;
+		default:
+			return false;
+		}
+	} else {
+		switch (keyCode) {
+		case NKCODE_DPAD_LEFT:
+		case NKCODE_MINUS:
+		case NKCODE_NUMPAD_SUBTRACT:
+			*value_ -= step_;
+			break;
+		case NKCODE_DPAD_RIGHT:
+		case NKCODE_PLUS:
+		case NKCODE_NUMPAD_ADD:
+			*value_ += step_;
+			break;
+		case NKCODE_PAGE_UP:
+			*value_ -= step_ * 10;
+			break;
+		case NKCODE_PAGE_DOWN:
+			*value_ += step_ * 10;
+			break;
+		case NKCODE_MOVE_HOME:
+			*value_ = minValue_;
+			break;
+		case NKCODE_MOVE_END:
+			*value_ = maxValue_;
+			break;
+		default:
+			return false;
+		}
 	}
+
 	EventParams params{};
 	params.v = this;
 	params.a = (uint32_t)(*value_);
@@ -1515,24 +1599,34 @@ void Slider::Clamp() {
 
 	// Clamp the value to be a multiple of the nearest step (e.g. if step == 5, value == 293, it'll round down to 290).
 	*value_ = *value_ - fmodf(*value_, step_);
+
+	// If it's a fixed set, snap it.
+	SnapToFixed();
 }
 
 void Slider::Draw(UIContext &dc) {
 	bool focus = HasFocus();
-	uint32_t linecolor = dc.theme->itemStyle.fgColor;
-	Style knobStyle = (down_ || focus) ? dc.theme->itemStyle : dc.theme->popupStyle;
+	uint32_t sliderColor;
+
+	if (down_) {
+		sliderColor = popupStyle_ ? dc.theme->popupSliderFocusedColor : dc.theme->itemDownStyle.fgColor;
+	} else if (focus) {
+		sliderColor = popupStyle_ ? dc.theme->popupSliderFocusedColor : dc.theme->itemFocusedStyle.fgColor;
+	} else {
+		sliderColor = popupStyle_ ? dc.theme->popupSliderColor : dc.theme->itemStyle.fgColor;
+	}
 
 	float knobX = ((float)(*value_) - minValue_) / (maxValue_ - minValue_) * (bounds_.w - paddingLeft_ - paddingRight_) + (bounds_.x + paddingLeft_);
-	dc.FillRect(Drawable(linecolor), Bounds(bounds_.x + paddingLeft_, bounds_.centerY() - 2, knobX - (bounds_.x + paddingLeft_), 4));
+	dc.FillRect(Drawable(sliderColor), Bounds(bounds_.x + paddingLeft_, bounds_.centerY() - 2, knobX - (bounds_.x + paddingLeft_), 4));
 	dc.FillRect(Drawable(0xFF808080), Bounds(knobX, bounds_.centerY() - 2, (bounds_.x + bounds_.w - paddingRight_ - knobX), 4));
-	dc.Draw()->DrawImage(dc.theme->sliderKnob, knobX, bounds_.centerY(), 1.0f, knobStyle.fgColor, ALIGN_CENTER);
+	dc.Draw()->DrawImage(dc.theme->sliderKnob, knobX, bounds_.centerY(), 1.0f, sliderColor, ALIGN_CENTER);
 	char temp[64];
 	if (showPercent_)
 		snprintf(temp, sizeof(temp), "%d%%", *value_);
 	else
 		snprintf(temp, sizeof(temp), "%d", *value_);
 	dc.SetFontStyle(dc.theme->uiFont);
-	dc.DrawText(temp, bounds_.x2() - 22, bounds_.centerY(), dc.theme->popupStyle.fgColor, ALIGN_CENTER | FLAG_DYNAMIC_ASCII);
+	dc.DrawText(temp, bounds_.x2() - 22, bounds_.centerY(), sliderColor, ALIGN_CENTER | FLAG_DYNAMIC_ASCII);
 }
 
 std::string Slider::DescribeText() const {
@@ -1559,6 +1653,30 @@ void Slider::Update() {
 	}
 }
 
+void Slider::SnapToFixed() {
+	if (!numFixedChoices_) {
+		return;
+	}
+
+	int val = *value_;
+	// Find the closest value.
+	int minDist = 999999999;
+	int best = -1;
+	for (int i = 0; i < numFixedChoices_; i++) {
+		int dist = val - fixedChoices_[i];
+		if (dist < 0)
+			dist = -dist;
+		if (dist < minDist) {
+			minDist = dist;
+			best = i;
+		}
+	}
+
+	if (best >= 0) {
+		*value_ = fixedChoices_[best];
+	}
+}
+
 void Slider::GetContentDimensions(const UIContext &dc, float &w, float &h) const {
 	// TODO
 	w = 100;
@@ -1648,17 +1766,24 @@ void SliderFloat::Clamp() {
 
 void SliderFloat::Draw(UIContext &dc) {
 	bool focus = HasFocus();
-	uint32_t linecolor = dc.theme->itemStyle.fgColor;
-	Style knobStyle = (down_ || focus) ? dc.theme->itemStyle : dc.theme->popupStyle;
+	uint32_t sliderColor;
+
+	if (down_) {
+		sliderColor = popupStyle_ ? dc.theme->popupSliderFocusedColor : dc.theme->itemDownStyle.fgColor;
+	} else if (focus) {
+		sliderColor = popupStyle_ ? dc.theme->popupSliderFocusedColor : dc.theme->itemFocusedStyle.fgColor;
+	} else {
+		sliderColor = popupStyle_ ? dc.theme->popupSliderColor : dc.theme->itemStyle.fgColor;
+	}
 
 	float knobX = (*value_ - minValue_) / (maxValue_ - minValue_) * (bounds_.w - paddingLeft_ - paddingRight_) + (bounds_.x + paddingLeft_);
-	dc.FillRect(Drawable(linecolor), Bounds(bounds_.x + paddingLeft_, bounds_.centerY() - 2, knobX - (bounds_.x + paddingLeft_), 4));
+	dc.FillRect(Drawable(sliderColor), Bounds(bounds_.x + paddingLeft_, bounds_.centerY() - 2, knobX - (bounds_.x + paddingLeft_), 4));
 	dc.FillRect(Drawable(0xFF808080), Bounds(knobX, bounds_.centerY() - 2, (bounds_.x + bounds_.w - paddingRight_ - knobX), 4));
-	dc.Draw()->DrawImage(dc.theme->sliderKnob, knobX, bounds_.centerY(), 1.0f, knobStyle.fgColor, ALIGN_CENTER);
+	dc.Draw()->DrawImage(dc.theme->sliderKnob, knobX, bounds_.centerY(), 1.0f, sliderColor, ALIGN_CENTER);
 	char temp[64];
 	snprintf(temp, sizeof(temp), "%0.2f", *value_);
 	dc.SetFontStyle(dc.theme->uiFont);
-	dc.DrawText(temp, bounds_.x2() - 22, bounds_.centerY(), dc.theme->popupStyle.fgColor, ALIGN_CENTER);
+	dc.DrawText(temp, bounds_.x2() - 22, bounds_.centerY(), sliderColor, ALIGN_CENTER);
 }
 
 std::string SliderFloat::DescribeText() const {
@@ -1693,4 +1818,33 @@ void Spacer::Draw(UIContext &dc) {
 	}
 }
 
+void DrawIconShine(UIContext &dc, const Bounds &bounds, float shine, bool animated) {
+	static const float radius[6] = { 0.5f, 0.6f, 0.7f, 0.8f, 0.9f, 1.0f };
+	static const float startAngle[6] = { 0.3f, 0.5f, 0.1f, 0.9f, 0.7f, 0.4f };
+	static const float arcLength[6] = { 0.45f, 0.2f, 0.6f, 0.7f, 0.3f, 0.5f };
+	static const float speed[6] = { 0.4f, -0.9f, 0.2f, -0.6f, 0.7f, -0.1f };
+	if (animated) {
+		dc.Flush();
+		dc.BeginNoTex();
+
+		const double t = time_now_d();
+		const int x = bounds.centerX();
+		const int y = bounds.centerY();
+		for (int i = 0; i < 6; i++) {
+			float radius = (i * 0.1f + 0.4f) * 1.3f;
+			float alpha = (5 - i) * (1.0f / 9.0f);
+
+			float angle = fmod(startAngle[i] + t * speed[i] * 0.7f, 1.0) * 2 * PI;
+			dc.Draw()->CircleSegment(x, y, radius * bounds.w, 4.0f, 64.0f, angle, angle + arcLength[i] * 2 * PI, colorAlpha(0xFF3EC5FF, alpha * shine), 0.0f);
+		}
+
+		dc.Flush();
+		dc.Begin();
+	}
+	const AtlasImage *img = dc.Draw()->GetAtlas()->getImage(ImageID("I_DROP_SHADOW"));
+	float scale = bounds.w / img->w;
+	dc.Draw()->DrawImage(ImageID("I_DROP_SHADOW"), bounds.centerX(), bounds.centerY(), scale * 1.7f, colorAlpha(0xFF3EC5FF, 0.75f * shine), ALIGN_CENTER);
+	dc.Flush();
+}
+
 }  // namespace
