@@ -30,7 +30,7 @@ enum VRAppMode {
 // VR app flow integration
 bool IsVREnabled();
 void InitVROnAndroid(void* vm, void* activity, const char* system, int version, const char* name);
-void EnterVR(bool firstStart, void* vulkanContext);
+void EnterVR(bool firstStart);
 void GetVRResolutionPerEye(int* width, int* height);
 void SetVRCallbacks(void(*axis)(const AxisInput *axis, size_t count), bool(*key)(const KeyInput &key), void(*touch)(const TouchInput &touch));
 
@@ -53,6 +53,7 @@ void PostVRFrameRender();
 int GetVRFBOIndex();
 int GetVRPassesCount();
 bool IsPassthroughSupported();
+bool IsBigScreenVRMode();
 bool IsFlatVRGame();
 bool IsFlatVRScene();
 bool IsGameVRScene();
