@@ -27,6 +27,8 @@ void WebSocketHLEThreadStop(DebuggerRequest &req);
 void WebSocketHLEFuncList(DebuggerRequest &req);
 void WebSocketHLEFuncAdd(DebuggerRequest &req);
 void WebSocketHLEFuncRemove(DebuggerRequest &req);
+void WebSocketHLEFuncRemoveRange(DebuggerRequest &req);
 void WebSocketHLEFuncRename(DebuggerRequest &req);
+void WebSocketHLEFuncScan(DebuggerRequest &req);
 void WebSocketHLEModuleList(DebuggerRequest &req);
 void WebSocketHLEBacktrace(DebuggerRequest &req);
