@@ -30,10 +30,10 @@ using namespace MIPSAnalyst;
 
 struct WebSocketSteppingState : public DebuggerSubscriber {
 	WebSocketSteppingState() {
-		disasm_.setCpu(currentDebugMIPS);
+		g_disassemblyManager.setCpu(currentDebugMIPS);
 	}
 	~WebSocketSteppingState() {
-		disasm_.clear();
+		g_disassemblyManager.clear();
 	}
 
 	void Into(DebuggerRequest &req);
@@ -47,8 +47,6 @@ protected:
 	int GetNextInstructionCount(DebugInterface *cpuDebug);
 	void PrepareResume();
 	void AddThreadCondition(uint32_t breakpointAddress, uint32_t threadID);
-
-	DisassemblyManager disasm_;
 };
 
 DebuggerSubscriber *WebSocketSteppingInit(DebuggerEventHandlerMap &map) {
@@ -93,7 +91,7 @@ void WebSocketSteppingState::Into(DebuggerRequest &req) {
 	if (!currentDebugMIPS->isAlive())
 		return req.Fail("CPU not started");
 	if (!Core_IsStepping()) {
-		Core_EnableStepping(true, "cpu.stepInto", 0);
+		Core_Break(BreakReason::DebugStepInto, 0);
 		return;
 	}
 
@@ -104,12 +102,10 @@ void WebSocketSteppingState::Into(DebuggerRequest &req) {
 
 	if (cpuDebug == currentDebugMIPS) {
 		// If the current PC is on a breakpoint, the user doesn't want to do nothing.
-		CBreakPoints::SetSkipFirst(currentMIPS->pc);
+		g_breakpoints.SetSkipFirst(currentMIPS->pc);
 
 		int c = GetNextInstructionCount(cpuDebug);
-		for (int i = 0; i < c; ++i) {
-			Core_DoSingleStep();
-		}
+		Core_RequestCPUStep(CPUStepType::Into, c);
 	} else {
 		uint32_t breakpointAddress = cpuDebug->GetPC();
 		PrepareResume();
@@ -117,9 +113,9 @@ void WebSocketSteppingState::Into(DebuggerRequest &req) {
 		// Note: we need to get cpuDebug again anyway (in case we ran some HLE above.)
 		cpuDebug = CPUFromRequest(req);
 		if (cpuDebug != currentDebugMIPS) {
-			CBreakPoints::AddBreakPoint(breakpointAddress, true);
+			g_breakpoints.AddBreakPoint(breakpointAddress, true);
 			AddThreadCondition(breakpointAddress, threadID);
-			Core_EnableStepping(false);
+			Core_Resume();
 		}
 	}
 }
@@ -170,10 +166,10 @@ void WebSocketSteppingState::Over(DebuggerRequest &req) {
 	// Could have advanced to the breakpoint already in PrepareResume().
 	cpuDebug = CPUFromRequest(req);
 	if (cpuDebug->GetPC() != breakpointAddress) {
-		CBreakPoints::AddBreakPoint(breakpointAddress, true);
+		g_breakpoints.AddBreakPoint(breakpointAddress, true);
 		if (cpuDebug != currentDebugMIPS)
 			AddThreadCondition(breakpointAddress, threadID);
-		Core_EnableStepping(false);
+		Core_Resume();
 	}
 }
 
@@ -219,10 +215,10 @@ void WebSocketSteppingState::Out(DebuggerRequest &req) {
 	// Could have advanced to the breakpoint already in PrepareResume().
 	cpuDebug = CPUFromRequest(req);
 	if (cpuDebug->GetPC() != breakpointAddress) {
-		CBreakPoints::AddBreakPoint(breakpointAddress, true);
+		g_breakpoints.AddBreakPoint(breakpointAddress, true);
 		if (cpuDebug != currentDebugMIPS)
 			AddThreadCondition(breakpointAddress, threadID);
-		Core_EnableStepping(false);
+		Core_Resume();
 	}
 }
 
@@ -247,8 +243,8 @@ void WebSocketSteppingState::RunUntil(DebuggerRequest &req) {
 	PrepareResume();
 	// We may have arrived already if PauseResume() stepped out of a delay slot.
 	if (currentMIPS->pc != address || wasAtAddress) {
-		CBreakPoints::AddBreakPoint(address, true);
-		Core_EnableStepping(false);
+		g_breakpoints.AddBreakPoint(address, true);
+		Core_Resume();
 	}
 }
 
@@ -264,12 +260,12 @@ void WebSocketSteppingState::HLE(DebuggerRequest &req) {
 
 	PrepareResume();
 	hleDebugBreak();
-	Core_EnableStepping(false);
+	Core_Resume();
 }
 
 uint32_t WebSocketSteppingState::GetNextAddress(DebugInterface *cpuDebug) {
-	uint32_t current = disasm_.getStartAddress(cpuDebug->GetPC());
-	return disasm_.getNthNextAddress(current, 1);
+	uint32_t current = g_disassemblyManager.getStartAddress(cpuDebug->GetPC());
+	return g_disassemblyManager.getNthNextAddress(current, 1);
 }
 
 int WebSocketSteppingState::GetNextInstructionCount(DebugInterface *cpuDebug) {
@@ -278,10 +274,11 @@ int WebSocketSteppingState::GetNextInstructionCount(DebugInterface *cpuDebug) {
 
 void WebSocketSteppingState::PrepareResume() {
 	if (currentMIPS->inDelaySlot) {
-		Core_DoSingleStep();
+		// Delay slot instructions are never joined, so we pass 1.
+		Core_RequestCPUStep(CPUStepType::Into, 1);
 	} else {
 		// If the current PC is on a breakpoint, the user doesn't want to do nothing.
-		CBreakPoints::SetSkipFirst(currentMIPS->pc);
+		g_breakpoints.SetSkipFirst(currentMIPS->pc);
 	}
 }
 
@@ -289,6 +286,6 @@ void WebSocketSteppingState::AddThreadCondition(uint32_t breakpointAddress, uint
 	BreakPointCond cond;
 	cond.debug = currentDebugMIPS;
 	cond.expressionString = StringFromFormat("threadid == 0x%08x", threadID);
-	if (currentDebugMIPS->initExpression(cond.expressionString.c_str(), cond.expression))
-		CBreakPoints::ChangeBreakPointAddCond(breakpointAddress, cond);
+	if (initExpression(currentDebugMIPS, cond.expressionString.c_str(), cond.expression))
+		g_breakpoints.ChangeBreakPointAddCond(breakpointAddress, cond);
 }
