@@ -19,6 +19,7 @@
 // * Frame skipping. This gets complicated.
 // * The game not actually asking for flips, like in static loading screens
 
+#include "ppsspp_config.h"
 #include "Common/Profiler/Profiler.h"
 #include "Common/Log.h"
 #include "Common/TimeUtil.h"
@@ -26,16 +27,24 @@
 #include "Core/RetroAchievements.h"
 #include "Core/CoreParameter.h"
 #include "Core/Core.h"
+#include "Core/System.h"
 #include "Core/Config.h"
 #include "Core/HW/Display.h"
+#include "Core/HLE/sceNet.h"
 #include "Core/FrameTiming.h"
 
 FrameTiming g_frameTiming;
 
-void WaitUntil(double now, double timestamp) {
-#ifdef _WIN32
+void WaitUntil(double now, double timestamp, const char *reason) {
+#if 1
+	// Use precise timing.
+	sleep_precise(timestamp - now);
+#else
+
+#if PPSSPP_PLATFORM(WINDOWS)
+	// Old method. TODO: Should we make an option?
 	while (time_now_d() < timestamp) {
-		sleep_ms(1); // Sleep for 1ms on this thread
+		sleep_ms(1, reason); // Sleep for 1ms on this thread
 	}
 #else
 	const double left = timestamp - now;
@@ -43,6 +52,8 @@ void WaitUntil(double now, double timestamp) {
 		usleep((long)(left * 1000000));
 	}
 #endif
+
+#endif
 }
 
 inline Draw::PresentMode GetBestImmediateMode(Draw::PresentMode supportedModes) {
@@ -71,7 +82,7 @@ void FrameTiming::DeferWaitUntil(double until, double *curTimePtr) {
 
 void FrameTiming::PostSubmit() {
 	if (waitUntil_ != 0.0) {
-		WaitUntil(time_now_d(), waitUntil_);
+		WaitUntil(time_now_d(), waitUntil_, "post-submit");
 		if (curTimePtr_) {
 			*curTimePtr_ = waitUntil_;
 			curTimePtr_ = nullptr;
@@ -92,10 +103,16 @@ Draw::PresentMode ComputePresentMode(Draw::DrawContext *draw, int *interval) {
 			wantInstant = true;
 		}
 
-		if (PSP_CoreParameter().fastForward) {
+		if (PSP_CoreParameter().fastForward && NetworkAllowSpeedControl()) {
 			wantInstant = true;
 		}
-		if (PSP_CoreParameter().fpsLimit != FPSLimit::NORMAL) {
+
+		FPSLimit limit = PSP_CoreParameter().fpsLimit;
+		if (!NetworkAllowSpeedControl()) {
+			limit = FPSLimit::NORMAL;
+		}
+
+		if (limit != FPSLimit::NORMAL) {
 			int limit;
 			if (PSP_CoreParameter().fpsLimit == FPSLimit::CUSTOM1)
 				limit = g_Config.iFpsLimit1;
