@@ -204,7 +204,7 @@ template<int func(u32, u32)> void WrapI_UU() {
 template<int func(u32, float, float)> void WrapI_UFF() {
 	// Not sure about the float arguments.
 	int retval = func(PARAM(0), PARAMF(0), PARAMF(1));
-	RETURN(retval);
+	RETURN(retval);	
 }
 
 template<int func(u32, u32, u32)> void WrapI_UUU() {
@@ -232,6 +232,16 @@ template<int func(u32, u32, u32, u32, u32)> void WrapI_UUUUU() {
 	RETURN(retval);
 }
 
+template<int func(u32, const char*, u32, u32, int)> void WrapI_UCUUI() {
+	int retval = func(PARAM(0), Memory::GetCharPointer(PARAM(1)), PARAM(2), PARAM(3), PARAM(4));
+	RETURN(retval);
+}
+
+template<int func(u32, int, const char*, u32, u32)> void WrapI_UICUU() {
+	int retval = func(PARAM(0), PARAM(1), Memory::GetCharPointer(PARAM(2)), PARAM(3), PARAM(4));
+	RETURN(retval);
+}
+
 template<int func()> void WrapI_V() {
 	int retval = func();
 	RETURN(retval);
@@ -438,11 +448,21 @@ template<int func(int, int, int, u32, int)> void WrapI_IIIUI() {
 	RETURN(retval);
 }
 
+template<int func(int, int, int, u32, u32)> void WrapI_IIIUU() {
+	int retval = func(PARAM(0), PARAM(1), PARAM(2), PARAM(3), PARAM(4));
+	RETURN(retval);
+}
+
 template<int func(int, u32, u32, int, int)> void WrapI_IUUII() {
 	int retval = func(PARAM(0), PARAM(1), PARAM(2), PARAM(3), PARAM(4));
 	RETURN(retval);
 }
 
+template<int func(int, u32, u32, int, int, int)> void WrapI_IUUIII() {
+	int retval = func(PARAM(0), PARAM(1), PARAM(2), PARAM(3), PARAM(4), PARAM(5));
+	RETURN(retval);
+}
+
 template<int func(int, const char *, int, u32, u32)> void WrapI_ICIUU() {
 	int retval = func(PARAM(0), Memory::GetCharPointer(PARAM(1)), PARAM(2), PARAM(3), PARAM(4));
 	RETURN(retval);
@@ -483,16 +503,41 @@ template<int func(const char *, u32)> void WrapI_CU() {
 	RETURN(retval);
 }
 
+template<int func(int, const char*, u32)> void WrapI_ICU() {
+	int retval = func(PARAM(0), Memory::GetCharPointer(PARAM(1)), PARAM(2));
+	RETURN(retval);
+}
+
 template<int func(const char *, u32, int)> void WrapI_CUI() {
 	int retval = func(Memory::GetCharPointer(PARAM(0)), PARAM(1), PARAM(2));
 	RETURN(retval);
 }
 
+template<u32 func(const char *, u32, int)> void WrapU_CUI() {
+	u32 retval = func(Memory::GetCharPointer(PARAM(0)), PARAM(1), PARAM(2));
+	RETURN(retval);
+}
+
 template<int func(int, const char *, int, u32)> void WrapI_ICIU() {
 	int retval = func(PARAM(0), Memory::GetCharPointer(PARAM(1)), PARAM(2), PARAM(3));
 	RETURN(retval);
 }
 
+template<int func(int, const char *, u32, u32)> void WrapI_ICUU() {
+	int retval = func(PARAM(0), Memory::GetCharPointer(PARAM(1)), PARAM(2), PARAM(3));
+	RETURN(retval);
+}
+
+template<int func(int, const char *, u32, u32, u32)> void WrapI_ICUUU() {
+	int retval = func(PARAM(0), Memory::GetCharPointer(PARAM(1)), PARAM(2), PARAM(3), PARAM(4));
+	RETURN(retval);
+}
+
+template<int func(int, int, u32, u32)> void WrapI_IIUU() {
+	int retval = func(PARAM(0), PARAM(1), PARAM(2), PARAM(3));
+	RETURN(retval);
+}
+
 template<int func(const char *, int, u32)> void WrapI_CIU() {
 	int retval = func(Memory::GetCharPointer(PARAM(0)), PARAM(1), PARAM(2));
 	RETURN(retval);
@@ -699,6 +744,11 @@ template<int func(int, u32, u32, u32, u32, u32)> void WrapI_IUUUUU() {
 	RETURN(retval);
 }
 
+template<int func(int, u32, u32, int, u32, u32)> void WrapI_IUUIUU() {
+	int retval = func(PARAM(0), PARAM(1), PARAM(2), PARAM(3), PARAM(4), PARAM(5));
+	RETURN(retval);
+}
+
 template<int func(int, u32, int, int)> void WrapI_IUII() {
 	int retval = func(PARAM(0), PARAM(1), PARAM(2), PARAM(3));
 	RETURN(retval);
@@ -755,6 +805,21 @@ template<int func(int, u32, u32, u32)> void WrapI_IUUU() {
 	RETURN(retval);
 }
 
+template<int func(int, u32, u32, int)> void WrapI_IUUI() {
+	int retval = func(PARAM(0), PARAM(1), PARAM(2), PARAM(3));
+	RETURN(retval);
+}
+
+template<int func(int, u32, int, int, u32, u32)> void WrapI_IUIIUU() {
+	int retval = func(PARAM(0), PARAM(1), PARAM(2), PARAM(3), PARAM(4), PARAM(5));
+	RETURN(retval);
+}
+
+template<int func(int, u32, int, int, u32, int)> void WrapI_IUIIUI() {
+	int retval = func(PARAM(0), PARAM(1), PARAM(2), PARAM(3), PARAM(4), PARAM(5));
+	RETURN(retval);
+}
+
 template<int func(int, u32, u32)> void WrapI_IUU() {
 	int retval = func(PARAM(0), PARAM(1), PARAM(2));
 	RETURN(retval);
@@ -765,6 +830,11 @@ template<u32 func(u32, u32, u32, u32, u32, u32, u32)> void WrapU_UUUUUUU() {
   RETURN(retval);
 }
 
+template<int func(u32, u32, u32, u32, u32, u32, u32)> void WrapI_UUUUUUU() {
+	int retval = func(PARAM(0), PARAM(1), PARAM(2), PARAM(3), PARAM(4), PARAM(5), PARAM(6));
+	RETURN(retval);
+}
+
 template<int func(int, u32, u32, u32, u32, u32, u32)> void WrapI_IUUUUUU() {
 	int retval = func(PARAM(0), PARAM(1), PARAM(2), PARAM(3), PARAM(4), PARAM(5), PARAM(6));
 	RETURN(retval);
@@ -814,3 +884,33 @@ template<int func(void *, u32, int)> void WrapI_VUI(){
 	u32 retval = func(Memory::GetPointerWrite(PARAM(0)), PARAM(1), PARAM(2));
 	RETURN(retval);
 }
+
+template<u32 func(void *, u32, u32)> void WrapU_VUU() {
+	u32 retval = func(Memory::GetPointerWrite(PARAM(0)), PARAM(1), PARAM(2));
+	RETURN(retval);
+}
+
+template<u32 func(void *, const char *)> void WrapU_VC() {
+	u32 retval = func(Memory::GetPointerWrite(PARAM(0)), Memory::GetCharPointer(PARAM(1)));
+	RETURN(retval);
+}
+
+template<int func(const char *, const char*, u32)> void WrapI_CCU() {
+	int retval = func(Memory::GetCharPointer(PARAM(0)), Memory::GetCharPointer(PARAM(1)), PARAM(2));
+	RETURN(retval);
+}
+
+template<int func(const char *, const char*)> void WrapI_CC() {
+	int retval = func(Memory::GetCharPointer(PARAM(0)), Memory::GetCharPointer(PARAM(1)));
+	RETURN(retval);
+}
+
+template<u32 func(void *, const char *, u32)> void WrapU_VCU() {
+	u32 retval = func(Memory::GetPointerWrite(PARAM(0)), Memory::GetCharPointer(PARAM(1)), PARAM(2));
+	RETURN(retval);
+}
+
+template<u32 func(void *, int)> void WrapU_VI() {
+	u32 retval = func(Memory::GetPointerWrite(PARAM(0)), PARAM(1));
+	RETURN(retval);
+}
