@@ -21,6 +21,7 @@
 #include "Core/MIPS/MIPS.h"
 #include "Core/CoreTiming.h"
 #include "Core/HLE/HLE.h"
+#include "Core/HLE/ErrorCodes.h"
 #include "Core/HLE/FunctionWrappers.h"
 #include "Core/HLE/sceKernelThread.h"
 #include "Core/HLE/sceAudio.h"
@@ -39,7 +40,7 @@ int defaultRoutingVolMode = AUDIO_ROUTING_SPEAKER_ON;
 extern FixedSizeQueue<s16, 32768 * 8> chanSampleQueues[PSP_AUDIO_CHANNEL_MAX + 1];
 
 // The extra channel is for SRC/Output2/Vaudio.
-AudioChannel chans[PSP_AUDIO_CHANNEL_MAX + 1];
+AudioChannel g_audioChans[PSP_AUDIO_CHANNEL_MAX + 1];
 
 void AudioChannel::DoState(PointerWrap &p)
 {
@@ -86,120 +87,99 @@ void AudioChannel::clear()
 // max or 50%?
 static u32 sceAudioOutputBlocking(u32 chan, int vol, u32 samplePtr) {
 	if (vol > 0xFFFF) {
-		ERROR_LOG(Log::sceAudio, "sceAudioOutputBlocking() - invalid volume");
-		return SCE_ERROR_AUDIO_INVALID_VOLUME;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_VOLUME, "invalid volume");
 	} else if (chan >= PSP_AUDIO_CHANNEL_MAX) {
-		ERROR_LOG(Log::sceAudio, "sceAudioOutputBlocking() - bad channel");
-		return SCE_ERROR_AUDIO_INVALID_CHANNEL;
-	} else if (!chans[chan].reserved) {
-		ERROR_LOG(Log::sceAudio, "sceAudioOutputBlocking() - channel not reserved");
-		return SCE_ERROR_AUDIO_CHANNEL_NOT_INIT;
-	} else {
-		DEBUG_LOG(Log::sceAudio, "sceAudioOutputBlocking(%08x, %08x, %08x)", chan, vol, samplePtr);
-		if (vol >= 0) {
-			chans[chan].leftVolume = vol;
-			chans[chan].rightVolume = vol;
-		}
-		chans[chan].sampleAddress = samplePtr;
-		return __AudioEnqueue(chans[chan], chan, true);
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_CHANNEL, "bad channel");
+	} else if (!g_audioChans[chan].reserved) {
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_CHANNEL_NOT_INIT, "channel not reserved");
 	}
+
+	if (vol >= 0) {
+		g_audioChans[chan].leftVolume = vol;
+		g_audioChans[chan].rightVolume = vol;
+	}
+	g_audioChans[chan].sampleAddress = samplePtr;
+	return hleLogDebug(Log::sceAudio, __AudioEnqueue(g_audioChans[chan], chan, true));
 }
 
 static u32 sceAudioOutputPannedBlocking(u32 chan, int leftvol, int rightvol, u32 samplePtr) {
-	int result = 0;
 	// For some reason, this is the only one that checks for negative.
 	if (leftvol > 0xFFFF || rightvol > 0xFFFF || leftvol < 0 || rightvol < 0) {
-		ERROR_LOG(Log::sceAudio, "sceAudioOutputPannedBlocking() - invalid volume");
-		result = SCE_ERROR_AUDIO_INVALID_VOLUME;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_VOLUME, "invalid volume");
 	} else if (chan >= PSP_AUDIO_CHANNEL_MAX) {
-		ERROR_LOG(Log::sceAudio, "sceAudioOutputPannedBlocking() - bad channel");
-		result = SCE_ERROR_AUDIO_INVALID_CHANNEL;
-	} else if (!chans[chan].reserved) {
-		ERROR_LOG(Log::sceAudio, "sceAudioOutputPannedBlocking() - channel not reserved");
-		result = SCE_ERROR_AUDIO_CHANNEL_NOT_INIT;
-	} else {
-		if (leftvol >= 0) {
-			chans[chan].leftVolume = leftvol;
-		}
-		if (rightvol >= 0) {
-			chans[chan].rightVolume = rightvol;
-		}
-		chans[chan].sampleAddress = samplePtr;
-		result = __AudioEnqueue(chans[chan], chan, true);
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_CHANNEL, "bad channel");
+	} else if (!g_audioChans[chan].reserved) {
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_CHANNEL_NOT_INIT, "channel not reserved");
 	}
 
-	DEBUG_LOG(Log::sceAudio, "%08x = sceAudioOutputPannedBlocking(%08x, %08x, %08x, %08x)", result, chan, leftvol, rightvol, samplePtr);
-	return result;
-
+	if (leftvol >= 0) {
+		g_audioChans[chan].leftVolume = leftvol;
+	}
+	if (rightvol >= 0) {
+		g_audioChans[chan].rightVolume = rightvol;
+	}
+	g_audioChans[chan].sampleAddress = samplePtr;
+	u32 result = __AudioEnqueue(g_audioChans[chan], chan, true);
+	return hleLogDebug(Log::sceAudio, result);
 }
 
 static u32 sceAudioOutput(u32 chan, int vol, u32 samplePtr) {
 	if (vol > 0xFFFF) {
-		ERROR_LOG(Log::sceAudio, "sceAudioOutput() - invalid volume");
-		return SCE_ERROR_AUDIO_INVALID_VOLUME;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_VOLUME, "invalid volume");
 	} else if (chan >= PSP_AUDIO_CHANNEL_MAX) {
-		ERROR_LOG(Log::sceAudio, "sceAudioOutput() - bad channel");
-		return SCE_ERROR_AUDIO_INVALID_CHANNEL;
-	} else if (!chans[chan].reserved)	{
-		ERROR_LOG(Log::sceAudio, "sceAudioOutput(%08x, %08x, %08x) - channel not reserved", chan, vol, samplePtr);
-		return SCE_ERROR_AUDIO_CHANNEL_NOT_INIT;
-	} else {
-		DEBUG_LOG(Log::sceAudio, "sceAudioOutput(%08x, %08x, %08x)", chan, vol, samplePtr);
-		if (vol >= 0) {
-			chans[chan].leftVolume = vol;
-			chans[chan].rightVolume = vol;
-		}
-		chans[chan].sampleAddress = samplePtr;
-		return __AudioEnqueue(chans[chan], chan, false);
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_CHANNEL, "bad channel");
+	} else if (!g_audioChans[chan].reserved)	{
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_CHANNEL_NOT_INIT, "channel not reserved");
 	}
+
+	if (vol >= 0) {
+		g_audioChans[chan].leftVolume = vol;
+		g_audioChans[chan].rightVolume = vol;
+	}
+	g_audioChans[chan].sampleAddress = samplePtr;
+	u32 result = __AudioEnqueue(g_audioChans[chan], chan, false);
+	return hleLogDebug(Log::sceAudio, result);
 }
 
 static u32 sceAudioOutputPanned(u32 chan, int leftvol, int rightvol, u32 samplePtr) {
 	if (leftvol > 0xFFFF || rightvol > 0xFFFF) {
-		ERROR_LOG(Log::sceAudio, "sceAudioOutputPanned() - invalid volume");
-		return SCE_ERROR_AUDIO_INVALID_VOLUME;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_VOLUME, "invalid volume");
 	} else if (chan >= PSP_AUDIO_CHANNEL_MAX) {
-		ERROR_LOG(Log::sceAudio, "sceAudioOutputPanned() - bad channel");
-		return SCE_ERROR_AUDIO_INVALID_CHANNEL;
-	} else if (!chans[chan].reserved) {
-		ERROR_LOG(Log::sceAudio, "sceAudioOutputPanned(%08x, %08x, %08x, %08x) - channel not reserved", chan, leftvol, rightvol, samplePtr);
-		return SCE_ERROR_AUDIO_CHANNEL_NOT_INIT;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_CHANNEL, "bad channel");
+	} else if (!g_audioChans[chan].reserved) {
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_CHANNEL_NOT_INIT, "channel not reserved");
 	} else {
-		DEBUG_LOG(Log::sceAudio, "sceAudioOutputPanned(%08x, %08x, %08x, %08x)", chan, leftvol, rightvol, samplePtr);
 		if (leftvol >= 0) {
-			chans[chan].leftVolume = leftvol;
+			g_audioChans[chan].leftVolume = leftvol;
 		}
 		if (rightvol >= 0) {
-			chans[chan].rightVolume = rightvol;
+			g_audioChans[chan].rightVolume = rightvol;
 		}
-		chans[chan].sampleAddress = samplePtr;
-		return __AudioEnqueue(chans[chan], chan, false);
+		g_audioChans[chan].sampleAddress = samplePtr;
+		u32 result = __AudioEnqueue(g_audioChans[chan], chan, false);
+		return hleLogDebug(Log::sceAudio, result);
 	}
 }
 
 static int sceAudioGetChannelRestLen(u32 chan) {
 	if (chan >= PSP_AUDIO_CHANNEL_MAX) {
-		ERROR_LOG(Log::sceAudio, "sceAudioGetChannelRestLen(%08x) - bad channel", chan);
-		return SCE_ERROR_AUDIO_INVALID_CHANNEL;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_CHANNEL, "bad channel");
 	}
 	int remainingSamples = (int)chanSampleQueues[chan].size() / 2;
-	VERBOSE_LOG(Log::sceAudio, "%d=sceAudioGetChannelRestLen(%08x)", remainingSamples, chan);
-	return remainingSamples;
+	return hleLogVerbose(Log::sceAudio, remainingSamples);
 }
 
 static int sceAudioGetChannelRestLength(u32 chan) {
 	if (chan >= PSP_AUDIO_CHANNEL_MAX) {
-		ERROR_LOG(Log::sceAudio, "sceAudioGetChannelRestLength(%08x) - bad channel", chan);
-		return SCE_ERROR_AUDIO_INVALID_CHANNEL;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_CHANNEL, "bad channel");
 	}
 	int remainingSamples = (int)chanSampleQueues[chan].size() / 2;
-	VERBOSE_LOG(Log::sceAudio, "%d=sceAudioGetChannelRestLength(%08x)", remainingSamples, chan);
-	return remainingSamples;
+	return hleLogVerbose(Log::sceAudio, remainingSamples);
 }
 
 static u32 GetFreeChannel() {
 	for (u32 i = PSP_AUDIO_CHANNEL_MAX - 1; i > 0; --i) {
-		if (!chans[i].reserved)
+		if (!g_audioChans[i].reserved)
 			return i;
 	}
 	return -1;
@@ -209,116 +189,93 @@ static u32 sceAudioChReserve(int chan, u32 sampleCount, u32 format) {
 	if (chan < 0) {
 		chan = GetFreeChannel();
 		if (chan < 0) {
-			ERROR_LOG(Log::sceAudio, "sceAudioChReserve - no channels remaining");
-			return SCE_ERROR_AUDIO_NO_CHANNELS_AVAILABLE;
+			return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_NO_CHANNELS_AVAILABLE, "no channels remaining");
 		}
 	}
 	if ((u32)chan >= PSP_AUDIO_CHANNEL_MAX)	{
-		ERROR_LOG(Log::sceAudio, "sceAudioChReserve(%08x, %08x, %08x) - bad channel", chan, sampleCount, format);
-		return SCE_ERROR_AUDIO_INVALID_CHANNEL;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_CHANNEL, "bad channel %d", chan);
 	}
 	if ((sampleCount & 63) != 0 || sampleCount == 0 || sampleCount > PSP_AUDIO_SAMPLE_MAX) {
-		ERROR_LOG(Log::sceAudio, "sceAudioChReserve(%08x, %08x, %08x) - invalid sample count", chan, sampleCount, format);
-		return SCE_ERROR_AUDIO_OUTPUT_SAMPLE_DATA_SIZE_NOT_ALIGNED;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_OUTPUT_SAMPLE_DATA_SIZE_NOT_ALIGNED, "invalid sample count (not aligned)");
 	}
 	if (format != PSP_AUDIO_FORMAT_MONO && format != PSP_AUDIO_FORMAT_STEREO) {
-		ERROR_LOG(Log::sceAudio, "sceAudioChReserve(%08x, %08x, %08x) - invalid format", chan, sampleCount, format);
-		return SCE_ERROR_AUDIO_INVALID_FORMAT;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_FORMAT, "invalid format");
 	}
-	if (chans[chan].reserved) {
-		ERROR_LOG(Log::sceAudio, "sceAudioChReserve - reserve channel failed");
-		return SCE_ERROR_AUDIO_INVALID_CHANNEL;
+	if (g_audioChans[chan].reserved) {
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_CHANNEL, "reserve channel failed");
 	}
 
-	DEBUG_LOG(Log::sceAudio, "sceAudioChReserve(%08x, %08x, %08x)", chan, sampleCount, format);
-	chans[chan].sampleCount = sampleCount;
-	chans[chan].format = format;
-	chans[chan].reserved = true;
-	chans[chan].leftVolume = 0;
-	chans[chan].rightVolume = 0;
-	return chan;
+	g_audioChans[chan].sampleCount = sampleCount;
+	g_audioChans[chan].format = format;
+	g_audioChans[chan].reserved = true;
+	g_audioChans[chan].leftVolume = 0;
+	g_audioChans[chan].rightVolume = 0;
+	return hleLogDebug(Log::sceAudio, chan);
 }
 
 static u32 sceAudioChRelease(u32 chan) {
 	if (chan >= PSP_AUDIO_CHANNEL_MAX) {
-		ERROR_LOG(Log::sceAudio, "sceAudioChRelease(%i) - bad channel", chan);
-		return SCE_ERROR_AUDIO_INVALID_CHANNEL;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_CHANNEL, "bad channel %d", chan);
+	} else if (!g_audioChans[chan].reserved) {
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_CHANNEL_NOT_INIT, "channel %d not reserved", chan);
 	}
 
-	if (!chans[chan].reserved) {
-		ERROR_LOG(Log::sceAudio, "sceAudioChRelease(%i) - channel not reserved", chan);
-		return SCE_ERROR_AUDIO_CHANNEL_NOT_RESERVED;
-	}
 	// TODO: Does this error if busy?
-	chans[chan].reset();
-	chans[chan].reserved = false;
-	return hleLogSuccessI(Log::sceAudio, 0);
+	g_audioChans[chan].reset();
+	g_audioChans[chan].reserved = false;
+	return hleLogDebug(Log::sceAudio, 0);
 }
 
 static u32 sceAudioSetChannelDataLen(u32 chan, u32 len) {
-	int result = 0;
 	if (chan >= PSP_AUDIO_CHANNEL_MAX) {
-		ERROR_LOG(Log::sceAudio, "sceAudioSetChannelDataLen(%08x, %08x) - bad channel", chan, len);
-		result = SCE_ERROR_AUDIO_INVALID_CHANNEL;
-	} else if (!chans[chan].reserved)	{
-		ERROR_LOG(Log::sceAudio, "sceAudioSetChannelDataLen(%08x, %08x) - channel not reserved", chan, len);
-		result = SCE_ERROR_AUDIO_CHANNEL_NOT_INIT;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_CHANNEL, "bad channel %d", chan);
+	} else if (!g_audioChans[chan].reserved)	{
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_CHANNEL_NOT_INIT, "channel %d not reserved", chan);
 	} else if ((len & 63) != 0 || len == 0 || len > PSP_AUDIO_SAMPLE_MAX) {
-		ERROR_LOG(Log::sceAudio, "sceAudioSetChannelDataLen(%08x, %08x) - invalid sample count", chan, len);
-		result = SCE_ERROR_AUDIO_OUTPUT_SAMPLE_DATA_SIZE_NOT_ALIGNED;
-	} else {
-		chans[chan].sampleCount = len;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_OUTPUT_SAMPLE_DATA_SIZE_NOT_ALIGNED, "invalid sample count");
 	}
-	DEBUG_LOG(Log::sceAudio, "%08x = sceAudioSetChannelDataLen(%08x, %08x)", result , chan, len);
-	return result;
+	
+	g_audioChans[chan].sampleCount = len;
+	return hleLogDebug(Log::sceAudio, 0);
 }
 
 static u32 sceAudioChangeChannelConfig(u32 chan, u32 format) {
 	if (chan >= PSP_AUDIO_CHANNEL_MAX) {
-		ERROR_LOG(Log::sceAudio, "sceAudioChangeChannelConfig(%08x, %08x) - invalid channel number", chan, format);
-		return SCE_ERROR_AUDIO_INVALID_CHANNEL;
-	} else if (!chans[chan].reserved) {
-		ERROR_LOG(Log::sceAudio, "sceAudioChangeChannelConfig(%08x, %08x) - channel not reserved", chan, format);
-		return SCE_ERROR_AUDIO_CHANNEL_NOT_RESERVED;
-	} else {
-		DEBUG_LOG(Log::sceAudio, "sceAudioChangeChannelConfig(%08x, %08x)", chan, format);
-		chans[chan].format = format;
-		return 0;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_CHANNEL, "invalid channel number %d", chan);
+	} else if (!g_audioChans[chan].reserved) {
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_CHANNEL_NOT_RESERVED, "channel %d not reserved", chan);
 	}
+
+	g_audioChans[chan].format = format;
+	return hleLogDebug(Log::sceAudio, 0);
 }
 
 static u32 sceAudioChangeChannelVolume(u32 chan, u32 leftvol, u32 rightvol) {
 	if (leftvol > 0xFFFF || rightvol > 0xFFFF) {
-		ERROR_LOG(Log::sceAudio, "sceAudioChangeChannelVolume(%08x, %08x, %08x) - invalid volume", chan, leftvol, rightvol);
-		return SCE_ERROR_AUDIO_INVALID_VOLUME;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_VOLUME, "invalid chan %d volume %d %d", chan, leftvol, rightvol);
 	} else if (chan >= PSP_AUDIO_CHANNEL_MAX) {
-		ERROR_LOG(Log::sceAudio, "sceAudioChangeChannelVolume(%08x, %08x, %08x) - invalid channel number", chan, leftvol, rightvol);
-		return SCE_ERROR_AUDIO_INVALID_CHANNEL;
-	} else if (!chans[chan].reserved)	{
-		ERROR_LOG(Log::sceAudio, "sceAudioChangeChannelVolume(%08x, %08x, %08x) - channel not reserved", chan, leftvol, rightvol);
-		return SCE_ERROR_AUDIO_CHANNEL_NOT_RESERVED;
-	} else {
-		DEBUG_LOG(Log::sceAudio, "sceAudioChangeChannelVolume(%08x, %08x, %08x)", chan, leftvol, rightvol);
-		chans[chan].leftVolume = leftvol;
-		chans[chan].rightVolume = rightvol;
-		return 0;
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_CHANNEL, "invalid channel %d", chan);
+	} else if (!g_audioChans[chan].reserved)	{
+		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_CHANNEL_NOT_RESERVED, "channel %d not reserved", chan);
 	}
+
+	g_audioChans[chan].leftVolume = leftvol;
+	g_audioChans[chan].rightVolume = rightvol;
+	return hleLogDebug(Log::sceAudio, 0);
 }
 
 static u32 sceAudioInit() {
-	DEBUG_LOG(Log::sceAudio, "sceAudioInit()");
 	// Don't need to do anything
-	return 0;
+	return hleLogDebug(Log::sceAudio, 0);
 }
 
 static u32 sceAudioEnd() {
-	DEBUG_LOG(Log::sceAudio, "sceAudioEnd()");
 	// Don't need to do anything
-	return 0;
+	return hleLogDebug(Log::sceAudio, 0);
 }
 
 static u32 sceAudioOutput2Reserve(u32 sampleCount) {
-	auto &chan = chans[PSP_AUDIO_CHANNEL_OUTPUT2];
+	auto &chan = g_audioChans[PSP_AUDIO_CHANNEL_OUTPUT2];
 	// This seems to ignore the MSB, for some reason.
 	sampleCount &= 0x7FFFFFFF;
 	if (sampleCount < 17 || sampleCount > 4111) {
@@ -331,7 +288,7 @@ static u32 sceAudioOutput2Reserve(u32 sampleCount) {
 	chan.format = PSP_AUDIO_FORMAT_STEREO;
 	chan.reserved = true;
 	__AudioSetSRCFrequency(0);
-	return hleLogSuccessI(Log::sceAudio, 0);
+	return hleLogDebug(Log::sceAudio, 0);
 }
 
 static u32 sceAudioOutput2OutputBlocking(u32 vol, u32 dataPtr) {
@@ -340,7 +297,7 @@ static u32 sceAudioOutput2OutputBlocking(u32 vol, u32 dataPtr) {
 		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_VOLUME, "invalid volume");
 	}
 
-	auto &chan = chans[PSP_AUDIO_CHANNEL_OUTPUT2];
+	auto &chan = g_audioChans[PSP_AUDIO_CHANNEL_OUTPUT2];
 	if (!chan.reserved) {
 		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_CHANNEL_NOT_RESERVED, "channel not reserved");
 	}
@@ -353,20 +310,20 @@ static u32 sceAudioOutput2OutputBlocking(u32 vol, u32 dataPtr) {
 	int result = __AudioEnqueue(chan, PSP_AUDIO_CHANNEL_OUTPUT2, true);
 	if (result < 0)
 		return hleLogError(Log::sceAudio, result);
-	return hleLogSuccessI(Log::sceAudio, result);
+	return hleLogDebug(Log::sceAudio, result);
 }
 
 static u32 sceAudioOutput2ChangeLength(u32 sampleCount) {
-	auto &chan = chans[PSP_AUDIO_CHANNEL_OUTPUT2];
+	auto &chan = g_audioChans[PSP_AUDIO_CHANNEL_OUTPUT2];
 	if (!chan.reserved) {
 		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_CHANNEL_NOT_RESERVED, "channel not reserved");
 	}
 	chan.sampleCount = sampleCount;
-	return hleLogSuccessI(Log::sceAudio, 0);
+	return hleLogDebug(Log::sceAudio, 0);
 }
 
 static u32 sceAudioOutput2GetRestSample() {
-	auto &chan = chans[PSP_AUDIO_CHANNEL_OUTPUT2];
+	auto &chan = g_audioChans[PSP_AUDIO_CHANNEL_OUTPUT2];
 	if (!chan.reserved) {
 		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_CHANNEL_NOT_RESERVED, "channel not reserved");
 	}
@@ -375,11 +332,11 @@ static u32 sceAudioOutput2GetRestSample() {
 		// If ChangeLength reduces the size, it still gets output but this return is clamped.
 		size = chan.sampleCount;
 	}
-	return hleLogSuccessI(Log::sceAudio, size);
+	return hleLogDebug(Log::sceAudio, size);
 }
 
 static u32 sceAudioOutput2Release() {
-	auto &chan = chans[PSP_AUDIO_CHANNEL_OUTPUT2];
+	auto &chan = g_audioChans[PSP_AUDIO_CHANNEL_OUTPUT2];
 	if (!chan.reserved)
 		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_CHANNEL_NOT_RESERVED, "channel not reserved");
 	if (!chanSampleQueues[PSP_AUDIO_CHANNEL_OUTPUT2].empty())
@@ -387,7 +344,7 @@ static u32 sceAudioOutput2Release() {
 
 	chan.reset();
 	chan.reserved = false;
-	return hleLogSuccessI(Log::sceAudio, 0);
+	return hleLogDebug(Log::sceAudio, 0);
 }
 
 static u32 sceAudioSetFrequency(u32 freq) {
@@ -416,7 +373,7 @@ static bool SRCFrequencyAllowed(int freq) {
 }
 
 static u32 sceAudioSRCChReserve(u32 sampleCount, u32 freq, u32 format) {
-	auto &chan = chans[PSP_AUDIO_CHANNEL_SRC];
+	auto &chan = g_audioChans[PSP_AUDIO_CHANNEL_SRC];
 	// This seems to ignore the MSB, for some reason.
 	sampleCount &= 0x7FFFFFFF;
 	if (format == 4) {
@@ -436,11 +393,11 @@ static u32 sceAudioSRCChReserve(u32 sampleCount, u32 freq, u32 format) {
 	chan.format = format == 2 ? PSP_AUDIO_FORMAT_STEREO : PSP_AUDIO_FORMAT_MONO;
 	// Zero means default to 44.1kHz.
 	__AudioSetSRCFrequency(freq);
-	return hleLogSuccessI(Log::sceAudio, 0);
+	return hleLogDebug(Log::sceAudio, 0);
 }
 
 static u32 sceAudioSRCChRelease() {
-	auto &chan = chans[PSP_AUDIO_CHANNEL_SRC];
+	auto &chan = g_audioChans[PSP_AUDIO_CHANNEL_SRC];
 	if (!chan.reserved)
 		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_CHANNEL_NOT_RESERVED, "channel not reserved");
 	if (!chanSampleQueues[PSP_AUDIO_CHANNEL_SRC].empty())
@@ -448,7 +405,7 @@ static u32 sceAudioSRCChRelease() {
 
 	chan.reset();
 	chan.reserved = false;
-	return hleLogSuccessI(Log::sceAudio, 0);
+	return hleLogDebug(Log::sceAudio, 0);
 }
 
 static u32 sceAudioSRCOutputBlocking(u32 vol, u32 buf) {
@@ -456,7 +413,7 @@ static u32 sceAudioSRCOutputBlocking(u32 vol, u32 buf) {
 		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_INVALID_VOLUME, "invalid volume");
 	}
 
-	auto &chan = chans[PSP_AUDIO_CHANNEL_SRC];
+	auto &chan = g_audioChans[PSP_AUDIO_CHANNEL_SRC];
 	if (!chan.reserved) {
 		return hleLogError(Log::sceAudio, SCE_ERROR_AUDIO_CHANNEL_NOT_RESERVED, "channel not reserved");
 	}
@@ -469,23 +426,19 @@ static u32 sceAudioSRCOutputBlocking(u32 vol, u32 buf) {
 	int result = __AudioEnqueue(chan, PSP_AUDIO_CHANNEL_SRC, true);
 	if (result < 0)
 		return hleLogError(Log::sceAudio, result);
-	return hleLogSuccessI(Log::sceAudio, result);
+	return hleLogDebug(Log::sceAudio, result);
 }
 
 static int sceAudioInputBlocking(u32 maxSamples, u32 sampleRate, u32 bufAddr) {
 	if (!Memory::IsValidAddress(bufAddr)) {
-		ERROR_LOG(Log::HLE, "sceAudioInputBlocking(%d, %d, %08x): invalid addresses", maxSamples, sampleRate, bufAddr);
-		return -1;
+		return hleLogError(Log::HLE, -1, "invalid address");
 	}
-
-	INFO_LOG(Log::HLE, "sceAudioInputBlocking: maxSamples: %d, samplerate: %d, bufAddr: %08x", maxSamples, sampleRate, bufAddr);
-	return __MicInput(maxSamples, sampleRate, bufAddr, AUDIOINPUT);
+	return hleLogInfo(Log::HLE, __MicInput(maxSamples, sampleRate, bufAddr, AUDIOINPUT));
 }
 
 static int sceAudioInput(u32 maxSamples, u32 sampleRate, u32 bufAddr) {
 	if (!Memory::IsValidAddress(bufAddr)) {
-		ERROR_LOG(Log::HLE, "sceAudioInput(%d, %d, %08x): invalid addresses", maxSamples, sampleRate, bufAddr);
-		return -1;
+		return hleLogError(Log::HLE, -1, "invalid address");
 	}
 
 	ERROR_LOG(Log::HLE, "UNTEST sceAudioInput: maxSamples: %d, samplerate: %d, bufAddr: %08x", maxSamples, sampleRate, bufAddr);
@@ -596,5 +549,5 @@ const HLEFunction sceAudio[] =
 
 void Register_sceAudio()
 {
-	RegisterModule("sceAudio", ARRAY_SIZE(sceAudio), sceAudio);
+	RegisterHLEModule("sceAudio", ARRAY_SIZE(sceAudio), sceAudio);
 }
