@@ -661,9 +661,6 @@ void ImportFuncSymbol(const FuncSymbolImport &func, bool reimporting, const char
 		// TODO: There's some double lookup going on here (we already did the lookup in GetHLEFunc above).
 		WriteHLESyscall(func.moduleName, func.nid, func.stubAddr);
 		currentMIPS->InvalidateICache(func.stubAddr, 8);
-		if (g_Config.bPreloadFunctions) {
-			MIPSAnalyst::PrecompileFunction(func.stubAddr, 8);
-		}
 		return;
 	}
 
@@ -682,9 +679,6 @@ void ImportFuncSymbol(const FuncSymbolImport &func, bool reimporting, const char
 				}
 				WriteFuncStub(func.stubAddr, it->symAddr);
 				currentMIPS->InvalidateICache(func.stubAddr, 8);
-				if (g_Config.bPreloadFunctions) {
-					MIPSAnalyst::PrecompileFunction(func.stubAddr, 8);
-				}
 				return;
 			}
 		}
@@ -725,9 +719,6 @@ void ExportFuncSymbol(const FuncSymbolExport &func) {
 				INFO_LOG(Log::Loader, "Resolving function %s/%08x", func.moduleName, func.nid);
 				WriteFuncStub(it->stubAddr, func.symAddr);
 				currentMIPS->InvalidateICache(it->stubAddr, 8);
-				if (g_Config.bPreloadFunctions) {
-					MIPSAnalyst::PrecompileFunction(it->stubAddr, 8);
-				}
 			}
 		}
 	}
@@ -1253,6 +1244,13 @@ static PSPModule *__KernelLoadELFFromPtr(const u8 *ptr, size_t elfSize, u32 load
 
 	modinfo = (const PspModuleInfo *)Memory::GetPointerUnchecked(modinfoaddr);
 
+	// OK, even if it's an ELF module, it might be one we shouldn't fully load and execute!
+	// This is seen with mpeg.prx in Tony Hawk's Underground 2, see #20568.
+	if (ShouldHLEModule(modinfo->name)) {
+		// We load it, but at least we don't run any part of it.
+		module->isFake = true;
+	}
+
 	module->nm.nsegment = reader.GetNumSegments();
 	module->nm.attribute = modinfo->moduleAttrs;
 	module->nm.version[0] = modinfo->moduleVersion & 0xFF;
@@ -1323,10 +1321,10 @@ static PSPModule *__KernelLoadELFFromPtr(const u8 *ptr, size_t elfSize, u32 load
 		bool insertSymbols = scan && !reader.LoadSymbols();
 		std::vector<SectionID> codeSections = reader.GetCodeSections();
 		for (SectionID id : codeSections) {
-			u32 start = reader.GetSectionAddr(id);
+			const u32 start = reader.GetSectionAddr(id);
 			// Note: scan end is inclusive.
-			u32 end = start + reader.GetSectionSize(id) - 4;
-			u32 len = end + 4 - start;
+			const u32 end = start + reader.GetSectionSize(id) - 4;
+			const u32 len = end + 4 - start;
 			if (len == 0) {
 				// Seen in WWE: Smackdown vs Raw 2009. See #17435.
 				continue;
@@ -1368,6 +1366,8 @@ static PSPModule *__KernelLoadELFFromPtr(const u8 *ptr, size_t elfSize, u32 load
 		}
 
 		if (scan) {
+			// TODO: Limit this to the newly loaded range! This is expensive, well, at least in debug builds
+			// and the cause of stutter during Wipeout Pure initialization.
 			MIPSAnalyst::FinalizeScan(insertSymbols);
 		}
 	}
@@ -1405,7 +1405,7 @@ static PSPModule *__KernelLoadELFFromPtr(const u8 *ptr, size_t elfSize, u32 load
 			continue;
 		}
 
-		u32 variableCount = ent->size <= 4 ? ent->vcount : std::max((u32)ent->vcount , (u32)ent->vcountNew);
+		const u32 variableCount = ent->size <= 4 ? ent->vcount : std::max((u32)ent->vcount , (u32)ent->vcountNew);
 		const char *name;
 		if (Memory::IsValidAddress(ent->name)) {
 			name = Memory::GetCharPointer(ent->name);
@@ -1436,8 +1436,13 @@ static PSPModule *__KernelLoadELFFromPtr(const u8 *ptr, size_t elfSize, u32 load
 		func.moduleName[KERNELOBJECT_MAX_NAME_LENGTH] = '\0';
 
 		for (u32 j = 0; j < ent->fcount; j++) {
-			u32 nid = residentPtr[j];
-			u32 exportAddr = exportPtr[j];
+			const u32 nid = residentPtr[j];
+			const u32 exportAddr = exportPtr[j];
+
+			if (exportAddr & 3) {
+				ERROR_LOG(Log::Loader, "Bad fn export address %08x", exportAddr);
+				// We should probably reject it, but risky.
+			}
 
 			switch (nid) {
 			case NID_MODULE_START:
@@ -1470,13 +1475,8 @@ static PSPModule *__KernelLoadELFFromPtr(const u8 *ptr, size_t elfSize, u32 load
 		var.moduleName[KERNELOBJECT_MAX_NAME_LENGTH] = '\0';
 
 		for (u32 j = 0; j < variableCount; j++) {
-			u32 nid = residentPtr[ent->fcount + j];
-			u32 exportAddr = exportPtr[ent->fcount + j];
-
-			if (exportAddr & 3) {
-				ERROR_LOG(Log::Loader, "Bad export address %08x", exportAddr);
-				continue;
-			}
+			const u32 nid = residentPtr[ent->fcount + j];
+			const u32 exportAddr = exportPtr[ent->fcount + j];  // These can be unaligned (small varables or char arrays).
 
 			int size;
 			switch (nid) {
@@ -1543,8 +1543,6 @@ static PSPModule *__KernelLoadELFFromPtr(const u8 *ptr, size_t elfSize, u32 load
 		// use module_start_func instead of entry_addr if entry_addr is 0
 		if (module->nm.entry_addr == 0)
 			module->nm.entry_addr = module->nm.module_start_func;
-
-		MIPSAnalyst::PrecompileFunctions();
 	} else {
 		module->nm.entry_addr = -1;
 	}
@@ -2083,7 +2081,7 @@ static u32 sceKernelStartModule(u32 moduleId, u32 argsize, u32 argAddr, u32 retu
 			module->nm.status = MODULE_STATUS_STARTING;
 			module->waitingThreads.push_back(mwt);
 		}
-		return hleLogInfo(Log::sceModule, ret);
+		return hleLogInfo(Log::sceModule, ret, "'%.*s'", (int)sizeof(module->nm.name), module->nm.name);
 	}
 }
 
