@@ -29,6 +29,7 @@
 #include "Common/Serialize/SerializeFuncs.h"
 #include "Common/TimeUtil.h"
 #include "Core/HLE/HLE.h"
+#include "Core/HLE/ErrorCodes.h"
 #include "Core/HLE/FunctionWrappers.h"
 #include "Core/MIPS/MIPS.h"
 #include "Core/Reporting.h"
@@ -76,24 +77,16 @@ const int PSP_TIME_INVALID_MINUTES = -5;
 const int PSP_TIME_INVALID_SECONDS = -6;
 const int PSP_TIME_INVALID_MICROSECONDS = -7;
 
-static u64 __RtcGetCurrentTick()
+u64 __RtcGetCurrentTick()
 {
 	// TODO: It's probably expecting ticks since January 1, 0001?
 	return CoreTiming::GetGlobalTimeUs() + rtcBaseTicks;
 }
 
-#if defined(__MINGW32__)
+#if defined(__MINGW32__) && !defined(_UCRT)
 errno_t _get_timezone(long *seconds)
 {
-  time_t now = time(NULL);
-
-  struct tm *gm = gmtime(&now);
-  time_t gmt = mktime(gm);
-
-  struct tm *loc = localtime(&now);
-  time_t local = mktime(loc);
-
-  *seconds = local - gmt;
+  *seconds = _timezone;
   return 0;
 }
 #endif
@@ -279,8 +272,7 @@ static bool __RtcValidatePspTime(const ScePspDateTime &t)
 
 static u32 sceRtcGetTickResolution()
 {
-	DEBUG_LOG(Log::sceRtc, "sceRtcGetTickResolution()");
-	return 1000000;
+	return hleLogDebug(Log::sceRtc, 1000000);
 }
 
 static u32 sceRtcGetCurrentTick(u32 tickPtr)
@@ -292,7 +284,7 @@ static u32 sceRtcGetCurrentTick(u32 tickPtr)
 		Memory::Write_U64(curTick, tickPtr);
 	hleEatCycles(300);
 	hleReSchedule("rtc current tick");
-	return 0;
+	return hleNoLog(0);
 }
 
 static u64 sceRtcGetAccumulativeTime()
@@ -300,7 +292,7 @@ static u64 sceRtcGetAccumulativeTime()
 	DEBUG_LOG(Log::sceRtc, "sceRtcGetAccumulativeTime()");
 	hleEatCycles(300);
 	hleReSchedule("rtc accumulative time");
-	return __RtcGetCurrentTick();
+	return hleNoLog(__RtcGetCurrentTick());
 }
 
 static u32 sceRtcGetCurrentClock(u32 pspTimePtr, int tz) {
@@ -326,7 +318,7 @@ static u32 sceRtcGetCurrentClock(u32 pspTimePtr, int tz) {
 
 	hleEatCycles(1900);
 	hleReSchedule("rtc current clock");
-	return hleLogSuccessI(Log::sceRtc, 0);
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static u32 sceRtcGetCurrentClockLocalTime(u32 pspTimePtr) {
@@ -348,7 +340,7 @@ static u32 sceRtcGetCurrentClockLocalTime(u32 pspTimePtr) {
 
 	hleEatCycles(2000);
 	hleReSchedule("rtc current clock local");
-	return hleLogSuccessI(Log::sceRtc, 0);
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static u32 sceRtcSetTick(u32 pspTimePtr, u32 tickPtr) {
@@ -359,7 +351,7 @@ static u32 sceRtcSetTick(u32 pspTimePtr, u32 tickPtr) {
 		return hleLogError(Log::sceRtc, 0, "bad address");
 
 	__RtcTicksToPspTime(*pt, *tick);
-	return hleLogSuccessI(Log::sceRtc, 0);
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static u32 sceRtcGetTick(u32 pspTimePtr, u32 tickPtr) {
@@ -372,7 +364,7 @@ static u32 sceRtcGetTick(u32 pspTimePtr, u32 tickPtr) {
 		return hleLogWarning(Log::sceRtc, SCE_KERNEL_ERROR_INVALID_VALUE, "invalid time");
 
 	*tick = __RtcPspTimeToTicks(*pt);
-	return hleLogSuccessI(Log::sceRtc, 0);
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static u32 sceRtcGetDayOfWeek(u32 year, u32 month, u32 day)
@@ -513,7 +505,7 @@ static int sceRtcCheckValid(u32 datePtr) {
 		result = PSP_TIME_INVALID_SECONDS;
 	else if (pt->microsecond >= 1000000UL)
 		result = PSP_TIME_INVALID_MICROSECONDS;
-	return hleLogSuccessI(Log::sceRtc, result);
+	return hleLogDebug(Log::sceRtc, result);
 }
 
 static int sceRtcSetTime_t(u32 datePtr, u32 time) {
@@ -522,7 +514,7 @@ static int sceRtcSetTime_t(u32 datePtr, u32 time) {
 		return hleLogError(Log::sceRtc, 1, "bad address");
 
 	__RtcTicksToPspTime(*pt, time * 1000000ULL + rtcMagicOffset);
-	return hleLogSuccessI(Log::sceRtc, 0);
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static int sceRtcSetTime64_t(u32 datePtr, u64 time) {
@@ -531,7 +523,7 @@ static int sceRtcSetTime64_t(u32 datePtr, u64 time) {
 		return hleLogError(Log::sceRtc, 1, "bad address");
 
 	__RtcTicksToPspTime(*pt, time * 1000000ULL + rtcMagicOffset);
-	return hleLogSuccessI(Log::sceRtc, 0);
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static int sceRtcGetTime_t(u32 datePtr, u32 timePtr) {
@@ -541,7 +533,7 @@ static int sceRtcGetTime_t(u32 datePtr, u32 timePtr) {
 		return hleLogError(Log::sceRtc, 1, "bad address");
 
 	*timep = (u32)((__RtcPspTimeToTicks(*pt) - rtcMagicOffset) / 1000000ULL);
-	return hleLogSuccessI(Log::sceRtc, 0);
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static int sceRtcGetTime64_t(u32 datePtr, u32 timePtr) {
@@ -551,7 +543,7 @@ static int sceRtcGetTime64_t(u32 datePtr, u32 timePtr) {
 		return hleLogError(Log::sceRtc, 1, "bad address");
 
 	*timep = (__RtcPspTimeToTicks(*pt) - rtcMagicOffset) / 1000000ULL;
-	return hleLogSuccessI(Log::sceRtc, 0);
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static int sceRtcSetDosTime(u32 datePtr, u32 dosTime) {
@@ -570,7 +562,7 @@ static int sceRtcSetDosTime(u32 datePtr, u32 dosTime) {
 	pt->second = (hms << 1) & 0x3E;
 	pt->microsecond = 0;
 
-	return hleLogSuccessI(Log::sceRtc, 0);
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static int sceRtcGetDosTime(u32 datePtr, u32 dosTime) {
@@ -597,7 +589,7 @@ static int sceRtcGetDosTime(u32 datePtr, u32 dosTime) {
 	int hms = hour | minute | second;
 
 	*dosp = (ymd << 16) | hms;
-	return hleLogSuccessI(Log::sceRtc, 0);
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static int sceRtcSetWin32FileTime(u32 datePtr, u64 win32Time)
@@ -649,11 +641,11 @@ static int sceRtcCompareTick(u32 tick1Ptr, u32 tick2Ptr)
 		u64 tick1 = Memory::Read_U64(tick1Ptr);
 		u64 tick2 = Memory::Read_U64(tick2Ptr);
 		if (tick1 > tick2)
-			return 1;
+			return hleNoLog(1);
 		if (tick1 < tick2)
-			return -1;
+			return hleNoLog(-1);
 	}
-	return 0;
+	return hleNoLog(0);
 }
 
 static int sceRtcTickAddTicks(u32 destTickPtr, u32 srcTickPtr, u64 numTicks)
@@ -665,9 +657,7 @@ static int sceRtcTickAddTicks(u32 destTickPtr, u32 srcTickPtr, u64 numTicks)
 		srcTick += numTicks;
 		Memory::Write_U64(srcTick, destTickPtr);
 	}
-
-	DEBUG_LOG(Log::sceRtc, "sceRtcTickAddTicks(%x,%x,%llu)", destTickPtr, srcTickPtr, numTicks);
-	return 0;
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static int sceRtcTickAddMicroseconds(u32 destTickPtr,u32 srcTickPtr, u64 numMS)
@@ -679,9 +669,7 @@ static int sceRtcTickAddMicroseconds(u32 destTickPtr,u32 srcTickPtr, u64 numMS)
 		srcTick += numMS;
 		Memory::Write_U64(srcTick, destTickPtr);
 	}
-
-	DEBUG_LOG(Log::sceRtc, "sceRtcTickAddMicroseconds(%x,%x,%llu)", destTickPtr, srcTickPtr, numMS);
-	return 0;
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static int sceRtcTickAddSeconds(u32 destTickPtr, u32 srcTickPtr, u64 numSecs)
@@ -693,8 +681,7 @@ static int sceRtcTickAddSeconds(u32 destTickPtr, u32 srcTickPtr, u64 numSecs)
 		srcTick += numSecs * 1000000UL;
 		Memory::Write_U64(srcTick, destTickPtr);
 	}
-	DEBUG_LOG(Log::sceRtc, "sceRtcTickAddSeconds(%x,%x,%llu)", destTickPtr, srcTickPtr, numSecs);
-	return 0;
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static int sceRtcTickAddMinutes(u32 destTickPtr, u32 srcTickPtr, u64 numMins)
@@ -706,8 +693,7 @@ static int sceRtcTickAddMinutes(u32 destTickPtr, u32 srcTickPtr, u64 numMins)
 		srcTick += numMins*60000000UL;
 		Memory::Write_U64(srcTick, destTickPtr);
 	}
-	DEBUG_LOG(Log::sceRtc, "sceRtcTickAddMinutes(%x,%x,%llu)", destTickPtr, srcTickPtr, numMins);
-	return 0;
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static int sceRtcTickAddHours(u32 destTickPtr, u32 srcTickPtr, int numHours)
@@ -718,8 +704,7 @@ static int sceRtcTickAddHours(u32 destTickPtr, u32 srcTickPtr, int numHours)
 		srcTick += numHours * 3600ULL * 1000000ULL;
 		Memory::Write_U64(srcTick, destTickPtr);
 	}
-	DEBUG_LOG(Log::sceRtc, "sceRtcTickAddMinutes(%d,%d,%d)", destTickPtr, srcTickPtr, numHours);
-	return 0;
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static int sceRtcTickAddDays(u32 destTickPtr, u32 srcTickPtr, int numDays)
@@ -731,8 +716,7 @@ static int sceRtcTickAddDays(u32 destTickPtr, u32 srcTickPtr, int numDays)
 		srcTick += numDays * 86400ULL * 1000000ULL;
 		Memory::Write_U64(srcTick, destTickPtr);
 	}
-	DEBUG_LOG(Log::sceRtc, "sceRtcTickAddDays(%d,%d,%d)", destTickPtr, srcTickPtr, numDays);
-	return 0;
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static int sceRtcTickAddWeeks(u32 destTickPtr, u32 srcTickPtr, int numWeeks)
@@ -744,16 +728,14 @@ static int sceRtcTickAddWeeks(u32 destTickPtr, u32 srcTickPtr, int numWeeks)
 		srcTick += numWeeks * 7ULL * 86400ULL * 1000000ULL;
 		Memory::Write_U64(srcTick, destTickPtr);
 	}
-	DEBUG_LOG(Log::sceRtc, "sceRtcTickAddWeeks(%d,%d,%d)", destTickPtr, srcTickPtr, numWeeks);
-	return 0;
+	return hleLogDebug(Log::sceRtc, 0);
 }
 
 static int sceRtcTickAddMonths(u32 destTickPtr, u32 srcTickPtr, int numMonths)
 {
 	if (!Memory::IsValidAddress(destTickPtr) || !Memory::IsValidAddress(srcTickPtr))
 	{
-		WARN_LOG(Log::sceRtc, "sceRtcTickAddMonths(%08x, %08x, %d): invalid address", destTickPtr, srcTickPtr, numMonths);
-		return -1;
+		return hleLogWarning(Log::sceRtc, -1, "invalid address");
 	}
 
 	u64 srcTick = Memory::Read_U64(srcTickPtr);
@@ -785,15 +767,13 @@ static int sceRtcTickAddMonths(u32 destTickPtr, u32 srcTickPtr, int numMonths)
 	}
 
 	DEBUG_LOG(Log::sceRtc, "sceRtcTickAddMonths(%08x, %08x = %lld, %d)", destTickPtr, srcTickPtr, srcTick, numMonths);
-	return 0;
+	return hleNoLog(0);
 }
 
 static int sceRtcTickAddYears(u32 destTickPtr, u32 srcTickPtr, int numYears)
 {
-	if (!Memory::IsValidAddress(destTickPtr) || !Memory::IsValidAddress(srcTickPtr))
-	{
-		WARN_LOG(Log::sceRtc, "sceRtcTickAddYears(%08x, %08x, %d): invalid address", destTickPtr, srcTickPtr, numYears);
-		return -1;
+	if (!Memory::IsValidAddress(destTickPtr) || !Memory::IsValidAddress(srcTickPtr)) {
+		return hleLogWarning(Log::sceRtc, -1, "invalid address");
 	}
 
 	u64 srcTick = Memory::Read_U64(srcTickPtr);
@@ -813,7 +793,7 @@ static int sceRtcTickAddYears(u32 destTickPtr, u32 srcTickPtr, int numYears)
 	}
 
 	DEBUG_LOG(Log::sceRtc, "sceRtcTickAddYears(%08x, %08x = %lld, %d)", destTickPtr, srcTickPtr, srcTick, numYears);
-	return 0;
+	return hleNoLog(0);
 }
 
 static int sceRtcParseDateTime(u32 destTickPtr, u32 dateStringPtr)
@@ -1035,5 +1015,5 @@ const HLEFunction sceRtc[] =
 
 void Register_sceRtc()
 {
-	RegisterModule("sceRtc", ARRAY_SIZE(sceRtc), sceRtc);
+	RegisterHLEModule("sceRtc", ARRAY_SIZE(sceRtc), sceRtc);
 }
