@@ -25,11 +25,9 @@
 #include "Core/Config.h"
 #include "Core/Reporting.h"
 #include "Core/Util/AudioFormat.h"
-#include "Core/Core.h"
+#include "Core/System.h"
 #include "SasAudio.h"
 
-// #define AUDIO_TO_FILE
-
 static const u8 f[16][2] = {
 	{   0,   0 },
 	{  60,   0 },
@@ -190,9 +188,11 @@ void VagDecoder::DoState(PointerWrap &p) {
 	Do(p, end_);
 }
 
-int SasAtrac3::setContext(u32 context) {
-	contextAddr_ = context;
-	atracID_ = AtracSasGetIDByContext(context);
+int SasAtrac3::SetContext(u32 contextAddr) {
+	contextAddr_ = contextAddr;
+	// Note: On hardware, atracID_ is also stored in the loopNum member of the context.
+	// But we don't actually mirror our struct to memory, so it doesn't really matter.
+	atracID_ = AtracSasBindContextAndGetID(contextAddr);
 	if (!sampleQueue_)
 		sampleQueue_ = new BufferQueue();
 	sampleQueue_->clear();
@@ -200,20 +200,23 @@ int SasAtrac3::setContext(u32 context) {
 	return 0;
 }
 
-void SasAtrac3::getNextSamples(s16 *outbuf, int wantedSamples) {
+void SasAtrac3::GetNextSamples(s16 *outbuf, int wantedSamples) {
 	if (atracID_ < 0) {
 		end_ = true;
 		return;
 	}
-	u32 finish = 0;
+
+	if (!buf_) {
+		buf_ = new s16[0x800];
+	}
+
+	int finish = 0;
 	int wantedbytes = wantedSamples * sizeof(s16);
 	while (!finish && sampleQueue_->getQueueSize() < wantedbytes) {
-		u32 numSamples = 0;
-		int remains = 0;
-		static s16 buf[0x800];
-		AtracSasDecodeData(atracID_, (u8*)buf, 0, &numSamples, &finish, &remains);
+		int numSamples = 0;
+		AtracSasDecodeData(atracID_, (u8*)buf_, &numSamples, &finish);
 		if (numSamples > 0)
-			sampleQueue_->push((u8*)buf, numSamples * sizeof(s16));
+			sampleQueue_->push((u8*)buf_, numSamples * sizeof(s16));
 		else
 			finish = 1;
 	}
@@ -221,8 +224,8 @@ void SasAtrac3::getNextSamples(s16 *outbuf, int wantedSamples) {
 	end_ = finish == 1;
 }
 
-int SasAtrac3::addStreamData(u32 bufPtr, u32 addbytes) {
-	if (atracID_ > 0) {
+int SasAtrac3::Concatenate(u32 bufPtr, u32 addbytes) {
+	if (atracID_ >= 0) {
 		AtracSasAddStreamData(atracID_, bufPtr, addbytes);
 	}
 	return 0;
@@ -369,9 +372,6 @@ void ADSREnvelope::SetSimpleEnvelope(u32 ADSREnv1, u32 ADSREnv2) {
 }
 
 SasInstance::SasInstance() {
-#ifdef AUDIO_TO_FILE
-	audioDump = fopen("D:\\audio.raw", "wb");
-#endif
 	memset(&waveformEffect, 0, sizeof(waveformEffect));
 	waveformEffect.type = PSP_SAS_EFFECT_TYPE_OFF;
 	waveformEffect.isDryOn = 1;
@@ -501,7 +501,7 @@ void SasVoice::ReadSamples(s16 *output, int numSamples) {
 		}
 		break;
 	case VOICETYPE_ATRAC3:
-		atrac3.getNextSamples(output, numSamples);
+		atrac3.GetNextSamples(output, numSamples);
 		break;
 	default:
 		memset(output, 0, numSamples * sizeof(s16));
@@ -531,10 +531,12 @@ void SasInstance::MixVoice(SasVoice &voice) {
 		if (voice.type == VOICETYPE_VAG && !voice.vagAddr)
 			break;
 		// else fallthrough! Don't change the check above.
+		[[fallthrough]];
 	case VOICETYPE_PCM:
 		if (voice.type == VOICETYPE_PCM && !voice.pcmAddr)
 			break;
 		// else fallthrough! Don't change the check above.
+		[[fallthrough]];
 	default:
 		// This feels a bit hacky.  The first 32 samples after a keyon are 0s.
 		int delay = 0;
@@ -621,7 +623,7 @@ void SasInstance::MixVoice(SasVoice &voice) {
 	}
 }
 
-void SasInstance::Mix(u32 outAddr, u32 inAddr, int leftVol, int rightVol) {
+void SasInstance::Mix(u32 outAddr, u32 inAddr, int leftVol, int rightVol, bool mute) {
 	for (int v = 0; v < PSP_SAS_VOICES_MAX; v++) {
 		SasVoice &voice = voices[v];
 		if (!voice.playing || voice.paused)
@@ -629,6 +631,12 @@ void SasInstance::Mix(u32 outAddr, u32 inAddr, int leftVol, int rightVol) {
 		MixVoice(voice);
 	}
 
+	// Apply mute if needed (note: we try to keep everything else identical to the non-muted case).
+	if (mute) {
+		memset(mixBuffer, 0, grainSize * sizeof(int) * 2);
+		memset(sendBuffer, 0, grainSize * sizeof(int) * 2);
+	}
+
 	// Then mix the send buffer in with the rest.
 
 	// Alright, all voices mixed. Let's convert and clip, and at the same time, wipe mixBuffer for next time. Could also dither.
@@ -660,12 +668,9 @@ void SasInstance::Mix(u32 outAddr, u32 inAddr, int leftVol, int rightVol) {
 	}
 	memset(mixBuffer, 0, grainSize * sizeof(int) * 2);
 	memset(sendBuffer, 0, grainSize * sizeof(int) * 2);
-
-#ifdef AUDIO_TO_FILE
-	fwrite(Memory::GetPointer(outAddr, grainSize * 2 * 2), 1, grainSize * 2 * 2, audioDump);
-#endif
 }
 
+// Note: leftVol/rightVol here are how much to scale the inp content by, not the mixBuffer.
 void SasInstance::WriteMixedOutput(s16 *outp, const s16 *inp, int leftVol, int rightVol) {
 	const bool dry = waveformEffect.isDryOn != 0;
 	const bool wet = waveformEffect.isWetOn != 0;
@@ -738,7 +743,7 @@ void SasInstance::ApplyWaveformEffect() {
 	}
 
 	// Volume max is 0x1000, while our factor is up to 0x8000. Shifting left by 3 fixes that.
-	reverb_.ProcessReverb(sendBufferProcessed, sendBufferDownsampled, grainSize / 2, waveformEffect.leftVol << 3, waveformEffect.rightVol << 3);
+	reverb_.ProcessReverb(sendBufferProcessed, sendBufferDownsampled, grainSize / 2, (uint16_t)(waveformEffect.leftVol << 3), (uint16_t)(waveformEffect.rightVol << 3));
 }
 
 void SasInstance::DoState(PointerWrap &p) {
