@@ -19,7 +19,6 @@
 #include <cmath>
 
 #include "Common/Serialize/SerializeFuncs.h"
-#include "Core/Config.h"
 #include "Core/Debugger/MemBlockInfo.h"
 #include "Core/HLE/FunctionWrappers.h"
 #include "Core/HW/SimpleAudioDec.h"
@@ -40,6 +39,7 @@ extern "C" {
 
 #include "Core/FFMPEGCompat.h"
 }
+#include "Core/Config.h"
 
 #else
 
@@ -70,8 +70,22 @@ public:
 	bool Decode(const uint8_t* inbuf, int inbytes, int *inbytesConsumed, int outputChannels, int16_t *outbuf, int *outSamples) override {
 		_dbg_assert_(outputChannels == 2);
 
+		// When used from sceMp3LowLevelDecode, this fails to parse the mp3 header!
+		// It's because minimp3 is a bit more sensitive than ffmpeg - if you give it a buffer that's larger than the frame size,
+		// it'll check that there's a second matching frame before accepting. But in our case we only get one frame,
+		// but we do not know the size. So this might need some modifications in minimp3.
 		mp3dec_frame_info_t info{};
-		int samplesWritten = mp3dec_decode_frame(&mp3_, inbuf, inbytes, (mp3d_sample_t *)outbuf, &info);
+		int samplesWritten = mp3dec_decode_frame(&mp3_, inbuf, inbytes, (mp3d_sample_t *)temp_, &info);
+		_dbg_assert_(samplesWritten <= MINIMP3_MAX_SAMPLES_PER_FRAME);
+		_dbg_assert_(info.channels <= 2);
+		if (info.channels == 1) {
+			for (int i = 0; i < samplesWritten; i++) {
+				outbuf[i * 2] = temp_[i];
+				outbuf[i * 2 + 1] = temp_[i];
+			}
+		} else {
+			memcpy(outbuf, temp_, 4 * samplesWritten);
+		}
 		*inbytesConsumed = info.frame_bytes;
 		*outSamples = samplesWritten;
 		return true;
@@ -87,6 +101,7 @@ public:
 private:
 	// We use the lowest-level API.
 	mp3dec_t mp3_{};
+	int16_t temp_[MINIMP3_MAX_SAMPLES_PER_FRAME]{};
 };
 
 // FFMPEG-based decoder. TODO: Replace with individual codecs.
@@ -126,15 +141,28 @@ private:
 };
 
 AudioDecoder *CreateAudioDecoder(PSPAudioType audioType, int sampleRateHz, int channels, size_t blockAlign, const uint8_t *extraData, size_t extraDataSize) {
+	bool forceFfmpeg = false;
+#ifdef USE_FFMPEG
+	forceFfmpeg = g_Config.bForceFfmpegForAudioDec;
+#endif
+	if (forceFfmpeg) {
+		return new FFmpegAudioDecoder(audioType, sampleRateHz, channels);
+	}
+
 	switch (audioType) {
-	case PSP_CODEC_MP3:
-		return new MiniMp3Audio();
+	// Our MiniMP3 backend has too many issues:
+	//   * Doesn't accept sample rate
+	//   * Doesn't accept data where there's only one valid frame if the buffer is bigger.
+	//     This prevents sceMp3LowLevelDecode from working, since nothing passes us the frame size.
+	//
+	// case PSP_CODEC_MP3:
+	// 	return new MiniMp3Audio();
 	case PSP_CODEC_AT3:
-		return CreateAtrac3Audio(channels, blockAlign, extraData, extraDataSize);
+	 	return CreateAtrac3Audio(channels, blockAlign, extraData, extraDataSize);
 	case PSP_CODEC_AT3PLUS:
 		return CreateAtrac3PlusAudio(channels, blockAlign);
 	default:
-		// Only AAC falls back to FFMPEG now.
+		// Only AAC normally falls back to FFMPEG now.
 		return new FFmpegAudioDecoder(audioType, sampleRateHz, channels);
 	}
 }
@@ -191,8 +219,15 @@ FFmpegAudioDecoder::FFmpegAudioDecoder(PSPAudioType audioType, int sampleRateHz,
 		ERROR_LOG(Log::ME, "Failed to allocate a codec context");
 		return;
 	}
-	codecCtx_->channels = channels_;
-	codecCtx_->channel_layout = channels_ == 2 ? AV_CH_LAYOUT_STEREO : AV_CH_LAYOUT_MONO;
+#if LIBAVUTIL_VERSION_MAJOR >= 59
+	if (channels_ == 2)
+		codecCtx_->ch_layout = AV_CHANNEL_LAYOUT_STEREO;
+	else
+		codecCtx_->ch_layout = AV_CHANNEL_LAYOUT_MONO;
+#else
+		codecCtx_->channels = channels_;
+		codecCtx_->channel_layout = channels_ == 2 ? AV_CH_LAYOUT_STEREO : AV_CH_LAYOUT_MONO;
+#endif
 	codecCtx_->sample_rate = sample_rate_;
 	codecOpen_ = false;
 #endif  // USE_FFMPEG
@@ -230,8 +265,15 @@ void FFmpegAudioDecoder::SetChannels(int channels) {
 		ERROR_LOG(Log::ME, "Codec already open, cannot change channels");
 	} else {
 		channels_ = channels;
+#if LIBAVUTIL_VERSION_MAJOR >= 59
+		if (channels_ == 2)
+			codecCtx_->ch_layout = AV_CHANNEL_LAYOUT_STEREO;
+		else
+			codecCtx_->ch_layout = AV_CHANNEL_LAYOUT_MONO;
+#else
 		codecCtx_->channels = channels_;
 		codecCtx_->channel_layout = channels_ == 2 ? AV_CH_LAYOUT_STEREO : AV_CH_LAYOUT_MONO;
+#endif
 	}
 #endif
 }
@@ -305,25 +347,48 @@ bool FFmpegAudioDecoder::Decode(const uint8_t *inbuf, int inbytes, int *inbytesC
 	}
 	
 	// get bytes consumed in source
-	*inbytesConsumed = len;
+	if (inbytesConsumed) {
+		*inbytesConsumed = len;
+	}
 
 	if (got_frame) {
 		// Initializing the sample rate convert. We will use it to convert float output into int.
 		_dbg_assert_(outputChannels == 2);
+#if LIBAVUTIL_VERSION_MAJOR >= 59
+		AVChannelLayout wanted_channel_layout = AV_CHANNEL_LAYOUT_STEREO; // we want stereo output layout
+		const AVChannelLayout& dec_channel_layout = frame_->ch_layout; // decoded channel layout
+#else
 		int64_t wanted_channel_layout = AV_CH_LAYOUT_STEREO; // we want stereo output layout
 		int64_t dec_channel_layout = frame_->channel_layout; // decoded channel layout
+#endif
 
 		if (!swrCtx_) {
+			// TODO: Allow these to differ.
+			const int inputSampleRate = codecCtx_->sample_rate;
+			const int outputSampleRate = codecCtx_->sample_rate;
+#if LIBAVUTIL_VERSION_MAJOR >= 59
+			swr_alloc_set_opts2(
+				&swrCtx_,
+				&wanted_channel_layout,
+				AV_SAMPLE_FMT_S16,
+				outputSampleRate,
+				&dec_channel_layout,
+				codecCtx_->sample_fmt,
+				inputSampleRate,
+				0,
+				NULL);
+#else
 			swrCtx_ = swr_alloc_set_opts(
 				swrCtx_,
 				wanted_channel_layout,
 				AV_SAMPLE_FMT_S16,
-				codecCtx_->sample_rate,
+				outputSampleRate,
 				dec_channel_layout,
 				codecCtx_->sample_fmt,
-				codecCtx_->sample_rate,
+				inputSampleRate,
 				0,
 				NULL);
+#endif
 
 			if (!swrCtx_ || swr_init(swrCtx_) < 0) {
 				ERROR_LOG(Log::ME, "swr_init: Failed to initialize the resampling context");
@@ -343,7 +408,9 @@ bool FFmpegAudioDecoder::Decode(const uint8_t *inbuf, int inbytes, int *inbytesC
 			return false;
 		}
 		// output stereo samples per frame
-		*outSamples = swrRet;
+		if (outSamples) {
+			*outSamples = swrRet;
+		}
 
 		// Save outbuf into pcm audio, you can uncomment this line to save and check the decoded audio into pcm file.
 		// SaveAudio("dump.pcm", outbuf, *outbytes);
@@ -351,7 +418,7 @@ bool FFmpegAudioDecoder::Decode(const uint8_t *inbuf, int inbytes, int *inbytesC
 	return true;
 #else
 	// Zero bytes output. No need to memset.
-	*outbytes = 0;
+	*outSamples = 0;
 	return true;
 #endif  // USE_FFMPEG
 }
