@@ -75,10 +75,10 @@ void DisassembleArm(const u8 *data, int size) {
 
 static u32 JitBreakpoint(uint32_t addr) {
 	// Should we skip this breakpoint?
-	if (CBreakPoints::CheckSkipFirst() == currentMIPS->pc || CBreakPoints::CheckSkipFirst() == addr)
+	if (g_breakpoints.CheckSkipFirst() == currentMIPS->pc || g_breakpoints.CheckSkipFirst() == addr)
 		return 0;
 
-	BreakAction result = CBreakPoints::ExecBreakPoint(addr);
+	BreakAction result = g_breakpoints.ExecBreakPoint(addr);
 	if ((result & BREAK_ACTION_PAUSE) == 0)
 		return 0;
 
@@ -86,7 +86,7 @@ static u32 JitBreakpoint(uint32_t addr) {
 }
 
 static u32 JitMemCheck(u32 pc) {
-	if (CBreakPoints::CheckSkipFirst() == currentMIPS->pc)
+	if (g_breakpoints.CheckSkipFirst() == currentMIPS->pc)
 		return 0;
 
 	// Note: pc may be the delay slot.
@@ -96,8 +96,8 @@ static u32 JitMemCheck(u32 pc) {
 		offset &= 0xFFFC;
 	u32 addr = currentMIPS->r[MIPS_GET_RS(op)] + offset;
 
-	CBreakPoints::ExecOpMemCheck(addr, pc);
-	return coreState == CORE_RUNNING || coreState == CORE_NEXTFRAME ? 0 : 1;
+	g_breakpoints.ExecOpMemCheck(addr, pc);
+	return coreState == CORE_RUNNING_CPU || coreState == CORE_NEXTFRAME ? 0 : 1;
 }
 
 namespace MIPSComp
@@ -120,7 +120,7 @@ ArmJit::ArmJit(MIPSState *mipsState) : blocks(mipsState, this), gpr(mipsState, &
 
 	// The debugger sets this so that "go" on a breakpoint will actually... go.
 	// But if they reset, we can end up hitting it by mistake, since it's based on PC and ticks.
-	CBreakPoints::SetSkipFirst(0);
+	g_breakpoints.SetSkipFirst(0);
 }
 
 ArmJit::~ArmJit() {
@@ -147,7 +147,7 @@ void ArmJit::DoState(PointerWrap &p)
 
 	// The debugger sets this so that "go" on a breakpoint will actually... go.
 	// But if they reset, we can end up hitting it by mistake, since it's based on PC and ticks.
-	CBreakPoints::SetSkipFirst(0);
+	g_breakpoints.SetSkipFirst(0);
 }
 
 void ArmJit::UpdateFCR31() {
@@ -536,7 +536,7 @@ bool ArmJit::ReplaceJalTo(u32 dest) {
 	js.compilerPC += 4;
 	// No writing exits, keep going!
 
-	if (CBreakPoints::HasMemChecks()) {
+	if (g_breakpoints.HasMemChecks()) {
 		// We could modify coreState, so we need to write PC and check.
 		// Otherwise, PC may end up on the jal.  We add 4 to skip the delay slot.
 		FlushAll();
@@ -572,7 +572,7 @@ void ArmJit::Comp_ReplacementFunc(MIPSOpcode op)
 		if ((entry->flags & (REPFLAG_HOOKENTER | REPFLAG_HOOKEXIT)) == 0) {
 			// Any breakpoint at the func entry was already tripped, so we can still run the replacement.
 			// That's a common case - just to see how often the replacement hits.
-			disabled = CBreakPoints::RangeContainsBreakPoint(GetCompilerPC() + sizeof(u32), funcSize - sizeof(u32));
+			disabled = g_breakpoints.RangeContainsBreakPoint(GetCompilerPC() + sizeof(u32), funcSize - sizeof(u32));
 		}
 	}
 
@@ -793,7 +793,7 @@ void ArmJit::WriteSyscallExit()
 }
 
 bool ArmJit::CheckJitBreakpoint(u32 addr, int downcountOffset) {
-	if (CBreakPoints::IsAddressBreakPoint(addr)) {
+	if (g_breakpoints.IsAddressBreakPoint(addr)) {
 		MRS(R8);
 		FlushAll();
 		MOVI2R(SCRATCHREG1, GetCompilerPC());
@@ -821,7 +821,7 @@ bool ArmJit::CheckJitBreakpoint(u32 addr, int downcountOffset) {
 }
 
 bool ArmJit::CheckMemoryBreakpoint(int instructionOffset) {
-	if (CBreakPoints::HasMemChecks()) {
+	if (g_breakpoints.HasMemChecks()) {
 		int off = instructionOffset + (js.inDelaySlot ? 1 : 0);
 
 		MRS(R8);
