@@ -105,7 +105,7 @@ void IRImmRegCache::MapDirtyInIn(IRReg rd, IRReg rs, IRReg rt) {
 IRNativeRegCacheBase::IRNativeRegCacheBase(MIPSComp::JitOptions *jo)
 	: jo_(jo) {}
 
-void IRNativeRegCacheBase::Start(MIPSComp::IRBlock *irBlock) {
+void IRNativeRegCacheBase::Start(MIPSComp::IRBlockCache *irBlockCache, int blockNum) {
 	if (!initialReady_) {
 		SetupInitialRegs();
 		initialReady_ = true;
@@ -114,6 +114,8 @@ void IRNativeRegCacheBase::Start(MIPSComp::IRBlock *irBlock) {
 	memcpy(nr, nrInitial_, sizeof(nr[0]) * config_.totalNativeRegs);
 	memcpy(mr, mrInitial_, sizeof(mr));
 
+	irBlock_ = irBlockCache->GetBlock(blockNum);
+
 	int numStatics;
 	const StaticAllocation *statics = GetStaticAllocations(numStatics);
 	for (int i = 0; i < numStatics; i++) {
@@ -124,10 +126,11 @@ void IRNativeRegCacheBase::Start(MIPSComp::IRBlock *irBlock) {
 		mr[statics[i].mr].nReg = statics[i].nr;
 		mr[statics[i].mr].isStatic = true;
 		// Lock it until the very end.
-		mr[statics[i].mr].spillLockIRIndex = irBlock->GetNumInstructions();
+		mr[statics[i].mr].spillLockIRIndex = irBlock_->GetNumIRInstructions();
 	}
 
-	irBlock_ = irBlock;
+	irBlockNum_ = blockNum;
+	irBlockCache_ = irBlockCache;
 	irIndex_ = 0;
 }
 
@@ -235,7 +238,7 @@ uint64_t IRNativeRegCacheBase::GetGPR2Imm(IRReg base) {
 void IRNativeRegCacheBase::SetGPRImm(IRReg gpr, uint32_t immVal) {
 	_dbg_assert_(IsValidGPR(gpr));
 	if (gpr == MIPS_REG_ZERO && immVal != 0) {
-		ERROR_LOG_REPORT(JIT, "Trying to set immediate %08x to r0", immVal);
+		ERROR_LOG_REPORT(Log::JIT, "Trying to set immediate %08x to r0", immVal);
 		return;
 	}
 
@@ -384,7 +387,7 @@ IRNativeReg IRNativeRegCacheBase::AllocateReg(MIPSLoc type, MIPSMap flags) {
 	}
 
 	// Uh oh, we have all of them spilllocked....
-	ERROR_LOG_REPORT(JIT, "Out of spillable registers in block PC %08x, index %d", irBlock_->GetOriginalStart(), irIndex_);
+	ERROR_LOG_REPORT(Log::JIT, "Out of spillable registers in block PC %08x, index %d", irBlock_->GetOriginalStart(), irIndex_);
 	_assert_(bestToSpill != -1);
 	return -1;
 }
@@ -430,8 +433,8 @@ bool IRNativeRegCacheBase::IsRegClobbered(MIPSLoc type, IRReg r) const {
 	info.lookaheadCount = UNUSED_LOOKAHEAD_OPS;
 	// We look starting one ahead, unlike spilling.  We want to know if it clobbers later.
 	info.currentIndex = irIndex_ + 1;
-	info.instructions = irBlock_->GetInstructions();
-	info.numInstructions = irBlock_->GetNumInstructions();
+	info.instructions = irBlockCache_->GetBlockInstructionPtr(irBlockNum_);
+	info.numInstructions = irBlock_->GetNumIRInstructions();
 
 	// Make sure we're on the first one if this is multi-lane.
 	IRReg first = r;
@@ -457,8 +460,8 @@ bool IRNativeRegCacheBase::IsRegRead(MIPSLoc type, IRReg first) const {
 	info.lookaheadCount = UNUSED_LOOKAHEAD_OPS;
 	// We look starting one ahead, unlike spilling.
 	info.currentIndex = irIndex_ + 1;
-	info.instructions = irBlock_->GetInstructions();
-	info.numInstructions = irBlock_->GetNumInstructions();
+	info.instructions = irBlockCache_->GetBlockInstructionPtr(irBlockNum_);
+	info.numInstructions = irBlock_->GetNumIRInstructions();
 
 	// Note: this intentionally doesn't look at the full reg, only the lane.
 	IRUsage usage = GetNextRegUsage(info, type, first);
@@ -474,8 +477,8 @@ IRNativeReg IRNativeRegCacheBase::FindBestToSpill(MIPSLoc type, MIPSMap flags, b
 	IRSituation info;
 	info.lookaheadCount = UNUSED_LOOKAHEAD_OPS;
 	info.currentIndex = irIndex_;
-	info.instructions = irBlock_->GetInstructions();
-	info.numInstructions = irBlock_->GetNumInstructions();
+	info.instructions = irBlockCache_->GetBlockInstructionPtr(irBlockNum_);
+	info.numInstructions = irBlock_->GetNumIRInstructions();
 
 	*clobbered = false;
 	for (int i = 0; i < allocCount; i++) {
@@ -583,7 +586,7 @@ void IRNativeRegCacheBase::FlushNativeReg(IRNativeReg nreg) {
 	}
 	_dbg_assert_(!mr[nr[nreg].mipsReg].isStatic);
 	if (mr[nr[nreg].mipsReg].isStatic) {
-		ERROR_LOG(JIT, "Cannot FlushNativeReg a statically mapped register");
+		ERROR_LOG(Log::JIT, "Cannot FlushNativeReg a statically mapped register");
 		return;
 	}
 
@@ -687,7 +690,7 @@ void IRNativeRegCacheBase::FlushAll(bool gprs, bool fprs) {
 
 	for (int i = 1; i < TOTAL_MAPPABLE_IRREGS; i++) {
 		IRReg mipsReg = (IRReg)i;
-		if (!fprs && i >= 32 && IsValidFPR(mipsReg))
+		if (!fprs && i >= 32 && IsValidFPR(mipsReg - 32))
 			continue;
 		if (!gprs && IsValidGPR(mipsReg))
 			continue;
@@ -705,7 +708,7 @@ void IRNativeRegCacheBase::FlushAll(bool gprs, bool fprs) {
 			} else if (mr[i].loc == MIPSLoc::REG_IMM) {
 				// The register already contains the immediate.
 				if (nr[nreg].pointerified) {
-					ERROR_LOG(JIT, "RVREG_IMM but pointerified. Wrong.");
+					ERROR_LOG(Log::JIT, "RVREG_IMM but pointerified. Wrong.");
 					nr[nreg].pointerified = false;
 				}
 				mr[i].loc = MIPSLoc::REG;
@@ -743,7 +746,7 @@ void IRNativeRegCacheBase::FlushAll(bool gprs, bool fprs) {
 	// Sanity check
 	for (int i = 0; i < config_.totalNativeRegs; i++) {
 		if (nr[i].mipsReg != IRREG_INVALID && !mr[nr[i].mipsReg].isStatic) {
-			ERROR_LOG_REPORT(JIT, "Flush fail: nr[%i].mipsReg=%i", i, nr[i].mipsReg);
+			ERROR_LOG_REPORT(Log::JIT, "Flush fail: nr[%i].mipsReg=%i", i, nr[i].mipsReg);
 		}
 	}
 }
@@ -908,6 +911,7 @@ void IRNativeRegCacheBase::MappingFromInst(const IRInst &inst, Mapping mapping[3
 		case '\0':
 		case '_':
 		case 'C':
+		case 'r':
 		case 'I':
 		case 'v':
 		case 's':
@@ -1026,8 +1030,8 @@ void IRNativeRegCacheBase::MapNativeReg(MIPSLoc type, IRNativeReg nreg, IRReg fi
 							IRSituation info;
 							info.lookaheadCount = 16;
 							info.currentIndex = irIndex_;
-							info.instructions = irBlock_->GetInstructions();
-							info.numInstructions = irBlock_->GetNumInstructions();
+							info.instructions = irBlockCache_->GetBlockInstructionPtr(irBlockNum_);
+							info.numInstructions = irBlock_->GetNumIRInstructions();
 
 							IRReg basefpr = first - oldlane - 32;
 							clobbered = true;
@@ -1213,7 +1217,7 @@ IRNativeReg IRNativeRegCacheBase::MapNativeRegAsPointer(IRReg gpr) {
 			nr[nreg].pointerified = true;
 		}
 	} else {
-		ERROR_LOG(JIT, "MapNativeRegAsPointer: MapNativeReg failed to allocate a register?");
+		ERROR_LOG(Log::JIT, "MapNativeRegAsPointer: MapNativeReg failed to allocate a register?");
 	}
 	return nreg;
 }
