@@ -97,7 +97,6 @@ namespace MIPSAnalyst {
 
 	void Reset();
 
-	bool IsRegisterUsed(u32 reg, u32 addr);
 	// This will not only create a database of "AnalyzedFunction" structs, it also
 	// will insert all the functions it finds into the symbol map, if insertSymbols is true.
 
@@ -108,8 +107,6 @@ namespace MIPSAnalyst {
 	bool ScanForFunctions(u32 startAddr, u32 endAddr, bool insertSymbols);
 	void FinalizeScan(bool insertSymbols);
 	void ForgetFunctions(u32 startAddr, u32 endAddr);
-	void PrecompileFunctions();
-	void PrecompileFunction(u32 startAddr, u32 length);
 
 	void SetHashMapFilename(const std::string& filename = "");
 	void LoadBuiltinHashMap();
