@@ -18,7 +18,6 @@
 #include "Common/StringUtils.h"
 
 #include "Core/Core.h"
-#include "Core/System.h"
 #include "Core/MemMap.h"
 #include "Core/MIPS/MIPS.h"
 #include "Core/MIPS/MIPSDis.h"
@@ -914,7 +913,9 @@ void MIPSCompileOp(MIPSOpcode op, MIPSComp::MIPSFrontendInterface *jit) {
 		if (info & OUT_EAT_PREFIX)
 			jit->EatPrefix();
 	} else {
-		ERROR_LOG_REPORT(Log::CPU, "MIPSCompileOp: Invalid instruction %08x", op.encoding);
+		// Used to _REPORT this, but I'm confident we have all instructions now, any caught here
+		// are due to games crashing, due to cheats or bugs.
+		ERROR_LOG(Log::CPU, "MIPSCompileOp: Invalid instruction %08x", op.encoding);
 	}
 }
 
@@ -970,7 +971,7 @@ void MIPSInterpret(MIPSOpcode op) {
 static inline void RunUntilFast() {
 	MIPSState *curMips = currentMIPS;
 	// NEVER stop in a delay slot!
-	while (curMips->downcount >= 0 && coreState == CORE_RUNNING) {
+	while (curMips->downcount >= 0 && coreState == CORE_RUNNING_CPU) {
 		do {
 			// Replacements and similar are processed here, intentionally.
 			MIPSOpcode op = MIPSOpcode(Memory::Read_U32(curMips->pc));
@@ -992,37 +993,37 @@ static inline void RunUntilFast() {
 static void RunUntilWithChecks(u64 globalTicks) {
 	MIPSState *curMips = currentMIPS;
 	// NEVER stop in a delay slot!
-	bool hasBPs = CBreakPoints::HasBreakPoints();
-	bool hasMCs = CBreakPoints::HasMemChecks();
-	while (curMips->downcount >= 0 && coreState == CORE_RUNNING) {
+	bool hasBPs = g_breakpoints.HasBreakPoints();
+	bool hasMCs = g_breakpoints.HasMemChecks();
+	while (curMips->downcount >= 0 && coreState == CORE_RUNNING_CPU) {
 		do {
 			// Replacements and similar are processed here, intentionally.
 			MIPSOpcode op = MIPSOpcode(Memory::Read_U32(curMips->pc));
 			const MIPSInstruction *instr = MIPSGetInstruction(op);
 
 			// Check for breakpoint
-			if (hasBPs && CBreakPoints::IsAddressBreakPoint(curMips->pc) && CBreakPoints::CheckSkipFirst() != curMips->pc) {
-				auto cond = CBreakPoints::GetBreakPointCondition(currentMIPS->pc);
+			if (hasBPs && g_breakpoints.IsAddressBreakPoint(curMips->pc) && g_breakpoints.CheckSkipFirst() != curMips->pc) {
+				auto cond = g_breakpoints.GetBreakPointCondition(currentMIPS->pc);
 				if (!cond || cond->Evaluate()) {
-					Core_EnableStepping(true, "cpu.breakpoint", curMips->pc);
-					if (CBreakPoints::IsTempBreakPoint(curMips->pc))
-						CBreakPoints::RemoveBreakPoint(curMips->pc);
+					Core_Break(BreakReason::CpuBreakpoint, curMips->pc);
+					if (g_breakpoints.IsTempBreakPoint(curMips->pc))
+						g_breakpoints.RemoveBreakPoint(curMips->pc);
 					break;
 				}
 			}
-			if (hasMCs && (instr->flags & (IN_MEM | OUT_MEM)) != 0 && CBreakPoints::CheckSkipFirst() != curMips->pc && instr->interpret != &Int_Syscall) {
+			if (hasMCs && (instr->flags & (IN_MEM | OUT_MEM)) != 0 && g_breakpoints.CheckSkipFirst() != curMips->pc && instr->interpret != &Int_Syscall) {
 				// This is common for all IN_MEM/OUT_MEM funcs.
 				int offset = (instr->flags & IS_VFPU) != 0 ? SignExtend16ToS32(op & 0xFFFC) : SignExtend16ToS32(op);
 				u32 addr = (R(_RS) + offset) & 0xFFFFFFFC;
 				int sz = MIPSGetMemoryAccessSize(op);
 
 				if ((instr->flags & IN_MEM) != 0)
-					CBreakPoints::ExecMemCheck(addr, false, sz, curMips->pc, "interpret");
+					g_breakpoints.ExecMemCheck(addr, false, sz, curMips->pc, "interpret");
 				if ((instr->flags & OUT_MEM) != 0)
-					CBreakPoints::ExecMemCheck(addr, true, sz, curMips->pc, "interpret");
+					g_breakpoints.ExecMemCheck(addr, true, sz, curMips->pc, "interpret");
 
 				// If it tripped, bail without running.
-				if (coreState == CORE_STEPPING)
+				if (coreState == CORE_STEPPING_CPU)
 					break;
 			}
 
@@ -1044,11 +1045,11 @@ static void RunUntilWithChecks(u64 globalTicks) {
 
 int MIPSInterpret_RunUntil(u64 globalTicks) {
 	MIPSState *curMips = currentMIPS;
-	while (coreState == CORE_RUNNING) {
+	while (coreState == CORE_RUNNING_CPU) {
 		CoreTiming::Advance();
 
 		uint64_t ticksLeft = globalTicks - CoreTiming::GetTicks();
-		if (CBreakPoints::HasBreakPoints() || CBreakPoints::HasMemChecks() || ticksLeft <= curMips->downcount)
+		if (g_breakpoints.HasBreakPoints() || g_breakpoints.HasMemChecks() || ticksLeft <= curMips->downcount)
 			RunUntilWithChecks(globalTicks);
 		else
 			RunUntilFast();
