@@ -18,6 +18,7 @@
 #include "ppsspp_config.h"
 
 #include <algorithm>
+
 #include <png.h>
 #include "ext/jpge/jpge.h"
 
@@ -25,14 +26,15 @@
 #include "Common/File/FileUtil.h"
 #include "Common/File/Path.h"
 #include "Common/Log.h"
+#include "Common/System/System.h"
 #include "Common/System/Display.h"
-#include "Core/Config.h"
+#include "Common/System/NativeApp.h"
+#include "Common/Thread/Promise.h"
 #include "Core/Screenshot.h"
-#include "Core/Core.h"
+#include "Core/System.h"
 #include "GPU/Common/GPUDebugInterface.h"
 #include "GPU/Common/FramebufferManagerCommon.h"
-#include "GPU/GPUInterface.h"
-#include "GPU/GPUState.h"
+#include "GPU/GPUCommon.h"
 
 // This is used to make non-ASCII paths work for filename.
 // Technically only needed on Windows.
@@ -329,57 +331,54 @@ static GPUDebugBuffer ApplyRotation(const GPUDebugBuffer &buf, DisplayRotation r
 	return rotated;
 }
 
-bool TakeGameScreenshot(Draw::DrawContext *draw, const Path &filename, ScreenshotFormat fmt, ScreenshotType type, int *width, int *height, int maxRes) {
+ScreenshotResult TakeGameScreenshot(Draw::DrawContext *draw, const Path &filename, ScreenshotFormat fmt, ScreenshotType type, int maxRes, std::function<void(bool success)> callback) {
 	GPUDebugBuffer buf;
-	bool success = false;
 	u32 w = (u32)-1;
 	u32 h = (u32)-1;
 
 	if (type == SCREENSHOT_DISPLAY || type == SCREENSHOT_RENDER) {
 		if (!gpuDebug) {
 			ERROR_LOG(Log::System, "Can't take screenshots when GPU not running");
-			return false;
+			return ScreenshotResult::ScreenshotNotPossible;
+		}
+		if (!gpuDebug->GetCurrentFramebuffer(buf, type == SCREENSHOT_RENDER ? GPU_DBG_FRAMEBUF_RENDER : GPU_DBG_FRAMEBUF_DISPLAY, maxRes)) {
+			return ScreenshotResult::ScreenshotNotPossible;
 		}
-		success = gpuDebug->GetCurrentFramebuffer(buf, type == SCREENSHOT_RENDER ? GPU_DBG_FRAMEBUF_RENDER : GPU_DBG_FRAMEBUF_DISPLAY, maxRes);
 		w = maxRes > 0 ? 480 * maxRes : PSP_CoreParameter().renderWidth;
 		h = maxRes > 0 ? 272 * maxRes : PSP_CoreParameter().renderHeight;
 	} else if (g_display.rotation != DisplayRotation::ROTATE_0) {
 		_dbg_assert_(draw);
 		GPUDebugBuffer temp;
-		success = ::GetOutputFramebuffer(draw, buf);
-		if (success) {
-			buf = ApplyRotation(temp, g_display.rotation);
+		if (!::GetOutputFramebuffer(draw, temp)) {
+			return ScreenshotResult::ScreenshotNotPossible;
 		}
+		buf = ApplyRotation(temp, g_display.rotation);
 	} else {
 		_dbg_assert_(draw);
-		success = ::GetOutputFramebuffer(draw, buf);
-	}
-
-	if (!success) {
-		ERROR_LOG(Log::G3D, "Failed to obtain screenshot data.");
-		return false;
-	}
-
-	if (success) {
-		u8 *flipbuffer = nullptr;
-		const u8 *buffer = ConvertBufferToScreenshot(buf, false, flipbuffer, w, h);
-		success = buffer != nullptr;
-		if (success) {
-			if (width)
-				*width = w;
-			if (height)
-				*height = h;
-
-			success = Save888RGBScreenshot(filename, fmt, buffer, w, h);
+		if (!GetOutputFramebuffer(draw, buf)) {
+			return ScreenshotResult::ScreenshotNotPossible;
 		}
-		delete[] flipbuffer;
 	}
 
-	if (!success) {
-		ERROR_LOG(Log::IO, "Failed to write screenshot.");
+	if (callback) {
+		g_threadManager.EnqueueTask(new IndependentTask(TaskType::IO_BLOCKING, TaskPriority::LOW,
+			[buf = std::move(buf), callback = std::move(callback), filename, fmt, w, h]() {
+			u8 *flipbuffer = nullptr;
+			u32 width = w, height = h;
+			const u8 *buffer = ConvertBufferToScreenshot(buf, false, flipbuffer, width, height);
+			bool success = Save888RGBScreenshot(filename, fmt, buffer, width, height);
+			delete[] flipbuffer;
+			System_RunOnMainThread([success, callback = std::move(callback)]() {
+				callback(success);
+			});
+		}));
+		return ScreenshotResult::DelayedResult;
 	}
-
-	return success;
+	u8 *flipbuffer = nullptr;
+	const u8 *buffer = ConvertBufferToScreenshot(buf, false, flipbuffer, w, h);
+	bool success = Save888RGBScreenshot(filename, fmt, buffer, w, h);
+	delete[] flipbuffer;
+	return success ? ScreenshotResult::Success : ScreenshotResult::FailedToWriteFile;
 }
 
 bool Save888RGBScreenshot(const Path &filename, ScreenshotFormat fmt, const u8 *bufferRGB888, int w, int h) {
