@@ -22,9 +22,9 @@
 #pragma once
 
 #ifdef USE_SYSTEM_MINIUPNPC
-#include <miniupnpc/include/miniwget.h>
-#include <miniupnpc/include/miniupnpc.h>
-#include <miniupnpc/include/upnpcommands.h>
+#include <miniupnpc/miniwget.h>
+#include <miniupnpc/miniupnpc.h>
+#include <miniupnpc/upnpcommands.h>
 #else
 #ifndef MINIUPNP_STATICLIB
 #define MINIUPNP_STATICLIB
@@ -116,7 +116,7 @@ private:
 
 extern PortManager g_PortManager;
 
-void __UPnPInit(const unsigned int timeout = 2000);
+void __UPnPInit(const int timeout_ms);
 void __UPnPShutdown();
 
 // Add a port & protocol (TCP, UDP or vendor-defined) to map for forwarding (intport = 0 : same as [external] port)
