@@ -17,12 +17,16 @@
 
 #pragma once
 
+#include "Common/Common.h"
+
 enum class WebServerFlags {
+	NONE = 0,
 	DISCS = 1,
 	DEBUGGER = 2,
 
 	ALL =  1 | 2,
 };
+ENUM_CLASS_BITOPS(WebServerFlags);
 
 bool StartWebServer(WebServerFlags flags);
 bool StopWebServer(WebServerFlags flags);
