@@ -257,8 +257,8 @@ JittedVertexDecoder VertexDecoderJitCache::Compile(const VertexDecoder &dec, int
 			// Reset the code ptr and return zero to indicate that we failed.
 			ResetCodePtr(GetOffset(start));
 			char temp[1024] = {0};
-			dec.ToString(temp);
-			INFO_LOG(G3D, "Could not compile vertex decoder: %s", temp);
+			dec.ToString(temp, true);
+			INFO_LOG(Log::G3D, "Could not compile vertex decoder: %s", temp);
 			return 0;
 		}
 	}
@@ -285,8 +285,8 @@ JittedVertexDecoder VertexDecoderJitCache::Compile(const VertexDecoder &dec, int
 	/*
 	DisassembleArm(start, GetCodePtr() - start);
 	char temp[1024] = {0};
-	dec.ToString(temp);
-	INFO_LOG(G3D, "%s", temp);
+	dec.ToString(temp, true);
+	INFO_LOG(Log::G3D, "%s", temp);
 	*/
 
 	*jittedSize = GetCodePtr() - start;
