@@ -22,18 +22,12 @@
 
 #include <map>
 
-#include "Common/Math/lin/matrix4x4.h"
-#include "Common/Math/math_util.h"
-#include "Common/Data/Convert/SmallDataConvert.h"
 #include "Common/GPU/thin3d.h"
-#include "Common/Data/Encoding/Utf8.h"
 #include "Common/Log.h"
 #include "Common/CommonTypes.h"
-#include "Core/Config.h"
-#include "GPU/Math3D.h"
 #include "GPU/GPUState.h"
-#include "GPU/ge_constants.h"
 #include "GPU/Common/VertexShaderGenerator.h"
+#include "GPU/Common/VertexDecoderCommon.h"
 #include "GPU/D3D11/ShaderManagerD3D11.h"
 #include "GPU/D3D11/D3D11Util.h"
 
@@ -41,14 +35,11 @@ D3D11FragmentShader::D3D11FragmentShader(ID3D11Device *device, D3D_FEATURE_LEVEL
 	: device_(device), useHWTransform_(useHWTransform), id_(id) {
 	source_ = code;
 
-	module_ = CreatePixelShaderD3D11(device, code, strlen(code), featureLevel);
-	if (!module_)
+	if (FAILED(CreatePixelShaderD3D11(device, code, strlen(code), featureLevel, 0, &module_)))
 		failed_ = true;
 }
 
 D3D11FragmentShader::~D3D11FragmentShader() {
-	if (module_)
-		module_->Release();
 }
 
 std::string D3D11FragmentShader::GetShaderString(DebugShaderStringType type) const {
@@ -66,14 +57,11 @@ D3D11VertexShader::D3D11VertexShader(ID3D11Device *device, D3D_FEATURE_LEVEL fea
 	: device_(device), useHWTransform_(useHWTransform), id_(id) {
 	source_ = code;
 
-	module_ = CreateVertexShaderD3D11(device, code, strlen(code), &bytecode_, featureLevel);
-	if (!module_)
+	if(FAILED(CreateVertexShaderD3D11(device, code, strlen(code), &bytecode_, featureLevel, 0, &module_)))
 		failed_ = true;
 }
 
 D3D11VertexShader::~D3D11VertexShader() {
-	if (module_)
-		module_->Release();
 }
 
 std::string D3D11VertexShader::GetShaderString(DebugShaderStringType type) const {
@@ -109,9 +97,6 @@ ShaderManagerD3D11::ShaderManagerD3D11(Draw::DrawContext *draw, ID3D11Device *de
 }
 
 ShaderManagerD3D11::~ShaderManagerD3D11() {
-	push_base->Release();
-	push_lights->Release();
-	push_bones->Release();
 	ClearShaders();
 	delete[] codeBuffer_;
 }
@@ -150,21 +135,21 @@ uint64_t ShaderManagerD3D11::UpdateUniforms(bool useBufferedRendering) {
 		D3D11_MAPPED_SUBRESOURCE map;
 		if (dirty & DIRTY_BASE_UNIFORMS) {
 			BaseUpdateUniforms(&ub_base, dirty, true, useBufferedRendering);
-			context_->Map(push_base, 0, D3D11_MAP_WRITE_DISCARD, 0, &map);
+			context_->Map(push_base.Get(), 0, D3D11_MAP_WRITE_DISCARD, 0, &map);
 			memcpy(map.pData, &ub_base, sizeof(ub_base));
-			context_->Unmap(push_base, 0);
+			context_->Unmap(push_base.Get(), 0);
 		}
 		if (dirty & DIRTY_LIGHT_UNIFORMS) {
 			LightUpdateUniforms(&ub_lights, dirty);
-			context_->Map(push_lights, 0, D3D11_MAP_WRITE_DISCARD, 0, &map);
+			context_->Map(push_lights.Get(), 0, D3D11_MAP_WRITE_DISCARD, 0, &map);
 			memcpy(map.pData, &ub_lights, sizeof(ub_lights));
-			context_->Unmap(push_lights, 0);
+			context_->Unmap(push_lights.Get(), 0);
 		}
 		if (dirty & DIRTY_BONE_UNIFORMS) {
 			BoneUpdateUniforms(&ub_bones, dirty);
-			context_->Map(push_bones, 0, D3D11_MAP_WRITE_DISCARD, 0, &map);
+			context_->Map(push_bones.Get(), 0, D3D11_MAP_WRITE_DISCARD, 0, &map);
 			memcpy(map.pData, &ub_bones, sizeof(ub_bones));
-			context_->Unmap(push_bones, 0);
+			context_->Unmap(push_bones.Get(), 0);
 		}
 	}
 	gstate_c.CleanUniforms();
@@ -172,19 +157,19 @@ uint64_t ShaderManagerD3D11::UpdateUniforms(bool useBufferedRendering) {
 }
 
 void ShaderManagerD3D11::BindUniforms() {
-	ID3D11Buffer *vs_cbs[3] = { push_base, push_lights, push_bones };
-	ID3D11Buffer *ps_cbs[1] = { push_base };
+	ID3D11Buffer *vs_cbs[3] = { push_base.Get(), push_lights.Get(), push_bones.Get() };
+	ID3D11Buffer *ps_cbs[1] = { push_base.Get() };
 	context_->VSSetConstantBuffers(0, 3, vs_cbs);
 	context_->PSSetConstantBuffers(0, 1, ps_cbs);
 }
 
-void ShaderManagerD3D11::GetShaders(int prim, VertexDecoder *decoder, D3D11VertexShader **vshader, D3D11FragmentShader **fshader, const ComputedPipelineState &pipelineState, bool useHWTransform, bool useHWTessellation, bool weightsAsFloat, bool useSkinInDecode) {
+void ShaderManagerD3D11::GetShaders(int prim, u32 vertexType, D3D11VertexShader **vshader, D3D11FragmentShader **fshader, const ComputedPipelineState &pipelineState, bool useHWTransform, bool useHWTessellation, bool weightsAsFloat, bool useSkinInDecode) {
 	VShaderID VSID;
 	FShaderID FSID;
 
 	if (gstate_c.IsDirty(DIRTY_VERTEXSHADER_STATE)) {
 		gstate_c.Clean(DIRTY_VERTEXSHADER_STATE);
-		ComputeVertexShaderID(&VSID, decoder, useHWTransform, useHWTessellation, weightsAsFloat, useSkinInDecode);
+		ComputeVertexShaderID(&VSID, vertexType, useHWTransform, useHWTessellation, weightsAsFloat, useSkinInDecode);
 	} else {
 		VSID = lastVSID_;
 	}
