@@ -20,24 +20,20 @@
 #include <cfloat>
 
 #include <d3d11.h>
+#include <wrl/client.h>
 
-#include "Common/TimeUtil.h"
-#include "Core/MemMap.h"
 #include "GPU/ge_constants.h"
 #include "GPU/GPUState.h"
 #include "GPU/Common/GPUStateUtils.h"
 #include "GPU/Common/DrawEngineCommon.h"
 #include "GPU/D3D11/TextureCacheD3D11.h"
 #include "GPU/D3D11/FramebufferManagerD3D11.h"
-#include "GPU/D3D11/ShaderManagerD3D11.h"
-#include "GPU/Common/TextureShaderCommon.h"
 #include "GPU/D3D11/D3D11Util.h"
-#include "GPU/Common/FramebufferManagerCommon.h"
-#include "GPU/Common/TextureDecoder.h"
 #include "Core/Config.h"
 
 #include "ext/xxhash.h"
-#include "Common/Math/math_util.h"
+
+using namespace Microsoft::WRL;
 
 // For depth depal
 struct DepthPushConstants {
@@ -46,8 +42,6 @@ struct DepthPushConstants {
 	float pad[2];
 };
 
-#define INVALID_TEX (ID3D11ShaderResourceView *)(-1LL)
-
 static const D3D11_INPUT_ELEMENT_DESC g_QuadVertexElements[] = {
 	{ "POSITION", 0, DXGI_FORMAT_R32G32B32_FLOAT, 0, 0, },
 	{ "TEXCOORD", 0, DXGI_FORMAT_R32G32_FLOAT, 0, 12,},
@@ -79,15 +73,14 @@ static DXGI_FORMAT ToDXGIFormat(Draw::DataFormat fmt) {
 }
 
 SamplerCacheD3D11::~SamplerCacheD3D11() {
-	for (auto &iter : cache_) {
-		iter.second->Release();
-	}
 }
 
-ID3D11SamplerState *SamplerCacheD3D11::GetOrCreateSampler(ID3D11Device *device, const SamplerCacheKey &key) {
+HRESULT SamplerCacheD3D11::GetOrCreateSampler(ID3D11Device *device, const SamplerCacheKey &key, ID3D11SamplerState **ppSamplerState) {
 	auto iter = cache_.find(key);
 	if (iter != cache_.end()) {
-		return iter->second;
+		iter->second->AddRef();
+		*ppSamplerState = iter->second.Get();
+		return S_OK;
 	}
 
 	D3D11_SAMPLER_DESC samp{};
@@ -130,10 +123,9 @@ ID3D11SamplerState *SamplerCacheD3D11::GetOrCreateSampler(ID3D11Device *device,
 		samp.BorderColor[i] = 1.0f;
 	}
 
-	ID3D11SamplerState *sampler;
-	ASSERT_SUCCESS(device->CreateSamplerState(&samp, &sampler));
-	cache_[key] = sampler;
-	return sampler;
+	ASSERT_SUCCESS(device->CreateSamplerState(&samp, ppSamplerState));
+	cache_[key] = *ppSamplerState;
+	return S_OK;
 }
 
 TextureCacheD3D11::TextureCacheD3D11(Draw::DrawContext *draw, Draw2D *draw2D)
@@ -141,24 +133,21 @@ TextureCacheD3D11::TextureCacheD3D11(Draw::DrawContext *draw, Draw2D *draw2D)
 	device_ = (ID3D11Device *)draw->GetNativeObject(Draw::NativeObject::DEVICE);
 	context_ = (ID3D11DeviceContext *)draw->GetNativeObject(Draw::NativeObject::CONTEXT);
 
-	lastBoundTexture = INVALID_TEX;
+	lastBoundTexture_ = D3D11_INVALID_TEX;
 
-	D3D11_BUFFER_DESC desc{ sizeof(DepthPushConstants), D3D11_USAGE_DYNAMIC, D3D11_BIND_CONSTANT_BUFFER, D3D11_CPU_ACCESS_WRITE };
-	HRESULT hr = device_->CreateBuffer(&desc, nullptr, &depalConstants_);
-	_dbg_assert_(SUCCEEDED(hr));
-
-	HRESULT result = 0;
-
-	nextTexture_ = nullptr;
+	InitDeviceObjects();
 }
 
 TextureCacheD3D11::~TextureCacheD3D11() {
-	depalConstants_->Release();
-
-	// pFramebufferVertexDecl->Release();
 	Clear(true);
 }
 
+void TextureCacheD3D11::InitDeviceObjects() {
+	D3D11_BUFFER_DESC desc{ sizeof(DepthPushConstants), D3D11_USAGE_DYNAMIC, D3D11_BIND_CONSTANT_BUFFER, D3D11_CPU_ACCESS_WRITE };
+	HRESULT hr = device_->CreateBuffer(&desc, nullptr, &depalConstants_);
+	_dbg_assert_(SUCCEEDED(hr));
+}
+
 void TextureCacheD3D11::SetFramebufferManager(FramebufferManagerD3D11 *fbManager) {
 	framebufferManager_ = fbManager;
 }
@@ -177,7 +166,7 @@ void TextureCacheD3D11::ReleaseTexture(TexCacheEntry *entry, bool delete_them) {
 }
 
 void TextureCacheD3D11::ForgetLastTexture() {
-	lastBoundTexture = INVALID_TEX;
+	lastBoundTexture_ = D3D11_INVALID_TEX;
 
 	ID3D11ShaderResourceView *nullTex[4]{};
 	context_->PSSetShaderResources(0, 4, nullTex);
@@ -226,20 +215,22 @@ void TextureCacheD3D11::BindTexture(TexCacheEntry *entry) {
 		return;
 	}
 	ID3D11ShaderResourceView *textureView = DxView(entry);
-	if (textureView != lastBoundTexture) {
+	if (textureView != lastBoundTexture_) {
 		context_->PSSetShaderResources(0, 1, &textureView);
-		lastBoundTexture = textureView;
+		lastBoundTexture_ = textureView;
 	}
 	int maxLevel = (entry->status & TexCacheEntry::STATUS_NO_MIPS) ? 0 : entry->maxLevel;
 	SamplerCacheKey samplerKey = GetSamplingParams(maxLevel, entry);
-	ID3D11SamplerState *state = samplerCache_.GetOrCreateSampler(device_, samplerKey);
-	context_->PSSetSamplers(0, 1, &state);
+	ComPtr<ID3D11SamplerState> state;
+	samplerCache_.GetOrCreateSampler(device_.Get(), samplerKey, &state);
+	context_->PSSetSamplers(0, 1, state.GetAddressOf());
 	gstate_c.SetUseShaderDepal(ShaderDepalMode::OFF);
 }
 
 void TextureCacheD3D11::ApplySamplingParams(const SamplerCacheKey &key) {
-	ID3D11SamplerState *state = samplerCache_.GetOrCreateSampler(device_, key);
-	context_->PSSetSamplers(0, 1, &state);
+	ComPtr<ID3D11SamplerState> state;
+	samplerCache_.GetOrCreateSampler(device_.Get(), key, &state);
+	context_->PSSetSamplers(0, 1, state.GetAddressOf());
 }
 
 void TextureCacheD3D11::Unbind() {
@@ -249,7 +240,7 @@ void TextureCacheD3D11::Unbind() {
 void TextureCacheD3D11::BindAsClutTexture(Draw::Texture *tex, bool smooth) {
 	ID3D11ShaderResourceView *clutTexture = (ID3D11ShaderResourceView *)draw_->GetNativeObject(Draw::NativeObject::TEXTURE_VIEW, tex);
 	context_->PSSetShaderResources(TEX_SLOT_CLUT, 1, &clutTexture);
-	context_->PSSetSamplers(3, 1, smooth ? &stockD3D11.samplerLinear2DClamp : &stockD3D11.samplerPoint2DClamp);
+	context_->PSSetSamplers(3, 1, smooth ? stockD3D11.samplerLinear2DClamp.GetAddressOf() : stockD3D11.samplerPoint2DClamp.GetAddressOf());
 }
 
 void TextureCacheD3D11::BuildTexture(TexCacheEntry *const entry) {
@@ -512,15 +503,14 @@ bool TextureCacheD3D11::GetCurrentTextureDebug(GPUDebugBuffer &buffer, int level
 	desc.Usage = D3D11_USAGE_STAGING;
 	desc.CPUAccessFlags = D3D11_CPU_ACCESS_READ;
 
-	ID3D11Texture2D *stagingCopy = nullptr;
+	ComPtr<ID3D11Texture2D> stagingCopy;
 	device_->CreateTexture2D(&desc, nullptr, &stagingCopy);
 	if (!stagingCopy)
 		return false;
-	context_->CopyResource(stagingCopy, texture);
+	context_->CopyResource(stagingCopy.Get(), texture);
 
 	D3D11_MAPPED_SUBRESOURCE map;
-	if (FAILED(context_->Map(stagingCopy, level, D3D11_MAP_READ, 0, &map))) {
-		stagingCopy->Release();
+	if (FAILED(context_->Map(stagingCopy.Get(), level, D3D11_MAP_READ, 0, &map))) {
 		return false;
 	}
 
@@ -529,13 +519,12 @@ bool TextureCacheD3D11::GetCurrentTextureDebug(GPUDebugBuffer &buffer, int level
 		memcpy(buffer.GetData() + bufferRowSize * y, (const uint8_t *)map.pData + map.RowPitch * y, bufferRowSize);
 	}
 
-	context_->Unmap(stagingCopy, level);
-	stagingCopy->Release();
+	context_->Unmap(stagingCopy.Get(), level);
 	*isFramebuffer = false;
 	return true;
 }
 
-void *TextureCacheD3D11::GetNativeTextureView(const TexCacheEntry *entry) {
+void *TextureCacheD3D11::GetNativeTextureView(const TexCacheEntry *entry, bool flat) const {
 	ID3D11ShaderResourceView *textureView = DxView(entry);
 	return (void *)textureView;
 }
