@@ -22,18 +22,11 @@
 #include "Common/System/OSD.h"
 #include "Common/Profiler/Profiler.h"
 #include "Common/Data/Text/I18n.h"
-#include "Core/Debugger/Breakpoints.h"
-#include "Core/MemMapHelpers.h"
-#include "Core/MIPS/MIPS.h"
 #include "Core/Config.h"
-#include "Core/ConfigValues.h"
-#include "Core/System.h"
 
 #include "Common/GPU/D3D9/D3D9StateCache.h"
 
 #include "GPU/GPUState.h"
-#include "GPU/ge_constants.h"
-#include "GPU/GeDisasm.h"
 
 #include "GPU/Common/FramebufferManagerCommon.h"
 #include "GPU/Directx9/ShaderManagerDX9.h"
@@ -56,6 +49,7 @@ GPU_DX9::GPU_DX9(GraphicsContext *gfxCtx, Draw::DrawContext *draw)
 	drawEngineCommon_ = &drawEngine_;
 	shaderManager_ = shaderManagerDX9_;
 
+	drawEngine_.SetGPUCommon(this);
 	drawEngine_.SetShaderManager(shaderManagerDX9_);
 	drawEngine_.SetTextureCache(textureCacheDX9_);
 	drawEngine_.SetFramebufferManager(framebufferManagerDX9_);
@@ -81,18 +75,19 @@ GPU_DX9::GPU_DX9(GraphicsContext *gfxCtx, Draw::DrawContext *draw)
 
 	// Some of our defaults are different from hw defaults, let's assert them.
 	// We restore each frame anyway, but here is convenient for tests.
-	dxstate.Restore();
 	textureCache_->NotifyConfigChanged();
 
 	if (g_Config.bHardwareTessellation) {
 		// Disable hardware tessellation bacause DX9 is still unsupported.
 		ERROR_LOG(Log::G3D, "Hardware Tessellation is unsupported, falling back to software tessellation");
-		auto gr = GetI18NCategory(I18NCat::GRAPHICS);
-		// TODO: Badly formulated
-		g_OSD.Show(OSDType::MESSAGE_WARNING, gr->T("Turn off Hardware Tessellation - unsupported"));
 	}
 }
 
+void GPU_DX9::FinishInitOnMainThread() {
+	textureCacheDX9_->InitDeviceObjects();
+	dxstate.Restore();
+}
+
 u32 GPU_DX9::CheckGPUFeatures() const {
 	u32 features = GPUCommonHW::CheckGPUFeatures();
 	features |= GPU_USE_16BIT_FORMATS;
