@@ -20,8 +20,8 @@
 #include <string>
 #include <vector>
 
+#include "Common/GPU/thin3d.h"
 #include "GPU/GPUCommonHW.h"
-#include "GPU/Directx9/FramebufferManagerDX9.h"
 #include "GPU/Directx9/DrawEngineDX9.h"
 #include "GPU/Common/TextureShaderCommon.h"
 #include "GPU/Common/VertexDecoderCommon.h"
@@ -29,10 +29,12 @@
 class ShaderManagerDX9;
 class LinkedShaderDX9;
 class TextureCacheDX9;
+class FramebufferManagerDX9;
 
 class GPU_DX9 : public GPUCommonHW {
 public:
 	GPU_DX9(GraphicsContext *gfxCtx, Draw::DrawContext *draw);
+	void FinishInitOnMainThread() override;
 
 	u32 CheckGPUFeatures() const override;
 
