@@ -73,6 +73,13 @@ TextureCacheDX9::TextureCacheDX9(Draw::DrawContext *draw, Draw2D *draw2D)
 	lastBoundTexture = INVALID_TEX;
 	device_ = (LPDIRECT3DDEVICE9)draw->GetNativeObject(Draw::NativeObject::DEVICE);
 	deviceEx_ = (LPDIRECT3DDEVICE9EX)draw->GetNativeObject(Draw::NativeObject::DEVICE_EX);
+}
+
+TextureCacheDX9::~TextureCacheDX9() {
+	Clear(true);
+}
+
+void TextureCacheDX9::InitDeviceObjects() {
 	D3DCAPS9 pCaps;
 	ZeroMemory(&pCaps, sizeof(pCaps));
 	HRESULT result = 0;
@@ -92,10 +99,6 @@ TextureCacheDX9::TextureCacheDX9(Draw::DrawContext *draw, Draw2D *draw2D)
 	device_->CreateVertexDeclaration(g_FramebufferVertexElements, &pFramebufferVertexDecl);
 }
 
-TextureCacheDX9::~TextureCacheDX9() {
-	Clear(true);
-}
-
 void TextureCacheDX9::SetFramebufferManager(FramebufferManagerDX9 *fbManager) {
 	framebufferManager_ = fbManager;
 }
@@ -112,7 +115,7 @@ void TextureCacheDX9::ForgetLastTexture() {
 	lastBoundTexture = INVALID_TEX;
 }
 
-D3DFORMAT getClutDestFormat(GEPaletteFormat format) {
+static D3DFORMAT getClutDestFormat(GEPaletteFormat format) {
 	switch (format) {
 	case GE_CMODE_16BIT_ABGR4444:
 		return D3DFMT_A4R4G4B4;
@@ -436,7 +439,7 @@ bool TextureCacheDX9::GetCurrentTextureDebug(GPUDebugBuffer &buffer, int level,
 	return success;
 }
 
-void *TextureCacheDX9::GetNativeTextureView(const TexCacheEntry *entry) {
+void *TextureCacheDX9::GetNativeTextureView(const TexCacheEntry *entry, bool flat) const {
 	LPDIRECT3DBASETEXTURE9 tex = DxTex(entry);
 	return (void *)tex;
 }
