@@ -661,7 +661,7 @@ void SoftGPU::BeginHostFrame() {
 }
 
 bool SoftGPU::PresentedThisFrame() const {
-	return presentation_->PresentedThisFrame();
+	return presentation_ ? presentation_->PresentedThisFrame() : false;
 }
 
 void SoftGPU::MarkDirty(uint32_t addr, uint32_t stride, uint32_t height, GEBufferFormat fmt, SoftGPUVRAMDirty value) {
@@ -1029,7 +1029,7 @@ void SoftGPU::Execute_FramebufPtr(u32 op, u32 diff) {
 	// We assume fb.data won't change while we're drawing.
 	if (diff) {
 		drawEngine_->transformUnit.Flush(this, "framebuf");
-		fb.data = Memory::GetPointerWrite(gstate.getFrameBufAddress());
+		fb.data = Memory::GetPointerWriteUnchecked(gstate.getFrameBufAddress());
 	}
 }
 
