@@ -15,14 +15,15 @@
 #include "Core/MemMap.h"
 #include "Core/System.h"
 #include "Core/Core.h"
-#include "GPU/GPUInterface.h"
+#include "GPU/GPUCommon.h"
 #include "Common/File/Path.h"
 #include "Common/System/System.h"
 #include "Common/System/Request.h"
 #include "Common/System/NativeApp.h"
-#include "Core/Config.h"
 #include "Common/Data/Text/I18n.h"
 #include "Common/StringUtils.h"
+#include "Core/Config.h"
+#include "Core/Util/RecentFiles.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -397,9 +398,9 @@ void OSXOpenURL(const char *url) {
     takeScreenshotAction.target = self;
     takeScreenshotAction.tag = 9;
 
-    NSMenuItem *dumpNextFrameToLogAction = [[NSMenuItem alloc] initWithTitle:DESKTOPUI_LOCALIZED("Dump Next Frame to Log") action:@selector(dumpNextFrameToLog) keyEquivalent:@""];
-    dumpNextFrameToLogAction.target = self;
-    dumpNextFrameToLogAction.tag = 10;
+    NSMenuItem *saveFrameDumpAction = [[NSMenuItem alloc] initWithTitle:DESKTOPUI_LOCALIZED("Save frame dump") action:@selector(saveFrameDump) keyEquivalent:@""];
+    saveFrameDumpAction.target = self;
+    saveFrameDumpAction.tag = 10;
 
     NSMenuItem *copyBaseAddr = [[NSMenuItem alloc] initWithTitle:DESKTOPUI_LOCALIZED("Copy PSP memory base address") action:@selector(copyAddr) keyEquivalent:@""];
     copyBaseAddr.target = self;
@@ -423,7 +424,7 @@ void OSXOpenURL(const char *url) {
     [parent addItem:[NSMenuItem separatorItem]];
 
     [parent addItem:takeScreenshotAction];
-    [parent addItem:dumpNextFrameToLogAction];
+    [parent addItem:saveFrameDumpAction];
     [parent addItem:showDebugStatsAction];
     [parent addItem:restartGraphicsAction];
 
@@ -438,10 +439,10 @@ void OSXOpenURL(const char *url) {
    std::shared_ptr<I18NCategory> developerUILocalization = GetI18NCategory(I18NCat::DEVELOPER);
 #define DEVELOPERUI_LOCALIZED(key) @(developerUILocalization->T_cstr(key))
     if (Core_IsStepping()) {
-        Core_EnableStepping(false, "ui.break");
+        Core_Resume();
         item.title = DESKTOPUI_LOCALIZED("Break");
     } else {
-        Core_EnableStepping(true, "ui.break");
+        Core_Break(BreakReason::DebugBreak, 0);
         item.title = DEVELOPERUI_LOCALIZED("Resume");
     }
 }
@@ -452,7 +453,7 @@ void OSXOpenURL(const char *url) {
 
 -(void)resetAction: (NSMenuItem *)item {
     System_PostUIMessage(UIMessage::REQUEST_GAME_RESET);
-	Core_EnableStepping(false);
+	Core_Resume();
 }
 
 -(void)chatAction: (NSMenuItem *)item {
@@ -492,8 +493,8 @@ void OSXOpenURL(const char *url) {
     return nil;
 }
 
--(void)dumpNextFrameToLog {
-    gpu->DumpNextFrame();
+-(void)saveFrameDump {
+	System_PostUIMessage(UIMessage::SAVE_FRAME_DUMP);
 }
 
 -(void)takeScreenshot {
@@ -622,14 +623,14 @@ TOGGLE_METHOD(FullScreen, g_Config.bFullScreen, System_MakeRequest(SystemRequest
     std::shared_ptr<I18NCategory> mainmenuLocalization = GetI18NCategory(I18NCat::MAINMENU);
 #define MAINMENU_LOCALIZED(key) @(mainmenuLocalization->T_cstr(key))
 
-    std::vector<std::string> recentIsos = g_Config.RecentIsos();
+    std::vector<std::string> recentFiles = g_recentFiles.GetRecentFiles();
     NSMenuItem *openRecent = [[NSMenuItem alloc] initWithTitle:MAINMENU_LOCALIZED("Recent") action:nil keyEquivalent:@""];
     NSMenu *recentsMenu = [[NSMenu alloc] init];
-    if (recentIsos.empty())
+    if (recentFiles.empty())
         openRecent.enabled = NO;
     
-    for (int i = 0; i < recentIsos.size(); i++) {
-        std::string filename = Path(recentIsos[i]).GetFilename();
+    for (const auto &file : recentFiles) {
+        std::string filename = Path(file).GetFilename();
         NSMenuItem *item = [[NSMenuItem alloc] initWithTitle:@(filename.c_str()) action:@selector(openRecentItem:) keyEquivalent:@""];
         item.target = self;
         [recentsMenu addItem:item];
@@ -640,12 +641,11 @@ TOGGLE_METHOD(FullScreen, g_Config.bFullScreen, System_MakeRequest(SystemRequest
 }
 
 -(void)openRecentItem: (NSMenuItem *)item {
-    System_PostUIMessage(UIMessage::REQUEST_GAME_BOOT, g_Config.RecentIsos()[item.tag].c_str());
+    System_PostUIMessage(UIMessage::REQUEST_GAME_BOOT, g_recentFiles.GetRecentFiles()[item.tag].c_str());
 }
 
 -(void)openSystemFileBrowser {
-    int g = 0;
-    DarwinDirectoryPanelCallback panelCallback = [g] (bool succ, Path thePathChosen) {
+    DarwinDirectoryPanelCallback panelCallback = [] (bool succ, Path thePathChosen) {
         if (succ)
             System_PostUIMessage(UIMessage::REQUEST_GAME_BOOT, thePathChosen.c_str());
     };
