@@ -10,6 +10,18 @@ pub struct Section {
     pub lines: Vec<String>,
 }
 
+pub fn line_value<'a>(line: &'a str) -> Option<&'a str> {
+    let line = line.trim();
+    if let Some(pos) = line.find(" =") {
+        let value = &line[pos + 2..];
+        if value.is_empty() {
+            return None;
+        }
+        return Some(value.trim());
+    }
+    None
+}
+
 impl Section {
     pub fn remove_line(&mut self, key: &str) -> Option<String> {
         let mut remove_index = None;
@@ -33,7 +45,7 @@ impl Section {
         }
     }
 
-    pub fn get_line(&mut self, key: &str) -> Option<String> {
+    pub fn get_line(&self, key: &str) -> Option<String> {
         for line in self.lines.iter() {
             let prefix = if let Some(pos) = line.find(" =") {
                 &line[0..pos]
@@ -116,7 +128,30 @@ impl Section {
             self.insert_line_if_missing(&line);
         } else {
             let name = &self.name;
-            println!("didn't find a line starting with {prefix} in section {name}");
+            println!("rename_key: didn't find a line starting with {prefix} in section {name}");
+        }
+    }
+
+    pub fn dupe_key(&mut self, old: &str, new: &str) {
+        let prefix = old.to_owned() + " =";
+        let mut found_index = None;
+        for (index, line) in self.lines.iter().enumerate() {
+            if line.starts_with(&prefix) {
+                found_index = Some(index);
+            }
+        }
+        if let Some(index) = found_index {
+            let line = self.lines.get(index).unwrap();
+            let mut right_part = line.strip_prefix(&prefix).unwrap().to_string();
+            if right_part.trim() == old.trim() {
+                // Was still untranslated - replace the translation too.
+                right_part = format!(" {}", new);
+            }
+            let line = new.to_owned() + " =" + &right_part;
+            self.insert_line_if_missing(&line);
+        } else {
+            let name = &self.name;
+            println!("dupe_key: didn't find a line starting with {prefix} in section {name}");
         }
     }
 
@@ -163,4 +198,50 @@ impl Section {
             other.lines.iter().any(|line| line.starts_with(prefix))
         });
     }
+
+    pub fn get_keys_if_not_in(&mut self, other: &Section) -> Vec<String> {
+        let mut missing_lines = Vec::new();
+        // Brute force (O(n^2)). Bad but not a problem.
+        for line in &self.lines {
+            let prefix = if let Some(pos) = line.find(" =") {
+                &line[0..pos + 2]
+            } else {
+                // Keep non-key lines.
+                continue;
+            };
+            if prefix.starts_with("Font") || prefix.starts_with('#') {
+                continue;
+            }
+
+            // keeps the line if this expression returns true.
+            if !other.lines.iter().any(|line| line.starts_with(prefix)) {
+                missing_lines.push(prefix[0..prefix.len() - 2].trim().to_string());
+            }
+        }
+        missing_lines
+    }
+
+    // Returns true if the key was found and updated.
+    pub fn set_value(&mut self, key: &str, value: &str) -> bool {
+        let mut found_index = None;
+        for (index, line) in self.lines.iter().enumerate() {
+            let prefix = if let Some(pos) = line.find(" =") {
+                &line[0..pos]
+            } else {
+                continue;
+            };
+
+            if prefix.eq_ignore_ascii_case(key) {
+                found_index = Some(index);
+                break;
+            }
+        }
+
+        if let Some(found_index) = found_index {
+            self.lines[found_index] = format!("{} = {}", key, value);
+            true
+        } else {
+            false
+        }
+    }
 }
