@@ -44,10 +44,6 @@ public:
 
 protected:
 	void CreateViews() override;
-	void CallbackDeleteConfig(bool yes);
-	void CallbackDeleteSaveData(bool yes);
-	void CallbackDeleteGame(bool yes);
-	bool isRecentGame(const Path &gamePath);
 
 private:
 	UI::Choice *AddOtherChoice(UI::Choice *choice);
@@ -59,7 +55,6 @@ private:
 	UI::EventReturn OnDeleteGame(UI::EventParams &e);
 	UI::EventReturn OnSwitchBack(UI::EventParams &e);
 	UI::EventReturn OnRemoveFromRecent(UI::EventParams &e);
-	UI::EventReturn OnShowInFolder(UI::EventParams &e);
 	UI::EventReturn OnCreateConfig(UI::EventParams &e);
 	UI::EventReturn OnDeleteConfig(UI::EventParams &e);
 	UI::EventReturn OnCwCheat(UI::EventParams &e);
@@ -87,7 +82,6 @@ private:
 	UI::Choice *btnCalcCRC_ = nullptr;
 
 	std::vector<UI::Choice *> otherChoices_;
-	std::vector<Path> saveDirs;
 	std::string CRC32string;
 
 	bool isHomebrew_ = false;
