@@ -46,10 +46,21 @@ struct ThemeInfo {
 	uint32_t uItemDisabledStyleBg = 0x55000000;
 
 	uint32_t uHeaderStyleFg = 0xFFFFFFFF;
+	uint32_t uHeaderStyleBg = 0x00000000;
 	uint32_t uInfoStyleFg = 0xFFFFFFFF;
 	uint32_t uInfoStyleBg = 0x00000000;
-	uint32_t uPopupStyleBg = 0xFF303030;
+	uint32_t uPopupStyleFg = 0xFFFFFFFF;
+	uint32_t uPopupStyleBg = 0xFF5E4D1F;
+	uint32_t uPopupTitleStyleFg = 0xFFFFFFFF;
+	uint32_t uPopupTitleStyleBg = 0x00000000;  // default to invisible
+	uint32_t uTooltipStyleFg = 0xFFFFFFFF;
+	uint32_t uTooltipStyleBg = 0xC0303030;
+	uint32_t uCollapsibleHeaderStyleFg = 0xFFFFFFFF;
+	uint32_t uCollapsibleHeaderStyleBg = 0x55000000;
 	uint32_t uBackgroundColor = 0xFF754D24;
+	uint32_t uScrollbarColor = 0x80FFFFFF;
+	uint32_t uPopupSliderColor = 0xFFFFFFFF;
+	uint32_t uPopupSliderFocusedColor = 0xFFEDC24C;
 
 	std::string sUIAtlas = "ui_atlas";
 
@@ -132,22 +143,39 @@ static void LoadThemeInfo(const std::vector<Path> &directories) {
 				section.Get("ItemDisabledStyleBg", &info.uItemDisabledStyleBg, info.uItemDisabledStyleBg);
 
 				section.Get("HeaderStyleFg", &info.uHeaderStyleFg, info.uHeaderStyleFg);
+				section.Get("HeaderStyleBg", &info.uHeaderStyleBg, info.uHeaderStyleBg);
 				section.Get("InfoStyleFg", &info.uInfoStyleFg, info.uInfoStyleFg);
 				section.Get("InfoStyleBg", &info.uInfoStyleBg, info.uInfoStyleBg);
+				section.Get("PopupStyleFg", &info.uPopupStyleFg, info.uItemStyleFg);  // Backwards compat
 				section.Get("PopupStyleBg", &info.uPopupStyleBg, info.uPopupStyleBg);
+				section.Get("TooltipStyleFg", &info.uTooltipStyleFg, info.uTooltipStyleFg);  // Backwards compat
+				section.Get("TooltipStyleBg", &info.uTooltipStyleBg, info.uTooltipStyleBg);
+				section.Get("PopupTitleStyleFg", &info.uPopupTitleStyleFg, info.uItemStyleFg);  // Backwards compat
+				section.Get("PopupTitleStyleBg", &info.uPopupTitleStyleBg, info.uPopupTitleStyleBg);
+				section.Get("CollapsibleHeaderStyleFg", &info.uCollapsibleHeaderStyleFg, info.uItemStyleFg);  // Backwards compat
+				section.Get("CollapsibleHeaderStyleBg", &info.uCollapsibleHeaderStyleBg, info.uItemStyleBg);
 				section.Get("BackgroundColor", &info.uBackgroundColor, info.uBackgroundColor);
+				section.Get("ScrollbarColor", &info.uScrollbarColor, info.uScrollbarColor);
+				section.Get("PopupSliderColor", &info.uPopupSliderColor, info.uPopupSliderColor);
+				section.Get("PopupSliderFocusedColor", &info.uPopupSliderFocusedColor, info.uPopupSliderFocusedColor);
 
 				std::string tmpPath;
 				section.Get("UIAtlas", &tmpPath, "");
 				if (!tmpPath.empty()) {
-					tmpPath = (path / tmpPath).ToString();
-
-					File::FileInfo tmpInfo;
-					if (g_VFS.GetFileInfo((tmpPath + ".meta").c_str(), &tmpInfo) && g_VFS.GetFileInfo((tmpPath + ".zim").c_str(), &tmpInfo)) {
-						info.sUIAtlas = tmpPath;
+					if (tmpPath == "../ui_atlas") {
+						// Do nothing.
+					} else {
+						// WARNING: Note that the below appears to be entirely broken. ..-navigation doesn't work on zip VFS.
+						INFO_LOG(Log::System, "Checking %s", tmpPath.c_str());
+						tmpPath = (path / tmpPath).ToString();
+						if (g_VFS.Exists((tmpPath + ".meta").c_str()) && g_VFS.Exists((tmpPath + ".zim").c_str())) {
+							// INFO_LOG(Log::System, "%s exists", tmpPath.c_str());
+							info.sUIAtlas = tmpPath;
+						} else {
+							INFO_LOG(Log::System, "%s.meta/zim doesn't exist, not overriding atlas", tmpPath.c_str());
+						}
 					}
 				}
-
 				appendTheme(info);
 			}
 		}
@@ -181,17 +209,26 @@ void UpdateTheme(UIContext *ctx) {
 		ReloadAllThemeInfo();
 	}
 
-	size_t i;
-	for (i = 0; i < themeInfos.size(); ++i) {
+	int defaultThemeIndex = -1;
+	int selectedThemeIndex = -1;
+	for (int i = 0; i < themeInfos.size(); ++i) {
+		if (themeInfos[i].name == "Default") {
+			defaultThemeIndex = i;
+		}
 		if (themeInfos[i].name == g_Config.sThemeName) {
-			break;
+			selectedThemeIndex = i;
 		}
 	}
 
 	// Reset to Default if not found
-	if (i >= themeInfos.size()) {
+	if (selectedThemeIndex < 0 || selectedThemeIndex >= themeInfos.size()) {
 		g_Config.sThemeName = "Default";
-		i = 0;
+		selectedThemeIndex = defaultThemeIndex;
+		if (selectedThemeIndex < 0) {
+			_dbg_assert_(false);
+			// No themes? Bad.
+			return;
+		}
 	}
 
 #if defined(USING_WIN_UI) || PPSSPP_PLATFORM(UWP) || defined(USING_QT_UI)
@@ -210,27 +247,38 @@ void UpdateTheme(UIContext *ctx) {
 	ui_theme.sliderKnob = ImageID("I_CIRCLE");
 	ui_theme.dropShadow4Grid = ImageID("I_DROP_SHADOW");
 
+	const ThemeInfo &themeInfo = themeInfos[selectedThemeIndex];
+
 	// Actual configurable themes setting start here
-	ui_theme.itemStyle = MakeStyle(themeInfos[i].uItemStyleFg, themeInfos[i].uItemStyleBg);
-	ui_theme.itemFocusedStyle = MakeStyle(themeInfos[i].uItemFocusedStyleFg, themeInfos[i].uItemFocusedStyleBg);
-	ui_theme.itemDownStyle = MakeStyle(themeInfos[i].uItemDownStyleFg, themeInfos[i].uItemDownStyleBg);
-	ui_theme.itemDisabledStyle = MakeStyle(themeInfos[i].uItemDisabledStyleFg, themeInfos[i].uItemDisabledStyleBg);
+	ui_theme.itemStyle = MakeStyle(themeInfo.uItemStyleFg, themeInfo.uItemStyleBg);
+	ui_theme.itemFocusedStyle = MakeStyle(themeInfo.uItemFocusedStyleFg, themeInfo.uItemFocusedStyleBg);
+	ui_theme.itemDownStyle = MakeStyle(themeInfo.uItemDownStyleFg, themeInfo.uItemDownStyleBg);
+	ui_theme.itemDisabledStyle = MakeStyle(themeInfo.uItemDisabledStyleFg, themeInfo.uItemDisabledStyleBg);
 
-	ui_theme.headerStyle.fgColor = themeInfos[i].uHeaderStyleFg;
-	ui_theme.infoStyle = MakeStyle(themeInfos[i].uInfoStyleFg, themeInfos[i].uInfoStyleBg);
+	ui_theme.headerStyle = MakeStyle(themeInfo.uHeaderStyleFg, themeInfo.uHeaderStyleBg);
+	ui_theme.collapsibleHeaderStyle = MakeStyle(themeInfo.uCollapsibleHeaderStyleFg, themeInfo.uCollapsibleHeaderStyleBg);
+	ui_theme.infoStyle = MakeStyle(themeInfo.uInfoStyleFg, themeInfo.uInfoStyleBg);
 
-	ui_theme.popupStyle = MakeStyle(themeInfos[i].uItemStyleFg, themeInfos[i].uPopupStyleBg);
-	ui_theme.backgroundColor = themeInfos[i].uBackgroundColor;
+	ui_theme.popupStyle = MakeStyle(themeInfo.uPopupStyleFg, themeInfo.uPopupStyleBg);
+	ui_theme.popupTitleStyle = MakeStyle(themeInfo.uPopupTitleStyleFg, themeInfo.uPopupTitleStyleBg);
+
+	ui_theme.tooltipStyle = MakeStyle(themeInfo.uTooltipStyleFg, themeInfo.uTooltipStyleBg);
+
+	ui_theme.backgroundColor = themeInfo.uBackgroundColor;
+	ui_theme.scrollbarColor = themeInfo.uScrollbarColor;
+
+	ui_theme.popupSliderColor = themeInfo.uPopupSliderColor;
+	ui_theme.popupSliderFocusedColor = themeInfo.uPopupSliderFocusedColor;
 
 	// Load any missing atlas metadata (the images are loaded from UIContext).
-	LoadAtlasMetadata(ui_atlas, (themeInfos[i].sUIAtlas + ".meta").c_str(), true);
+	LoadAtlasMetadata(ui_atlas, (themeInfo.sUIAtlas + ".meta").c_str(), true);
 #if !(PPSSPP_PLATFORM(WINDOWS) || PPSSPP_PLATFORM(ANDROID))
 	LoadAtlasMetadata(font_atlas, "font_atlas.meta", ui_atlas.num_fonts == 0);
 #else
 	LoadAtlasMetadata(font_atlas, "asciifont_atlas.meta", ui_atlas.num_fonts == 0);
 #endif
 
-	ctx->setUIAtlas(themeInfos[i].sUIAtlas + ".zim");
+	ctx->setUIAtlas(themeInfo.sUIAtlas + ".zim");
 }
 
 UI::Theme *GetTheme() {
