@@ -158,7 +158,7 @@ void CtrlThreadList::showMenu(int itemIndex, const POINT &pt)
 	}
 }
 
-void CtrlThreadList::GetColumnText(wchar_t* dest, int row, int col)
+void CtrlThreadList::GetColumnText(wchar_t* dest, size_t destSize, int row, int col)
 {
 	if (row < 0 || row >= (int)threads.size()) {
 		return;
@@ -217,7 +217,7 @@ void CtrlThreadList::GetColumnText(wchar_t* dest, int row, int col)
 		}
 		break;
 	case TL_WAITTYPE:
-		wcscpy(dest, ConvertUTF8ToWString(getWaitTypeName(threads[row].waitType)).c_str());
+		wcscpy(dest, ConvertUTF8ToWString(WaitTypeToString(threads[row].waitType)).c_str());
 		break;
 	}
 }
@@ -265,7 +265,7 @@ const char* CtrlThreadList::getCurrentThreadName()
 // CtrlBreakpointList
 //
 
-CtrlBreakpointList::CtrlBreakpointList(HWND hwnd, DebugInterface* cpu, CtrlDisAsmView* disasm)
+CtrlBreakpointList::CtrlBreakpointList(HWND hwnd, MIPSDebugInterface* cpu, CtrlDisAsmView* disasm)
 	: GenericListControl(hwnd,breakpointListDef),cpu(cpu),disasm(disasm)
 {
 	SetSendInvalidRows(true);
@@ -317,8 +317,8 @@ bool CtrlBreakpointList::WindowMessage(UINT msg, WPARAM wParam, LPARAM lParam, L
 void CtrlBreakpointList::reloadBreakpoints()
 {
 	// Update the items we're displaying from the debugger.
-	displayedBreakPoints_ = CBreakPoints::GetBreakpoints();
-	displayedMemChecks_= CBreakPoints::GetMemChecks();
+	displayedBreakPoints_ = g_breakpoints.GetBreakpoints();
+	displayedMemChecks_= g_breakpoints.GetMemChecks();
 
 	for (int i = 0; i < GetRowCount(); i++)
 	{
@@ -349,7 +349,7 @@ void CtrlBreakpointList::editBreakpoint(int itemIndex)
 		win.loadFromMemcheck(mem);
 		if (win.exec())
 		{
-			CBreakPoints::RemoveMemCheck(mem.start,mem.end);
+			g_breakpoints.RemoveMemCheck(mem.start,mem.end);
 			win.addBreakpoint();
 		}
 	} else {
@@ -357,7 +357,7 @@ void CtrlBreakpointList::editBreakpoint(int itemIndex)
 		win.loadFromBreakpoint(bp);
 		if (win.exec())
 		{
-			CBreakPoints::RemoveBreakPoint(bp.addr);
+			g_breakpoints.RemoveBreakPoint(bp.addr);
 			win.addBreakpoint();
 		}
 	}
@@ -371,10 +371,10 @@ void CtrlBreakpointList::toggleEnabled(int itemIndex)
 
 	if (isMemory) {
 		MemCheck mcPrev = displayedMemChecks_[index];
-		CBreakPoints::ChangeMemCheck(mcPrev.start, mcPrev.end, mcPrev.cond, BreakAction(mcPrev.result ^ BREAK_ACTION_PAUSE));
+		g_breakpoints.ChangeMemCheck(mcPrev.start, mcPrev.end, mcPrev.cond, BreakAction(mcPrev.result ^ BREAK_ACTION_PAUSE));
 	} else {
 		BreakPoint bpPrev = displayedBreakPoints_[index];
-		CBreakPoints::ChangeBreakPoint(bpPrev.addr, BreakAction(bpPrev.result ^ BREAK_ACTION_PAUSE));
+		g_breakpoints.ChangeBreakPoint(bpPrev.addr, BreakAction(bpPrev.result ^ BREAK_ACTION_PAUSE));
 	}
 }
 
@@ -404,13 +404,12 @@ void CtrlBreakpointList::removeBreakpoint(int itemIndex)
 	int index = getBreakpointIndex(itemIndex,isMemory);
 	if (index == -1) return;
 
-	if (isMemory)
-	{
+	if (isMemory) {
 		auto mc = displayedMemChecks_[index];
-		CBreakPoints::RemoveMemCheck(mc.start, mc.end);
+		g_breakpoints.RemoveMemCheck(mc.start, mc.end);
 	} else {
 		u32 address = displayedBreakPoints_[index].addr;
-		CBreakPoints::RemoveBreakPoint(address);
+		g_breakpoints.RemoveBreakPoint(address);
 	}
 }
 
@@ -458,7 +457,7 @@ int CtrlBreakpointList::getBreakpointIndex(int itemIndex, bool& isMemory)
 	return -1;
 }
 
-void CtrlBreakpointList::GetColumnText(wchar_t* dest, int row, int col)
+void CtrlBreakpointList::GetColumnText(wchar_t* dest, size_t destSize, int row, int col)
 {
 	if (!PSP_IsInited()) {
 		return;
@@ -490,7 +489,7 @@ void CtrlBreakpointList::GetColumnText(wchar_t* dest, int row, int col)
 					break;
 				}
 			} else {
-				wcscpy(dest,L"Execute");
+				wcscpy(dest, L"Execute");
 			}
 		}
 		break;
@@ -513,10 +512,8 @@ void CtrlBreakpointList::GetColumnText(wchar_t* dest, int row, int col)
 					wsprintf(dest,L"0x%08X",mc.end-mc.start);
 			} else {
 				const std::string sym = g_symbolMap->GetLabelString(displayedBreakPoints_[index].addr);
-				if (!sym.empty())
-				{
-					std::wstring s = ConvertUTF8ToWString(sym);
-					wcscpy(dest,s.c_str());
+				if (!sym.empty()) {
+					ConvertUTF8ToWString(dest, destSize, sym);
 				} else {
 					wcscpy(dest,L"-");
 				}
@@ -530,8 +527,7 @@ void CtrlBreakpointList::GetColumnText(wchar_t* dest, int row, int col)
 			} else {
 				char temp[256];
 				disasm->getOpcodeText(displayedBreakPoints_[index].addr, temp, sizeof(temp));
-				std::wstring s = ConvertUTF8ToWString(temp);
-				wcscpy(dest,s.c_str());
+				ConvertUTF8ToWString(dest, destSize, temp);
 			}
 		}
 		break;
@@ -612,9 +608,9 @@ void CtrlBreakpointList::showBreakpointMenu(int itemIndex, const POINT &pt)
 		{
 		case ID_DISASM_DISABLEBREAKPOINT:
 			if (isMemory) {
-				CBreakPoints::ChangeMemCheck(mcPrev.start, mcPrev.end, mcPrev.cond, BreakAction(mcPrev.result ^ BREAK_ACTION_PAUSE));
+				g_breakpoints.ChangeMemCheck(mcPrev.start, mcPrev.end, mcPrev.cond, BreakAction(mcPrev.result ^ BREAK_ACTION_PAUSE));
 			} else {
-				CBreakPoints::ChangeBreakPoint(bpPrev.addr, BreakAction(bpPrev.result ^ BREAK_ACTION_PAUSE));
+				g_breakpoints.ChangeBreakPoint(bpPrev.addr, BreakAction(bpPrev.result ^ BREAK_ACTION_PAUSE));
 			}
 			break;
 		case ID_DISASM_EDITBREAKPOINT:
@@ -670,7 +666,7 @@ bool CtrlStackTraceView::WindowMessage(UINT msg, WPARAM wParam, LPARAM lParam, L
 	return false;
 }
 
-void CtrlStackTraceView::GetColumnText(wchar_t* dest, int row, int col)
+void CtrlStackTraceView::GetColumnText(wchar_t* dest, size_t destSize, int row, int col)
 {
 	// We should have emptied the list if g_symbolMap is nullptr, but apparently we don't,
 	// so let's have a sanity check here.
@@ -780,16 +776,15 @@ bool CtrlModuleList::WindowMessage(UINT msg, WPARAM wParam, LPARAM lParam, LRESU
 	return false;
 }
 
-void CtrlModuleList::GetColumnText(wchar_t* dest, int row, int col)
+void CtrlModuleList::GetColumnText(wchar_t* dest, size_t destSize, int row, int col)
 {
 	if (row < 0 || row >= (int)modules.size()) {
 		return;
 	}
 
-	switch (col)
-	{
+	switch (col) {
 	case ML_NAME:
-		wcscpy(dest,ConvertUTF8ToWString(modules[row].name).c_str());
+		ConvertUTF8ToWString(dest, destSize, modules[row].name);
 		break;
 	case ML_ADDRESS:
 		wsprintf(dest,L"%08X",modules[row].address);
@@ -840,7 +835,7 @@ void CtrlWatchList::RefreshValues() {
 		}
 
 		uint32_t prevValue = watch.currentValue;
-		watch.evaluateFailed = !cpu_->parseExpression(watch.expression, watch.currentValue);
+		watch.evaluateFailed = !parseExpression(cpu_, watch.expression, watch.currentValue);
 		if (prevValue != watch.currentValue)
 			changes = true;
 	}
@@ -888,7 +883,7 @@ bool CtrlWatchList::WindowMessage(UINT msg, WPARAM wParam, LPARAM lParam, LRESUL
 	return false;
 }
 
-void CtrlWatchList::GetColumnText(wchar_t *dest, int row, int col) {
+void CtrlWatchList::GetColumnText(wchar_t *dest, size_t destSize, int row, int col) {
 	const auto &watch = watches_[row];
 	switch (col) {
 	case WL_NAME:
@@ -914,12 +909,12 @@ void CtrlWatchList::GetColumnText(wchar_t *dest, int row, int col) {
 				break;
 			case WatchFormat::FLOAT:
 				memcpy(&valuef, &value, sizeof(valuef));
-				swprintf_s(dest, 255, L"%f", valuef);
+				swprintf_s(dest, destSize, L"%f", valuef);
 				break;
 			case WatchFormat::STR:
 				if (Memory::IsValidAddress(value)) {
 					uint32_t len = Memory::ValidSize(value, 255);
-					swprintf_s(dest, 255, L"%.*S", len, Memory::GetCharPointer(value));
+					swprintf_s(dest, destSize, L"%.*S", len, Memory::GetCharPointer(value));
 				} else {
 					wsprintf(dest, L"(0x%08X)", value);
 				}
@@ -964,7 +959,7 @@ void CtrlWatchList::AddWatch() {
 	WatchItemWindow win(nullptr, GetHandle(), cpu_);
 	if (win.Exec()) {
 		WatchInfo info;
-		if (cpu_->initExpression(win.GetExpression().c_str(), info.expression)) {
+		if (initExpression(cpu_, win.GetExpression().c_str(), info.expression)) {
 			info.name = win.GetName();
 			info.originalExpression = win.GetExpression();
 			info.format = win.GetFormat();
@@ -983,7 +978,7 @@ void CtrlWatchList::EditWatch(int pos) {
 	WatchItemWindow win(nullptr, GetHandle(), cpu_);
 	win.Init(watch.name, watch.originalExpression, watch.format);
 	if (win.Exec()) {
-		if (cpu_->initExpression(win.GetExpression().c_str(), watch.expression)) {
+		if (initExpression(cpu_, win.GetExpression().c_str(), watch.expression)) {
 			watch.name = win.GetName();
 			watch.originalExpression = win.GetExpression();
 			watch.format = win.GetFormat();
