@@ -32,6 +32,7 @@
 #include "GPU/Common/GPUDebugInterface.h"
 #include "GPU/Debugger/Breakpoints.h"
 #include "GPU/Debugger/Stepping.h"
+#include "GPU/Debugger/State.h"
 
 static const GenericListViewColumn vertexListCols[] = {
 	{ L"X", 0.1f },
@@ -50,18 +51,6 @@ GenericListViewDef vertexListDef = {
 	vertexListCols,	ARRAY_SIZE(vertexListCols),	NULL,	false
 };
 
-enum VertexListCols {
-	VERTEXLIST_COL_X,
-	VERTEXLIST_COL_Y,
-	VERTEXLIST_COL_Z,
-	VERTEXLIST_COL_U,
-	VERTEXLIST_COL_V,
-	VERTEXLIST_COL_COLOR,
-	VERTEXLIST_COL_NX,
-	VERTEXLIST_COL_NY,
-	VERTEXLIST_COL_NZ,
-};
-
 static const GenericListViewColumn matrixListCols[] = {
 	{ L"", 0.03f },
 	{ L"Name", 0.21f },
@@ -138,7 +127,7 @@ CtrlVertexList::~CtrlVertexList() {
 	delete decoder;
 }
 
-void CtrlVertexList::GetColumnText(wchar_t *dest, int row, int col) {
+void CtrlVertexList::GetColumnText(wchar_t *dest, size_t destSize, int row, int col) {
 	if (row < 0 || row >= rowCount_ ) {
 		wcscpy(dest, L"Invalid");
 		return;
@@ -146,133 +135,24 @@ void CtrlVertexList::GetColumnText(wchar_t *dest, int row, int col) {
 
 	if (!indices.empty()) {
 		if (row >= (int)indices.size()) {
-			swprintf(dest, 255, L"Invalid indice %d", row);
+			swprintf(dest, destSize, L"Invalid index %d", row);
 			return;
 		}
 		row = indices[row];
 	}
 
+	char temp[256];
 	if (raw_) {
-		FormatVertColRaw(dest, row, col);
+		FormatVertColRaw(decoder, temp, sizeof(temp), row, col);
 	} else {
 		if (row >= (int)vertices.size()) {
-			swprintf(dest, 255, L"Invalid vertex %d", row);
+			swprintf(dest, destSize, L"Invalid vertex %d", row);
 			return;
 		}
 
-		FormatVertCol(dest, vertices[row], col);
-	}
-}
-
-void CtrlVertexList::FormatVertCol(wchar_t *dest, const GPUDebugVertex &vert, int col) {
-	switch (col) {
-	case VERTEXLIST_COL_X: swprintf(dest, 255, L"%f", vert.x); break;
-	case VERTEXLIST_COL_Y: swprintf(dest, 255, L"%f", vert.y); break;
-	case VERTEXLIST_COL_Z: swprintf(dest, 255, L"%f", vert.z); break;
-	case VERTEXLIST_COL_U: swprintf(dest, 255, L"%f", vert.u); break;
-	case VERTEXLIST_COL_V: swprintf(dest, 255, L"%f", vert.v); break;
-	case VERTEXLIST_COL_COLOR:
-		swprintf(dest, 255, L"%02x%02x%02x%02x", vert.c[0], vert.c[1], vert.c[2], vert.c[3]);
-		break;
-	case VERTEXLIST_COL_NX: swprintf(dest, 255, L"%f", vert.nx); break;
-	case VERTEXLIST_COL_NY: swprintf(dest, 255, L"%f", vert.ny); break;
-	case VERTEXLIST_COL_NZ: swprintf(dest, 255, L"%f", vert.nz); break;
-
-	default:
-		wcscpy(dest, L"Invalid");
-		break;
-	}
-}
-
-void CtrlVertexList::FormatVertColRaw(wchar_t *dest, int row, int col) {
-	auto memLock = Memory::Lock();
-	if (!PSP_IsInited()) {
-		wcscpy(dest, L"Invalid");
-		return;
-	}
-
-	// We could use the vertex decoder and reader, but those already do some minor adjustments.
-	// There's only a few values - let's just go after them directly.
-	const u8 *vert = Memory::GetPointer(gpuDebug->GetVertexAddress()) + row * decoder->size;
-	const u8 *pos = vert + decoder->posoff;
-	const u8 *tc = vert + decoder->tcoff;
-	const u8 *color = vert + decoder->coloff;
-	const u8 *norm = vert + decoder->nrmoff;
-
-	switch (col) {
-	case VERTEXLIST_COL_X:
-		FormatVertColRawType(dest, pos, decoder->pos, 0);
-		break;
-	case VERTEXLIST_COL_Y:
-		FormatVertColRawType(dest, pos, decoder->pos, 1);
-		break;
-	case VERTEXLIST_COL_Z:
-		FormatVertColRawType(dest, pos, decoder->pos, 2);
-		break;
-	case VERTEXLIST_COL_U:
-		FormatVertColRawType(dest, tc, decoder->tc, 0);
-		break;
-	case VERTEXLIST_COL_V:
-		FormatVertColRawType(dest, tc, decoder->tc, 1);
-		break;
-	case VERTEXLIST_COL_COLOR:
-		FormatVertColRawColor(dest, color, decoder->col);
-		break;
-
-	case VERTEXLIST_COL_NX: FormatVertColRawType(dest, norm, decoder->nrm, 0); break;
-	case VERTEXLIST_COL_NY: FormatVertColRawType(dest, norm, decoder->nrm, 1); break;
-	case VERTEXLIST_COL_NZ: FormatVertColRawType(dest, norm, decoder->nrm, 2); break;
-
-	default:
-		wcscpy(dest, L"Invalid");
-		break;
-	}
-}
-
-void CtrlVertexList::FormatVertColRawType(wchar_t *dest, const void *data, int type, int offset) {
-	switch (type) {
-	case 0:
-		wcscpy(dest, L"-");
-		break;
-
-	case 1: // 8-bit
-		swprintf(dest, 255, L"%02x", ((const u8 *)data)[offset]);
-		break;
-
-	case 2: // 16-bit
-		swprintf(dest, 255, L"%04x", ((const u16_le *)data)[offset]);
-		break;
-
-	case 3: // float
-		swprintf(dest, 255, L"%f", ((const float *)data)[offset]);
-		break;
-
-	default:
-		wcscpy(dest, L"Invalid");
-		break;
-	}
-}
-
-void CtrlVertexList::FormatVertColRawColor(wchar_t *dest, const void *data, int type) {
-	switch (type) {
-	case GE_VTYPE_COL_NONE >> GE_VTYPE_COL_SHIFT:
-		wcscpy(dest, L"-");
-		break;
-
-	case GE_VTYPE_COL_565 >> GE_VTYPE_COL_SHIFT:
-	case GE_VTYPE_COL_5551 >> GE_VTYPE_COL_SHIFT:
-	case GE_VTYPE_COL_4444 >> GE_VTYPE_COL_SHIFT:
-		swprintf(dest, 255, L"%04x", *(const u16_le *)data);
-		break;
-
-	case GE_VTYPE_COL_8888 >> GE_VTYPE_COL_SHIFT:
-		swprintf(dest, 255, L"%08x", *(const u32_le *)data);
-		break;
-
-	default:
-		wcscpy(dest, L"Invalid");
-		break;
+		FormatVertCol(temp, sizeof(temp), vertices[row], col);
 	}
+	ConvertUTF8ToWString(dest, destSize, temp);
 }
 
 int CtrlVertexList::GetRowCount() {
@@ -288,28 +168,15 @@ int CtrlVertexList::GetRowCount() {
 
 	// TODO: Maybe there are smarter ways?  Also, is this the best place to recalc?
 	auto state = gpuDebug->GetGState();
-	rowCount_ = state.prim & 0xFFFF;
 
-	// Override if we're on a prim command.
-	DisplayList list;
-	if (gpuDebug->GetCurrentDisplayList(list)) {
-		u32 cmd = Memory::Read_U32(list.pc);
-		if ((cmd >> 24) == GE_CMD_PRIM || (cmd >> 24) == GE_CMD_BOUNDINGBOX) {
-			rowCount_ = cmd & 0xFFFF;
-		} else if ((cmd >> 24) == GE_CMD_BEZIER || (cmd >> 24) == GE_CMD_SPLINE) {
-			u32 u = (cmd & 0x00FF) >> 0;
-			u32 v = (cmd & 0xFF00) >> 8;
-			rowCount_ = u * v;
-		}
-	}
-
-	if (!gpuDebug->GetCurrentSimpleVertices(rowCount_, vertices, indices)) {
+	int rowCount_ = gpuDebug->GetCurrentPrimCount();
+	if (!gpuDebug->GetCurrentDrawAsDebugVertices(rowCount_, vertices, indices)) {
 		rowCount_ = 0;
 	}
 	VertexDecoderOptions options{};
 	// TODO: Maybe an option?
-	options.applySkinInDecode = true;
-	decoder->SetVertexType(state.vertType, options);
+	u32 vertTypeID = GetVertTypeID(state.vertType, state.getUVGenMode(), true);
+	decoder->SetVertexType(vertTypeID, options);
 	return rowCount_;
 }
 
@@ -461,7 +328,7 @@ bool CtrlMatrixList::GetValue(const GPUgstate &state, int row, int col, float &v
 	return true;
 }
 
-void CtrlMatrixList::GetColumnText(wchar_t *dest, int row, int col) {
+void CtrlMatrixList::GetColumnText(wchar_t *dest, size_t destSize, int row, int col) {
 	if (col == MATRIXLIST_COL_BREAKPOINT) {
 		wcscpy(dest, L" ");
 		return;
@@ -570,16 +437,16 @@ void CtrlMatrixList::ToggleBreakpoint(int row) {
 		return;
 
 	// Okay, this command is in range.  Toggle the actual breakpoint.
-	bool state = !GPUBreakpoints::IsCmdBreakpoint(info->cmd);
+	bool state = !gpuDebug->GetBreakpoints()->IsCmdBreakpoint(info->cmd);
 	if (state) {
-		GPUBreakpoints::AddCmdBreakpoint(info->cmd);
+		gpuDebug->GetBreakpoints()->AddCmdBreakpoint(info->cmd);
 	} else {
-		if (GPUBreakpoints::GetCmdBreakpointCond(info->cmd, nullptr)) {
+		if (gpuDebug->GetBreakpoints()->GetCmdBreakpointCond(info->cmd, nullptr)) {
 			int ret = MessageBox(GetHandle(), L"This breakpoint has a custom condition.\nDo you want to remove it?", L"Confirmation", MB_YESNO);
 			if (ret != IDYES)
 				return;
 		}
-		GPUBreakpoints::RemoveCmdBreakpoint(info->cmd);
+		gpuDebug->GetBreakpoints()->RemoveCmdBreakpoint(info->cmd);
 	}
 
 	for (int r = info->row; r < (info + 1)->row; ++r) {
@@ -593,12 +460,12 @@ void CtrlMatrixList::PromptBreakpointCond(int row) {
 		return;
 
 	std::string expression;
-	GPUBreakpoints::GetCmdBreakpointCond(info->cmd, &expression);
+	gpuDebug->GetBreakpoints()->GetCmdBreakpointCond(info->cmd, &expression);
 	if (!InputBox_GetString(GetModuleHandle(NULL), GetHandle(), L"Expression", expression, expression))
 		return;
 
 	std::string error;
-	if (!GPUBreakpoints::SetCmdBreakpointCond(info->cmd, expression, &error))
+	if (!gpuDebug->GetBreakpoints()->SetCmdBreakpointCond(info->cmd, expression, &error))
 		MessageBox(GetHandle(), ConvertUTF8ToWString(error).c_str(), L"Invalid expression", MB_OK | MB_ICONEXCLAMATION);
 }
 
@@ -623,7 +490,7 @@ void CtrlMatrixList::OnDoubleClick(int row, int column) {
 	if (sscanf(strvalue.c_str(), "%f", &val) == 1) {
 		auto prevState = gpuDebug->GetGState();
 		auto setCmdValue = [&](u32 op) {
-			SendMessage(GetParent(GetParent(GetHandle())), WM_GEDBG_SETCMDWPARAM, op, NULL);
+			SendMessage(GetParent(GetParent(GetHandle())), WM_GEDBG_SETCMDWPARAM, op, 0);
 		};
 
 		union {
@@ -664,7 +531,7 @@ void CtrlMatrixList::OnRightClick(int row, int column, const POINT &point) {
 
 	HMENU subMenu = GetContextMenu(ContextMenuID::GEDBG_MATRIX);
 	SetMenuDefaultItem(subMenu, ID_REGLIST_CHANGE, FALSE);
-	EnableMenuItem(subMenu, ID_GEDBG_SETCOND, info && GPUBreakpoints::IsCmdBreakpoint(info->cmd) ? MF_ENABLED : MF_GRAYED);
+	EnableMenuItem(subMenu, ID_GEDBG_SETCOND, info && gpuDebug->GetBreakpoints()->IsCmdBreakpoint(info->cmd) ? MF_ENABLED : MF_GRAYED);
 
 	switch (TriggerContextMenu(ContextMenuID::GEDBG_MATRIX, GetHandle(), ContextPoint::FromClient(point))) {
 	case ID_DISASM_TOGGLEBREAKPOINT:
