@@ -20,6 +20,7 @@ namespace MainWindow
 		WM_USER_RESTART_EMUTHREAD = WM_USER + 106,
 		WM_USER_SWITCHUMD_UPDATED = WM_USER + 107,
 		WM_USER_RUN_CALLBACK = WM_USER + 108,
+		WM_USER_DESTROY = WM_USER + 109,
 	};
 
 	enum {
@@ -82,6 +83,8 @@ namespace MainWindow
 	void SetWindowSize(int zoom);
 	void RunCallbackInWndProc(void (*callback)(void *window, void *userdata), void *userdata);
 	void SetKeepScreenBright(bool keepBright);
+
+	bool ConfirmAction(HWND hWnd, bool actionIsReset);
 }
 
 #endif
