@@ -37,4 +37,4 @@ extern CGEDebugger* geDebuggerWindow;
 
 extern int g_activeWindow;
 
-enum { WINDOW_MAINWINDOW, WINDOW_CPUDEBUGGER, WINDOW_GEDEBUGGER };
+enum { WINDOW_MAINWINDOW, WINDOW_CPUDEBUGGER, WINDOW_GEDEBUGGER, WINDOW_OTHER };
