@@ -2,7 +2,7 @@
 
 #include "rc_api_runtime.h" /* for rc_fetch_image */
 
-#include "rc_compat.h"
+#include "../rc_compat.h"
 
 #include "../test_framework.h"
 
@@ -16,7 +16,7 @@ static void _assert_json_parse_response(rc_api_response_t* response, rc_json_fie
     RC_JSON_NEW_FIELD("Error"),
     RC_JSON_NEW_FIELD("Test")
   };
-  rc_buf_init(&response->buffer);
+  rc_buffer_init(&response->buffer);
 
   memset(&server_response, 0, sizeof(server_response));
   server_response.body = json;
@@ -76,7 +76,7 @@ static void test_json_parse_response_non_json() {
     RC_JSON_NEW_FIELD("Error"),
     RC_JSON_NEW_FIELD("Test")
   };
-  rc_buf_init(&response.buffer);
+  rc_buffer_init(&response.buffer);
 
   memset(&server_response, 0, sizeof(server_response));
   server_response.body = error_message;
@@ -90,6 +90,30 @@ static void test_json_parse_response_non_json() {
   ASSERT_NUM_EQUALS(response.succeeded, 0);
 }
 
+static void test_json_parse_response_non_json_bounded() {
+  int result;
+  rc_api_server_response_t server_response;
+  rc_api_response_t response;
+  const char* error_message = "This is an error.\r\n<title>Should not be seen</title>";
+  rc_json_field_t fields[] = {
+    RC_JSON_NEW_FIELD("Success"),
+    RC_JSON_NEW_FIELD("Error"),
+    RC_JSON_NEW_FIELD("Test")
+  };
+  rc_buffer_init(&response.buffer);
+
+  memset(&server_response, 0, sizeof(server_response));
+  server_response.body = error_message;
+  server_response.body_length = 16; /* "This is an error" (no period, newline, etc) */
+
+  result = rc_json_parse_server_response(&response, &server_response, fields, sizeof(fields) / sizeof(fields[0]));
+  ASSERT_NUM_EQUALS(result, RC_INVALID_JSON);
+
+  ASSERT_PTR_NOT_NULL(response.error_message);
+  ASSERT_STR_EQUALS(response.error_message, "This is an error");
+  ASSERT_NUM_EQUALS(response.succeeded, 0);
+}
+
 static void test_json_parse_response_error_from_server() {
   int result;
   rc_api_server_response_t server_response;
@@ -100,7 +124,7 @@ static void test_json_parse_response_error_from_server() {
     RC_JSON_NEW_FIELD("Error"),
     RC_JSON_NEW_FIELD("Test")
   };
-  rc_buf_init(&response.buffer);
+  rc_buffer_init(&response.buffer);
 
   json = "{\"Success\":false,\"Error\":\"Oops\"}";
   memset(&server_response, 0, sizeof(server_response));
@@ -125,7 +149,7 @@ static void test_json_parse_response_incorrect_size() {
     RC_JSON_NEW_FIELD("Error"),
     RC_JSON_NEW_FIELD("Test")
   };
-  rc_buf_init(&response.buffer);
+  rc_buffer_init(&response.buffer);
 
   json = "{\"Success\":false,\"Error\":\"Oops\"}";
   memset(&server_response, 0, sizeof(server_response));
@@ -255,11 +279,11 @@ static void test_json_get_required_num() {
   ASSERT_NUM_EQUALS(response.succeeded, 0);
 }
 
-static void test_json_get_unum(const char* input, unsigned expected) {
+static void test_json_get_unum(const char* input, uint32_t expected) {
   rc_api_response_t response;
   rc_json_field_t field;
   char buffer[64];
-  unsigned value = 0;
+  uint32_t value = 0;
   snprintf(buffer, sizeof(buffer), "{\"Test\":%s}", input);
 
   assert_json_parse_response(&response, &field, buffer, RC_OK);
@@ -277,7 +301,7 @@ static void test_json_get_unum(const char* input, unsigned expected) {
 static void test_json_get_optional_unum() {
   rc_api_response_t response;
   rc_json_field_t field;
-  unsigned value = 0;
+  uint32_t value = 0;
 
   assert_json_parse_response(&response, &field, "{\"Test\":12345678}", RC_OK);
 
@@ -293,7 +317,7 @@ static void test_json_get_optional_unum() {
 static void test_json_get_required_unum() {
   rc_api_response_t response;
   rc_json_field_t field;
-  unsigned value = 0;
+  uint32_t value = 0;
 
   assert_json_parse_response(&response, &field, "{\"Test\":12345678}", RC_OK);
 
@@ -313,6 +337,69 @@ static void test_json_get_required_unum() {
   ASSERT_NUM_EQUALS(response.succeeded, 0);
 }
 
+static void test_json_get_float(const char* input, float expected)
+{
+  rc_api_response_t response;
+  rc_json_field_t field;
+  char buffer[64];
+  float value = 0.0;
+  snprintf(buffer, sizeof(buffer), "{\"Test\":%s}", input);
+
+  assert_json_parse_response(&response, &field, buffer, RC_OK);
+
+  if (expected)
+  {
+    ASSERT_TRUE(rc_json_get_float(&value, &field, "Test"));
+  }
+  else
+  {
+    ASSERT_FALSE(rc_json_get_float(&value, &field, "Test"));
+  }
+
+  ASSERT_FLOAT_EQUALS(value, expected);
+}
+
+static void test_json_get_optional_float()
+{
+  rc_api_response_t response;
+  rc_json_field_t field;
+  float value = 0.0;
+
+  assert_json_parse_response(&response, &field, "{\"Test\":1.5}", RC_OK);
+
+  rc_json_get_optional_float(&value, &field, "Test", 9999);
+  ASSERT_FLOAT_EQUALS(value, 1.5);
+
+  assert_json_parse_response(&response, &field, "{\"Test2\":1.5}", RC_OK);
+
+  rc_json_get_optional_float(&value, &field, "Test", 2.5);
+  ASSERT_FLOAT_EQUALS(value, 2.5);
+}
+
+static void test_json_get_required_float()
+{
+  rc_api_response_t response;
+  rc_json_field_t field;
+  float value = 0.0;
+
+  assert_json_parse_response(&response, &field, "{\"Test\":1.5}", RC_OK);
+
+  ASSERT_TRUE(rc_json_get_required_float(&value, &response, &field, "Test"));
+  ASSERT_FLOAT_EQUALS(value, 1.5f);
+
+  ASSERT_PTR_NULL(response.error_message);
+  ASSERT_NUM_EQUALS(response.succeeded, 1);
+
+  assert_json_parse_response(&response, &field, "{\"Test2\":1.5}", RC_OK);
+
+  ASSERT_FALSE(rc_json_get_required_float(&value, &response, &field, "Test"));
+  ASSERT_FLOAT_EQUALS(value, 0.0f);
+
+  ASSERT_PTR_NOT_NULL(response.error_message);
+  ASSERT_STR_EQUALS(response.error_message, "Test not found in response");
+  ASSERT_NUM_EQUALS(response.succeeded, 0);
+}
+
 static void test_json_get_bool(const char* input, int expected) {
   rc_api_response_t response;
   rc_json_field_t field;
@@ -390,12 +477,12 @@ static void test_json_get_datetime(const char* input, int expected) {
   }
 }
 
-static void test_json_get_unum_array(const char* input, unsigned expected_count, int expected_result) {
+static void test_json_get_unum_array(const char* input, uint32_t expected_count, int expected_result) {
   rc_api_response_t response;
   rc_json_field_t field;
   int result;
-  unsigned count = 0xFFFFFFFF;
-  unsigned *values;
+  uint32_t count = 0xFFFFFFFF;
+  uint32_t*values;
   char buffer[128];
 
   snprintf(buffer, sizeof(buffer), "{\"Test\":%s}", input);
@@ -405,7 +492,7 @@ static void test_json_get_unum_array(const char* input, unsigned expected_count,
   ASSERT_NUM_EQUALS(result, expected_result);
   ASSERT_NUM_EQUALS(count, expected_count);
 
-  rc_buf_destroy(&response.buffer);
+  rc_buffer_destroy(&response.buffer);
 }
 
 static void test_json_get_unum_array_trailing_comma() {
@@ -419,13 +506,13 @@ static void test_url_build_dorequest_url_default_host() {
   rc_api_request_t request;
   rc_api_fetch_image_request_t api_params;
 
-  rc_api_url_build_dorequest_url(&request);
+  rc_api_url_build_dorequest_url(&request, NULL);
   ASSERT_STR_EQUALS(request.url, "https://retroachievements.org/dorequest.php");
   rc_api_destroy_request(&request);
 
   api_params.image_type = RC_IMAGE_TYPE_ACHIEVEMENT;
   api_params.image_name = "12345";
-  rc_api_init_fetch_image_request(&request, &api_params);
+  rc_api_init_fetch_image_request_hosted(&request, &api_params, NULL);
   ASSERT_STR_EQUALS(request.url, "https://media.retroachievements.org/Badge/12345.png");
   rc_api_destroy_request(&request);
 }
@@ -433,81 +520,81 @@ static void test_url_build_dorequest_url_default_host() {
 static void test_url_build_dorequest_url_default_host_nonssl() {
   rc_api_request_t request;
   rc_api_fetch_image_request_t api_params;
+  rc_api_host_t host;
 
-  rc_api_set_host("http://retroachievements.org");
+  memset(&host, 0, sizeof(host));
+  host.host = "http://retroachievements.org";
 
-  rc_api_url_build_dorequest_url(&request);
+  rc_api_url_build_dorequest_url(&request, &host);
   ASSERT_STR_EQUALS(request.url, "http://retroachievements.org/dorequest.php");
   rc_api_destroy_request(&request);
 
   api_params.image_type = RC_IMAGE_TYPE_ACHIEVEMENT;
   api_params.image_name = "12345";
-  rc_api_init_fetch_image_request(&request, &api_params);
+  rc_api_init_fetch_image_request_hosted(&request, &api_params, &host);
   ASSERT_STR_EQUALS(request.url, "http://media.retroachievements.org/Badge/12345.png");
   rc_api_destroy_request(&request);
-
-  rc_api_set_host(NULL);
 }
 
 static void test_url_build_dorequest_url_custom_host() {
   rc_api_request_t request;
   rc_api_fetch_image_request_t api_params;
+  rc_api_host_t host;
 
-  rc_api_set_host("http://localhost");
+  memset(&host, 0, sizeof(host));
+  host.host = "http://localhost";
 
-  rc_api_url_build_dorequest_url(&request);
+  rc_api_url_build_dorequest_url(&request, &host);
   ASSERT_STR_EQUALS(request.url, "http://localhost/dorequest.php");
   rc_api_destroy_request(&request);
 
   api_params.image_type = RC_IMAGE_TYPE_ACHIEVEMENT;
   api_params.image_name = "12345";
-  rc_api_init_fetch_image_request(&request, &api_params);
+  rc_api_init_fetch_image_request_hosted(&request, &api_params, &host);
   ASSERT_STR_EQUALS(request.url, "http://localhost/Badge/12345.png");
   rc_api_destroy_request(&request);
-
-  rc_api_set_host(NULL);
 }
 
 static void test_url_build_dorequest_url_custom_host_no_protocol() {
   rc_api_request_t request;
   rc_api_fetch_image_request_t api_params;
+  rc_api_host_t host;
 
-  rc_api_set_host("my.host");
+  memset(&host, 0, sizeof(host));
+  host.host = "my.host";
 
-  rc_api_url_build_dorequest_url(&request);
+  rc_api_url_build_dorequest_url(&request, &host);
   ASSERT_STR_EQUALS(request.url, "http://my.host/dorequest.php");
   rc_api_destroy_request(&request);
 
   api_params.image_type = RC_IMAGE_TYPE_ACHIEVEMENT;
   api_params.image_name = "12345";
-  rc_api_init_fetch_image_request(&request, &api_params);
+  rc_api_init_fetch_image_request_hosted(&request, &api_params, &host);
   ASSERT_STR_EQUALS(request.url, "http://my.host/Badge/12345.png");
   rc_api_destroy_request(&request);
-
-  rc_api_set_host(NULL);
 }
 
 static void test_url_builder_append_encoded_str(const char* input, const char* expected) {
   rc_api_url_builder_t builder;
-  rc_api_buffer_t buffer;
+  rc_buffer_t buffer;
   const char* output;
 
-  rc_buf_init(&buffer);
+  rc_buffer_init(&buffer);
   rc_url_builder_init(&builder, &buffer, 128);
   rc_url_builder_append_encoded_str(&builder, input);
   output = rc_url_builder_finalize(&builder);
 
   ASSERT_STR_EQUALS(output, expected);
 
-  rc_buf_destroy(&buffer);
+  rc_buffer_destroy(&buffer);
 }
 
 static void test_url_builder_append_str_param() {
   rc_api_url_builder_t builder;
-  rc_api_buffer_t buffer;
+  rc_buffer_t buffer;
   const char* output;
 
-  rc_buf_init(&buffer);
+  rc_buffer_init(&buffer);
   rc_url_builder_init(&builder, &buffer, 64);
   rc_url_builder_append_str_param(&builder, "a", "Apple");
   rc_url_builder_append_str_param(&builder, "b", "Banana");
@@ -516,15 +603,15 @@ static void test_url_builder_append_str_param() {
 
   ASSERT_STR_EQUALS(output, "a=Apple&b=Banana&t=Test+1");
 
-  rc_buf_destroy(&buffer);
+  rc_buffer_destroy(&buffer);
 }
 
 static void test_url_builder_append_unum_param() {
   rc_api_url_builder_t builder;
-  rc_api_buffer_t buffer;
+  rc_buffer_t buffer;
   const char* output;
 
-  rc_buf_init(&buffer);
+  rc_buffer_init(&buffer);
   rc_url_builder_init(&builder, &buffer, 32);
   rc_url_builder_append_unum_param(&builder, "a", 0);
   rc_url_builder_append_unum_param(&builder, "b", 123456);
@@ -533,15 +620,15 @@ static void test_url_builder_append_unum_param() {
 
   ASSERT_STR_EQUALS(output, "a=0&b=123456&t=4294967295");
 
-  rc_buf_destroy(&buffer);
+  rc_buffer_destroy(&buffer);
 }
 
 static void test_url_builder_append_num_param() {
   rc_api_url_builder_t builder;
-  rc_api_buffer_t buffer;
+  rc_buffer_t buffer;
   const char* output;
 
-  rc_buf_init(&buffer);
+  rc_buffer_init(&buffer);
   rc_url_builder_init(&builder, &buffer, 32);
   rc_url_builder_append_num_param(&builder, "a", 0);
   rc_url_builder_append_num_param(&builder, "b", 123456);
@@ -550,7 +637,7 @@ static void test_url_builder_append_num_param() {
 
   ASSERT_STR_EQUALS(output, "a=0&b=123456&t=-1");
 
-  rc_buf_destroy(&buffer);
+  rc_buffer_destroy(&buffer);
 }
 
 static void test_init_fetch_image_request_game() {
@@ -626,6 +713,66 @@ static void test_init_fetch_image_request_unknown() {
   rc_api_destroy_request(&request);
 }
 
+static void test_init_fetch_image_request_custom_host()
+{
+  rc_api_fetch_image_request_t fetch_image_request;
+  rc_api_request_t request;
+  rc_api_host_t host;
+
+  memset(&host, 0, sizeof(host));
+  host.host = "http://localhost";
+
+  memset(&fetch_image_request, 0, sizeof(fetch_image_request));
+  fetch_image_request.image_name = "0123324";
+  fetch_image_request.image_type = RC_IMAGE_TYPE_GAME;
+
+  ASSERT_NUM_EQUALS(rc_api_init_fetch_image_request_hosted(&request, &fetch_image_request, &host), RC_OK);
+  ASSERT_STR_EQUALS(request.url, "http://localhost/Images/0123324.png");
+  ASSERT_PTR_NULL(request.post_data);
+
+  rc_api_destroy_request(&request);
+}
+
+static void test_init_fetch_image_request_explicit_default_host()
+{
+  rc_api_fetch_image_request_t fetch_image_request;
+  rc_api_request_t request;
+  rc_api_host_t host;
+
+  memset(&host, 0, sizeof(host));
+  host.host = rc_api_default_host();
+
+  memset(&fetch_image_request, 0, sizeof(fetch_image_request));
+  fetch_image_request.image_name = "0123324";
+  fetch_image_request.image_type = RC_IMAGE_TYPE_GAME;
+
+  ASSERT_NUM_EQUALS(rc_api_init_fetch_image_request_hosted(&request, &fetch_image_request, &host), RC_OK);
+  ASSERT_STR_EQUALS(request.url, "https://media.retroachievements.org/Images/0123324.png");
+  ASSERT_PTR_NULL(request.post_data);
+
+  rc_api_destroy_request(&request);
+}
+
+static void test_init_fetch_image_request_explicit_nonssl_host()
+{
+  rc_api_fetch_image_request_t fetch_image_request;
+  rc_api_request_t request;
+  rc_api_host_t host;
+
+  memset(&host, 0, sizeof(host));
+  host.host = "http://retroachievements.org";
+
+  memset(&fetch_image_request, 0, sizeof(fetch_image_request));
+  fetch_image_request.image_name = "0123324";
+  fetch_image_request.image_type = RC_IMAGE_TYPE_GAME;
+
+  ASSERT_NUM_EQUALS(rc_api_init_fetch_image_request_hosted(&request, &fetch_image_request, &host), RC_OK);
+  ASSERT_STR_EQUALS(request.url, "http://media.retroachievements.org/Images/0123324.png");
+  ASSERT_PTR_NULL(request.post_data);
+
+  rc_api_destroy_request(&request);
+}
+
 void test_rapi_common(void) {
   TEST_SUITE_BEGIN();
 
@@ -646,6 +793,7 @@ void test_rapi_common(void) {
   TEST_PARAMS2(test_json_parse_response_field, "{ \"Other\" : 1, \"Test\" : 2 }", "2"); /* preceding field */
   TEST_PARAMS2(test_json_parse_response_field, "{ \"Test\" : 1, \"Other\" : 2 }", "1"); /* trailing field */
   TEST(test_json_parse_response_non_json);
+  TEST(test_json_parse_response_non_json_bounded);
   TEST(test_json_parse_response_error_from_server);
   TEST(test_json_parse_response_incorrect_size);
 
@@ -684,6 +832,17 @@ void test_rapi_common(void) {
   TEST(test_json_get_optional_unum);
   TEST(test_json_get_required_unum);
 
+  /* rc_json_get_num */
+  TEST_PARAMS2(test_json_get_float, "Banana", 0.0f);
+  TEST_PARAMS2(test_json_get_float, "True", 0.0f);
+  TEST_PARAMS2(test_json_get_float, "2468", 2468.0f);
+  TEST_PARAMS2(test_json_get_float, "+55", 55.0f);
+  TEST_PARAMS2(test_json_get_float, "-16", -16.0f);
+  TEST_PARAMS2(test_json_get_float, "3.14159", 3.14159f);
+  TEST_PARAMS2(test_json_get_float, "-6.7", -6.7f);
+  TEST(test_json_get_optional_float);
+  TEST(test_json_get_required_float);
+
   /* rc_json_get_bool */
   TEST_PARAMS2(test_json_get_bool, "true", 1);
   TEST_PARAMS2(test_json_get_bool, "false", 0);
@@ -711,7 +870,7 @@ void test_rapi_common(void) {
   TEST_PARAMS3(test_json_get_unum_array, "[A,B,C]", 3, RC_MISSING_VALUE);
   TEST(test_json_get_unum_array_trailing_comma);
 
-  /* rc_api_url_build_dorequest_url / rc_api_set_host */
+  /* rc_api_url_build_dorequest_url / rc_api_url_build_dorequest_url_hosted */
   TEST(test_url_build_dorequest_url_default_host);
   TEST(test_url_build_dorequest_url_default_host_nonssl);
   TEST(test_url_build_dorequest_url_custom_host);
@@ -738,6 +897,9 @@ void test_rapi_common(void) {
   TEST(test_init_fetch_image_request_achievement_locked);
   TEST(test_init_fetch_image_request_user);
   TEST(test_init_fetch_image_request_unknown);
+  TEST(test_init_fetch_image_request_custom_host);
+  TEST(test_init_fetch_image_request_explicit_default_host);
+  TEST(test_init_fetch_image_request_explicit_nonssl_host);
 
 
   TEST_SUITE_END();
