@@ -271,7 +271,7 @@ bool CompareOutput(const Path &bootFilename, const std::string &output, bool ver
 				printf("%s", output.c_str());
 				printf("============== expected output:\n");
 				std::string fullExpected;
-				if (File::ReadFileToString(true, expect_filename, fullExpected))
+				if (File::ReadTextFileToString(expect_filename, &fullExpected))
 					printf("%s", fullExpected.c_str());
 				printf("===============================\n");
 			}
