@@ -8,6 +8,7 @@
 #import "Core/System.h"
 #import "Core/Config.h"
 #import "Common/Log.h"
+#import "IAPManager.h"
 
 #import <AVFoundation/AVFoundation.h>
 
@@ -89,6 +90,10 @@
 	[[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(handleAudioSessionInterruption:) name:AVAudioSessionInterruptionNotification object:[AVAudioSession sharedInstance]];
 	[[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(handleMediaServicesWereReset:) name:AVAudioSessionMediaServicesWereResetNotification object:nil];
 
+#if PPSSPP_PLATFORM(IOS_APP_STORE)
+	[IAPManager sharedIAPManager];  // Kick off the IAPManager early.
+#endif  // IOS_APP_STORE
+
 	return [self launchPPSSPP:argc argv:argv];
 }
 
