@@ -10,9 +10,10 @@
 
 @interface PPSSPPViewControllerMetal : UIViewController<
     iCadeEventDelegate, LocationHandlerDelegate, CameraFrameDelegate,
-    UIGestureRecognizerDelegate, UIKeyInput, PPSSPPViewController>
+    UIGestureRecognizerDelegate, UIKeyInput, PPSSPPViewController,
+	UIImagePickerControllerDelegate, UINavigationControllerDelegate>
 @end
 
 /** The Metal-compatibile view. */
 @interface PPSSPPMetalView : UIView
-@end
\ No newline at end of file
+@end
