@@ -3,6 +3,7 @@
 #import "DisplayManager.h"
 #include "Controls.h"
 #import "iOSCoreAudio.h"
+#import "IAPManager.h"
 
 #include "Common/Log.h"
 
@@ -16,6 +17,7 @@
 #include "Common/System/System.h"
 #include "Common/System/OSD.h"
 #include "Common/System/NativeApp.h"
+#include "Common/System/Request.h"
 #include "Common/GraphicsContext.h"
 #include "Common/Thread/ThreadUtil.h"
 
@@ -29,12 +31,15 @@
 // https://www.progressconcepts.com/blog/ios-appdelegate-viewcontroller-method-order/
 
 // TODO: Share this between backends.
-static uint32_t FlagsFromConfig() {
-	uint32_t flags;
+static VulkanInitFlags FlagsFromConfig() {
+	VulkanInitFlags flags;
 	if (g_Config.bVSync) {
-		flags = VULKAN_FLAG_PRESENT_FIFO;
+		flags = VulkanInitFlags::PRESENT_FIFO;
 	} else {
-		flags = VULKAN_FLAG_PRESENT_MAILBOX | VULKAN_FLAG_PRESENT_IMMEDIATE;
+		flags = VulkanInitFlags::PRESENT_MAILBOX | VulkanInitFlags::PRESENT_IMMEDIATE;
+	}
+	if (g_Config.bVulkanDisableImplicitLayers) {
+		flags |= VulkanInitFlags::DISABLE_IMPLICIT_LAYERS;
 	}
 	return flags;
 }
@@ -57,13 +62,13 @@ public:
 	bool InitAPI();
 
 	bool InitFromRenderThread(CAMetalLayer *layer, int desiredBackbufferSizeX, int desiredBackbufferSizeY);
-	void ShutdownFromRenderThread();  // Inverses InitFromRenderThread.
+	void ShutdownFromRenderThread() override;  // Inverses InitFromRenderThread.
 
-	void Shutdown();
-	void Resize();
+	void Shutdown() override;
+	void Resize() override;
 
-	void *GetAPIContext() { return g_Vulkan; }
-	Draw::DrawContext *GetDrawContext() { return draw_; }
+	void *GetAPIContext() override { return g_Vulkan; }
+	Draw::DrawContext *GetDrawContext() override { return draw_; }
 
 private:
 	VulkanContext *g_Vulkan = nullptr;
@@ -143,7 +148,7 @@ void IOSVulkanContext::Resize() {
 	g_Vulkan->DestroySwapchain();
 	g_Vulkan->DestroySurface();
 
-	g_Vulkan->UpdateFlags(FlagsFromConfig());
+	g_Vulkan->UpdateInitFlags(FlagsFromConfig());
 
 	g_Vulkan->ReinitSurface();
 	g_Vulkan->InitSwapchain();
@@ -209,6 +214,9 @@ static std::thread g_renderLoopThread;
 	IOSVulkanContext *graphicsContext;
 	LocationHelper *locationHelper;
 	CameraHelper *cameraHelper;
+
+	int imageRequestId;
+	NSString *imageFilename;
 }
 
 @property (nonatomic) GCController *gameController __attribute__((weak_import));
@@ -478,6 +486,15 @@ void VulkanRenderLoop(IOSVulkanContext *graphicsContext, CAMetalLayer *metalLaye
 	[self hideKeyboard];
 	[self updateGesture];
 
+	// This needs to be called really late during startup, unfortunately.
+#if PPSSPP_PLATFORM(IOS_APP_STORE)
+	[IAPManager sharedIAPManager];  // Kick off the IAPManager early.
+	NSLog(@"Metal viewDidAppear. updating icon");
+	dispatch_after(dispatch_time(DISPATCH_TIME_NOW, (int64_t)(4.0 * NSEC_PER_SEC)), dispatch_get_main_queue(), ^{
+		[[IAPManager sharedIAPManager] updateIcon:false];
+		[self hideKeyboard];
+	});
+#endif  // IOS_APP_STORE
 }
 
 - (BOOL)prefersHomeIndicatorAutoHidden {
@@ -713,6 +730,7 @@ extern float g_safeInsetBottom;
 
 -(void) showKeyboard {
 	dispatch_async(dispatch_get_main_queue(), ^{
+		NSLog(@"becomeFirstResponder");
 		[self becomeFirstResponder];
 	});
 }
@@ -723,6 +741,47 @@ extern float g_safeInsetBottom;
 	});
 }
 
+- (void)pickPhoto:(NSString *)saveFilename requestId:(int)requestId {
+	imageRequestId = requestId;
+	imageFilename = saveFilename;
+	NSLog(@"Picking photo to save to %@ (id: %d)", saveFilename, requestId);
+
+	UIImagePickerController *picker = [[UIImagePickerController alloc] init];
+	picker.sourceType = UIImagePickerControllerSourceTypePhotoLibrary;
+	picker.delegate = self;
+	[self presentViewController:picker animated:YES completion:nil];
+}
+
+- (void)imagePickerController:(UIImagePickerController *)picker
+		didFinishPickingMediaWithInfo:(NSDictionary<UIImagePickerControllerInfoKey,id> *)info {
+
+	UIImage *image = info[UIImagePickerControllerOriginalImage];
+
+	// Convert to JPEG with 90% quality
+	NSData *jpegData = UIImageJPEGRepresentation(image, 0.9);
+	if (jpegData) {
+		// Do something with the JPEG data (e.g., save to file)
+		[jpegData writeToFile:imageFilename atomically:YES];
+		NSLog(@"Saved JPEG image to %@", imageFilename);
+		g_requestManager.PostSystemSuccess(imageRequestId, "", 1);
+	} else {
+		g_requestManager.PostSystemFailure(imageRequestId);
+	}
+
+	[picker dismissViewControllerAnimated:YES completion:nil];
+	[self hideKeyboard];
+}
+
+- (void)imagePickerControllerDidCancel:(UIImagePickerController *)picker {
+	NSLog(@"User cancelled image picker");
+
+	[picker dismissViewControllerAnimated:YES completion:nil];
+
+	// You can also call your custom callback or use the requestId here
+	g_requestManager.PostSystemFailure(imageRequestId);
+	[self hideKeyboard];
+}
+
 @end
 
 @implementation PPSSPPMetalView
