@@ -25,6 +25,7 @@
 #import "PPSSPPUIApplication.h"
 #import "ViewController.h"
 #import "iOSCoreAudio.h"
+#import "IAPManager.h"
 
 #include "Common/MemoryUtil.h"
 #include "Common/System/NativeApp.h"
@@ -35,6 +36,7 @@
 #include "Common/Thread/ThreadUtil.h"
 #include "Core/Config.h"
 #include "Common/Log.h"
+#include "Common/Log/LogManager.h"
 #include "UI/DarwinFileSystemServices.h"
 
 // Compile out all the hackery in app store builds.
@@ -315,6 +317,10 @@ std::vector<std::string> System_GetPropertyStringVec(SystemProperty prop) {
 	}
 }
 
+extern "C" {
+int Apple_GetCurrentBatteryCapacity();
+}
+
 int64_t System_GetPropertyInt(SystemProperty prop) {
 	switch (prop) {
 		case SYSPROP_AUDIO_SAMPLE_RATE:
@@ -323,6 +329,8 @@ int64_t System_GetPropertyInt(SystemProperty prop) {
 			return DEVICE_TYPE_MOBILE;
 		case SYSPROP_SYSTEMVERSION:
 			return g_iosVersionMajor;
+		case SYSPROP_BATTERY_PERCENTAGE:
+			return Apple_GetCurrentBatteryCapacity();
 		default:
 			return -1;
 	}
@@ -351,6 +359,8 @@ bool System_GetPropertyBool(SystemProperty prop) {
 			return true;
 		case SYSPROP_HAS_FOLDER_BROWSER:
 			return true;
+		case SYSPROP_HAS_IMAGE_BROWSER:
+			return true;
 		case SYSPROP_HAS_OPEN_DIRECTORY:
 			return false;
 		case SYSPROP_HAS_BACK_BUTTON:
@@ -364,6 +374,16 @@ bool System_GetPropertyBool(SystemProperty prop) {
 			return true;
 		case SYSPROP_APP_GOLD:
 #ifdef GOLD
+			// This is deprecated.
+			return true;
+#elif PPSSPP_PLATFORM(IOS_APP_STORE)
+			// Check the IAP status.
+			return [[IAPManager sharedIAPManager] isGoldUnlocked];
+#else
+			return false;
+#endif
+		case SYSPROP_USE_IAP:
+#if PPSSPP_PLATFORM(IOS_APP_STORE) && defined(USE_IAP)
 			return true;
 #else
 			return false;
@@ -380,6 +400,9 @@ bool System_GetPropertyBool(SystemProperty prop) {
 		case SYSPROP_SUPPORTS_HTTPS:
 			return true;
 #endif
+		case SYSPROP_CAN_READ_BATTERY_PERCENTAGE:
+			return true;
+
 		default:
 			return false;
 	}
@@ -414,7 +437,7 @@ void System_Notify(SystemNotification notification) {
 bool System_MakeRequest(SystemRequestType type, int requestId, const std::string &param1, const std::string &param2, int64_t param3, int64_t param4) {
 	switch (type) {
 	case SystemRequestType::RESTART_APP:
-        dispatch_async(dispatch_get_main_queue(), ^{
+		dispatch_async(dispatch_get_main_queue(), ^{
 			[(AppDelegate *)[[UIApplication sharedApplication] delegate] restart:param1.c_str()];
 		});
 		return true;
@@ -452,6 +475,14 @@ bool System_MakeRequest(SystemRequestType type, int requestId, const std::string
 		DarwinFileSystemServices::presentDirectoryPanel(callback, /* allowFiles = */ false, /* allowDirectories = */ true);
 		return true;
 	}
+	case SystemRequestType::BROWSE_FOR_IMAGE:
+	{
+		NSString *filename = [NSString stringWithUTF8String:param2.c_str()];
+		dispatch_async(dispatch_get_main_queue(), ^{
+			[sharedViewController pickPhoto:filename requestId:requestId];
+		});
+		return true;
+	}
 	case SystemRequestType::CAMERA_COMMAND:
 		if (!strncmp(param1.c_str(), "startVideo", 10)) {
 			int width = 0, height = 0;
@@ -491,6 +522,18 @@ bool System_MakeRequest(SystemRequestType type, int requestId, const std::string
 		}
 		return true;
 	}
+#if PPSSPP_PLATFORM(IOS_APP_STORE)
+	case SystemRequestType::IAP_RESTORE_PURCHASES:
+	{
+		[[IAPManager sharedIAPManager] restorePurchasesWithRequestID:requestId];
+		return true;
+	}
+	case SystemRequestType::IAP_MAKE_PURCHASE:
+	{
+		[[IAPManager sharedIAPManager] buyGoldWithRequestID:requestId];
+		return true;
+	}
+#endif
 /*
 	// Not 100% sure the threading is right
 	case SystemRequestType::COPY_TO_CLIPBOARD:
@@ -502,10 +545,10 @@ bool System_MakeRequest(SystemRequestType type, int requestId, const std::string
 	}
 */
 	case SystemRequestType::SET_KEEP_SCREEN_BRIGHT:
-        dispatch_async(dispatch_get_main_queue(), ^{
-            INFO_LOG(Log::System, "SET_KEEP_SCREEN_BRIGHT: %d", (int)param3);
-            [[UIApplication sharedApplication] setIdleTimerDisabled: (param3 ? YES : NO)];
-        });
+		dispatch_async(dispatch_get_main_queue(), ^{
+			INFO_LOG(Log::System, "SET_KEEP_SCREEN_BRIGHT: %d", (int)param3);
+			[[UIApplication sharedApplication] setIdleTimerDisabled: (param3 ? YES : NO)];
+		});
 		return true;
 	default:
 		break;
@@ -578,6 +621,8 @@ int main(int argc, char *argv[])
 		g_iosVersionMajor = 14;
 	}
 
+	g_logManager.EnableOutput(LogOutput::Stdio);
+
 #if PPSSPP_PLATFORM(IOS_APP_STORE)
 	g_jitAvailable = false;
 #else
