@@ -326,12 +326,11 @@ struct retro_core_option_v2_definition option_defs_us[] = {
       },
       "480x272"
    },
-#if 0 // see issue #16786
    {
       "ppsspp_mulitsample_level",
-      "MSAA Antialiasing (Vulkan Only)",
-      NULL,
+      "MSAA Antialiasing",
       NULL,
+      "Vulkan only. Core restart required.",
       NULL,
       "video",
       {
@@ -343,7 +342,6 @@ struct retro_core_option_v2_definition option_defs_us[] = {
       },
       "Disabled"
    },
-#endif
    {
       "ppsspp_cropto16x9",
       "Crop to 16x9",
@@ -462,7 +460,7 @@ struct retro_core_option_v2_definition option_defs_us[] = {
       "ppsspp_analog_deadzone",
       "Analog Deadzone",
       NULL,
-      "Select how far you have to push the analog stick before it starts being processed.",
+      "Additional deadzone to apply after frontend input.",
       NULL,
       "input",
       {
@@ -479,13 +477,13 @@ struct retro_core_option_v2_definition option_defs_us[] = {
          { "0.50", "50%" },
          { NULL, NULL },
       },
-      "0.15"
+      "0.0"
    },
    {
       "ppsspp_analog_sensitivity",
       "Analog Axis Scale",
       NULL,
-      "Sets the analog stick axis scaling factor.",
+      "Additional sensitivity factor to apply after frontend input.",
       NULL,
       "input",
       {
@@ -498,7 +496,7 @@ struct retro_core_option_v2_definition option_defs_us[] = {
          {"1.42", NULL}, {"1.43", NULL}, {"1.44", NULL}, {"1.45", NULL}, {"1.46", NULL}, {"1.47", NULL}, {"1.48", NULL},
          {"1.49", NULL}, {"1.50", NULL}, {NULL, NULL},
       },
-      "1.10"
+      "1.00"
    },
    {
       "ppsspp_skip_buffer_effects",
@@ -601,16 +599,6 @@ struct retro_core_option_v2_definition option_defs_us[] = {
       BOOL_OPTIONS,
       "disabled"
    },
-   {
-      "ppsspp_vertex_cache",
-      "Vertex Cache",
-      NULL,
-      "Faster, but may cause temporary flicker.",
-      NULL,
-      "video",
-      BOOL_OPTIONS,
-      "disabled"
-   },
    {
       "ppsspp_texture_scaling_type",
       "Texture Upscale Type",
@@ -735,7 +723,7 @@ struct retro_core_option_v2_definition option_defs_us[] = {
    },
    {
       "ppsspp_change_mac_address01",
-      "MAC Address Pt  1: X-:--:--:--:--:--",
+      "MAC Address Pt  1: x-:--:--:--:--:--",
       NULL,
       NULL,
       NULL,
@@ -745,7 +733,7 @@ struct retro_core_option_v2_definition option_defs_us[] = {
    },
    {
       "ppsspp_change_mac_address02",
-      "MAC Address Pt  2: -X:--:--:--:--:--",
+      "MAC Address Pt  2: -x:--:--:--:--:--",
       NULL,
       NULL,
       NULL,
@@ -755,7 +743,7 @@ struct retro_core_option_v2_definition option_defs_us[] = {
    },
    {
       "ppsspp_change_mac_address03",
-      "MAC Address Pt  3: --:X-:--:--:--:--",
+      "MAC Address Pt  3: --:x-:--:--:--:--",
       NULL,
       NULL,
       NULL,
@@ -765,7 +753,7 @@ struct retro_core_option_v2_definition option_defs_us[] = {
    },
    {
       "ppsspp_change_mac_address04",
-      "MAC Address Pt  4: --:-X:--:--:--:--",
+      "MAC Address Pt  4: --:-x:--:--:--:--",
       NULL,
       NULL,
       NULL,
@@ -775,7 +763,7 @@ struct retro_core_option_v2_definition option_defs_us[] = {
    },
    {
       "ppsspp_change_mac_address05",
-      "MAC Address Pt  5: --:--:X-:--:--:--",
+      "MAC Address Pt  5: --:--:x-:--:--:--",
       NULL,
       NULL,
       NULL,
@@ -785,7 +773,7 @@ struct retro_core_option_v2_definition option_defs_us[] = {
    },
    {
       "ppsspp_change_mac_address06",
-      "MAC Address Pt  6: --:--:-X:--:--:--",
+      "MAC Address Pt  6: --:--:-x:--:--:--",
       NULL,
       NULL,
       NULL,
@@ -795,7 +783,7 @@ struct retro_core_option_v2_definition option_defs_us[] = {
    },
    {
       "ppsspp_change_mac_address07",
-      "MAC Address Pt  7: --:--:--:X-:--:--",
+      "MAC Address Pt  7: --:--:--:x-:--:--",
       NULL,
       NULL,
       NULL,
@@ -805,7 +793,7 @@ struct retro_core_option_v2_definition option_defs_us[] = {
    },
    {
       "ppsspp_change_mac_address08",
-      "MAC Address Pt  8: --:--:--:-X:--:--",
+      "MAC Address Pt  8: --:--:--:-x:--:--",
       NULL,
       NULL,
       NULL,
@@ -815,7 +803,7 @@ struct retro_core_option_v2_definition option_defs_us[] = {
    },
    {
       "ppsspp_change_mac_address09",
-      "MAC Address Pt  9: --:--:--:--:X-:--",
+      "MAC Address Pt  9: --:--:--:--:x-:--",
       NULL,
       NULL,
       NULL,
@@ -825,7 +813,7 @@ struct retro_core_option_v2_definition option_defs_us[] = {
    },
    {
       "ppsspp_change_mac_address10",
-      "MAC Address Pt 10: --:--:--:--:-X:--",
+      "MAC Address Pt 10: --:--:--:--:-x:--",
       NULL,
       NULL,
       NULL,
@@ -835,7 +823,7 @@ struct retro_core_option_v2_definition option_defs_us[] = {
    },
    {
       "ppsspp_change_mac_address11",
-      "MAC Address Pt 11: --:--:--:--:--:X-",
+      "MAC Address Pt 11: --:--:--:--:--:x-",
       NULL,
       NULL,
       NULL,
@@ -845,7 +833,7 @@ struct retro_core_option_v2_definition option_defs_us[] = {
    },
    {
       "ppsspp_change_mac_address12",
-      "MAC Address Pt 12: --:--:--:--:--:-X",
+      "MAC Address Pt 12: --:--:--:--:--:-x",
       NULL,
       NULL,
       NULL,
